# KrakenParser: Convert Kraken2 Reports to CSV

## Overview
KrakenParser is a collection of scripts designed to process Kraken2 reports and convert them into CSV format. This pipeline extracts taxonomic abundance data at six levels:
- **Phylum**
- **Class**
- **Order**
- **Family**
- **Genus**
- **Species**

You can run the entire pipeline with **a single command**, or use the scripts **individually** depending on your needs.

🔗 Please visit [KrakenParser wiki](https://github.com/PopovIILab/KrakenParser/wiki) page

## Output example

### Total abundance output

`counts_phylum.csv` parsed from 7 kraken2 reports of metagenomic samples using `KrakenParser`:

```
Sample_id,Caldithrix abyssi,Caldisericum exile,Thermosulfidibacter takaii,Candidatus Endomicrobium trichonymphae,Endomicrobium proavitum,Elusimicrobium minutum,Candidatus Chazhemtobacterium aquaticus,Candidatus Fervidibacter sacchari,Lentisphaera profundi,Kiritimatiella glycovorans,Tichowtungia aerotolerans,Vulcanimicrobium alpinum,Atribacter laminatus,Dictyoglomus turgidum,Nitrospina watsonii,Desulfurispirillum indicum,Coprothermobacter proteolyticus,Thermovibrio ammonificans,Desulfurobacterium thermolithotrophum,Sulfurihydrogenibium azorense,Sulfurihydrogenibium sp. YO3AOP1,Persephonella marina,Thermocrinis minervae,Aquifex aeolicus,Hydrogenobaculum sp. Y04AAS1,Hydrogenobaculum sp. HO,Thermotoga profunda,Pseudothermotoga thermarum,Pseudothermotoga hypogea,Fervidobacterium nodosum,Thermosipho africanus,Thermosipho ferrireducens,Thermosipho melanesiensis,Oceanotoga sp. DSM 15011,Defluviitoga tunisiensis,Petrotoga mobilis,Tepiditoga spiralis,Marinitoga sp. 1137,Athalassotoga saccharophila,Mesotoga prima,Mesotoga infera,Kosmotoga pacifica,Kosmotoga olearia,Halobacteriovorax marinus,Halobacteriovorax sp. BALOs 7,Bacteriovorax stolpii,Peredibacter starrii,Spirobacillus cienkowskii,Pigmentibacter sp. JX0631,Fluviispira sanaruensis,Silvanigrella aquatica,Micavibrio aeruginosavorus,Pseudobdellovibrio exovorus,Bdellovibrio sp. NC01,Bdellovibrio bacteriovorus,Thermodesulfovibrio yellowstonii,Dissulfurispira thermophila,Leptospirillum ferrooxidans,Nitrospira tepida,Candidatus Nitrospira inopinata,Nitrospira japonica,Deferribacter desulfuricans,Calditerrivibrio nitroreducens,Mucispirillum schaedleri,Flexistipes sinusarabici,Denitrovibrio acetiphilus,Geovibrio thiophilus,Aminobacterium colombiense,Aminobacterium sp. MB27-C1,Aminithiophilus ramosus,Acetomicrobium mobile,Pyramidobacter sp. YE332,Pyramidobacter piscolens,Jonquetella anthropi,uncultured Dethiosulfovibrio sp.,Thermanaerovibrio acidaminovorans,Aminomonas paucivorans,Cloacibacillus porcorum,Nannocystis poenicansa,Haliangium ochraceum,Labilithrix luteola,Polyangium aurulentum,Chondromyces crocatus,Pajaroellobacter abortibovis,Sorangium cellulosum,Sandaracinus amylolyticus,Cystobacter fuscus,Archangium violaceum,Stigmatella aurantiaca,Myxococcus xanthus,Myxococcus sp. SDU36,Myxococcus stipitatus,Myxococcus hansupus,Pyxidicoccus parkwaysis,Vulgatibacter incomptus,Anaeromyxobacter oryzae,Anaeromyxobacter paludicola,Anaeromyxobacter sp. Fw109-5,Luteitalea pratensis,Chloracidobacterium validum,Candidatus Korobacter versatilis,Alloacidobacterium dinghuense,Occallatibacter riparius,Acidobacterium capsulatum,Acidisarcina polymorpha,Granulicella sp. WH15,uncultured Paludibaculum sp.,Sulfidibacter corallicola,Thermotomaculum hydrothermale,Mesoterricola sediminis,Mesoterricola silvestris,uncultured Holophaga sp.,Geothrix sp. 21YS21S-4,Geothrix sp. PMB-07,Candidatus Chromulinivorax destructor,Candidatus Babela massiliensis,Candidatus Bipolaricaulis anaerobius,Candidatus Mycosynbacter amalyticus,Candidatus Nanosynbacter featherlites,Candidatus Saccharimonas aalborgensis,Candidatus Minimicrobia vallesae,Candidatus Absconditicoccus praedator,Haliovirga abyssi,Ilyobacter polytropus,uncultured Ilyobacter sp.,Cetobacterium somerae,Fusobacterium pseudoperiodonticum,Fusobacterium ulcerans,Fusobacterium varium,Fusobacterium gonidiaformans,Fusobacterium polymorphum,Fusobacterium necrophorum,Fusobacterium vincentii,Fusobacterium nucleatum,Fusobacterium animalis,Fusobacterium hwasookii,Sneathia vaginalis,Pseudoleptotrichia goodfellowii,Streptobacillus moniliformis,Sebaldella termitidis,Leptotrichia hofstadii,Leptotrichia buccalis,Leptotrichia wadei,Leptotrichia trevisanii,Leptotrichia hongkongensis,Leptotrichia sp. oral taxon 498,Leptotrichia sp. oral taxon 221,Leptotrichia sp. oral taxon 212,Leptotrichia sp. oral taxon 847,Leptotrichia shahii,Dissulfurimicrobium hydrothermale,Microvenator marinus,Bradymonas sediminis,Persicimonas caeni,Brachyspira murdochii,Brachyspira hyodysenteriae,Brachyspira pilosicoli,Thermospira aquatica,Turneriella parva,Leptospira tipperaryensis,Leptospira santarosai,Leptospira mayottensis,Leptospira borgpetersenii,Leptospira noguchii,Leptospira interrogans,Leptospira sp. GIMC2001,Leptospira kobayashii,Breznakiella homolactica,Parasphaerochaeta coccoides,uncultured Sphaerochaeta sp.,Sediminispirochaeta smaragdinae,Oceanispirochaeta crateris,Marispirochaeta aestuarii,Marispirochaeta sp.,Salinispira pacifica,Candidatus Haliotispira prima,Entomospira culicis,Thiospirochaeta perfilievii,Spirochaeta thermophila,Spirochaeta africana,Brucepastera parasyntrophica,Treponema primitia,Treponema denticola,Treponema phagedenis,Treponema bryantii,Treponema pedis,Treponema sp. OMZ 791,Treponema brennaborense,Treponema socranskii,Treponema ruminis,Treponema succinifaciens,Treponema vincentii,Treponema peruense,Treponema pallidum,Treponema saccharophilum,Borrelia miyamotoi,Borrelia sp. HM,Borrelia sp. P9F1,Borreliella mayonii,Borreliella sinica,Borreliella tanukii,Borreliella bissettiae,Borreliella kurtenbachii,Borreliella lusitaniae,Borreliella afzelii,Borreliella carolinensis,Borreliella andersonii,Borreliella garinii,Candidatus Velamenicoccus archaeovorus,Simkania negevensis,Candidatus Neptunochlamydia sp. REUL1,Candidatus Rhabdochlamydia porcellionis,Parachlamydia acanthamoebae,Candidatus Protochlamydia amoebophila,Candidatus Protochlamydia naegleriophila,Chlamydia abortus,Chlamydia psittaci,Chlamydia suis,Chlamydia pecorum,Methylacidimicrobium sp. B4,Candidatus Xiphinematobacter sp. Idaho Grape,Candidatus Pelagisphaera phototrophica,Rubellicoccus peritrichatus,Coraliomargarita algicola,Coraliomargarita akajimensis,Opitutus terrae,Lacunisphaera limnophila,Actomonas aquatica,Termitidicoccus mucosus,Synoicihabitans lomoniglobus,Akkermansia glycaniphila,Roseimicrobium sp. ORNL1,Luteolibacter luteus,Luteolibacter sp. SL250,Verrucomicrobium sp. GAS474,Verrucomicrobium spinosum,Sulfuriroseicoccus oceanibius,Fontisphaera persica,Candidatus Kuenenia stuttgartiensis,Candidatus Uabimicrobium amorphum,Humisphaera borealis,Mucisphaera calidilacus,Poriferisphaera corsica,Phycisphaera mikurensis,Limihaloglobus sulfuriphilus,Sedimentisphaera cyanobacteriorum,Sedimentisphaera salicampi,Anaerohalosphaera lusitana,Tautonia plasticadhaerens,Singulisphaera acidiphila,Aquisphaera giovannonii,Paludisphaera borealis,Isosphaera pallida,Telmatocola sphagniphila,Urbifossiella limnaea,Frigoriglobus tundricola,Limnoglobus roseus,Tuwongella immobilis,Gemmata massiliana,Gemmata obscuriglobus,Thermogutta terrifontis,Aeoliella mucimassa,Bythopirellula goksoeyrii,Pirellulimonas nuda,Botrimarina mediterranea,Lacipirellula parvula,Lacipirellula limnantheis,Adhaeretor mobilis,Rosistilla ulvae,Lignipirellula cremea,Blastopirellula sp. J2-11,Anatilimnocola aggregata,Aureliella helgolandensis,Mariniblastus fucicola,Rubripirellula lacrimiformis,Stieleria maiorica,Stieleria varia,Pirellula sp. SH-Sr6A,Planctoellipticum variicoloris,Stratiformator vulcanicus,Thalassoglobus polymorphus,Polystyrenella longa,Planctomyces sp. SH-PL14,Planctomyces sp. SH-PL62,Caulifigura coniformis,Rubinisphaera brasiliensis,Calycomorphotria hydatis,Symmachiella dynata,Alienimonas californiensis,Fuerstiella marisgermanici,Gimesia chilikensis,Gimesia fumaroli,Gimesia maris,Gimesia alba,Candidatus Desulfofervidus auxilii,Desulfomonile tiedjei,Desulfobacca acetoxidans,Desulfoglaeba alkanexedens,Syntrophobacter fumaroxidans,Desulfarculus baarsii,Desulfoferula mesophilus,Desulfatibacillum aliphaticivorans,Desulfoluna limicola,Desulfosarcina ovata,Desulfosarcina sp. BuS5,Desulfosarcina alkanivorans,Desulfococcus multivorans,Desulfonema magnum,Desulfonema limicola,Desulfosudis oleivorans,Desulfobacula toluolica,Desulfobacter hydrogenophilus,uncultured Desulfobacter sp.,Desulforapulum autotrophicum,Syntrophus aciditrophicus,Thermodesulfatator indicus,Caldimicrobium thiodismutans,Thermosulfurimonas marina,Thermodesulfobacterium geofontis,Thermosulfuriphilus ammonigenes,Geotalea uraniireducens,Citrifermentans bemidjiense,Trichlorobacter lovleyi,Geomonas sp. RF6,Geobacter pickeringii,Geobacter sp. FeAm09,Geoalkalibacter halelectricus,Geoalkalibacter subterraneus,uncultured Desulfuromusa sp.,Pelobacter propionicus,uncultured Desulfuromonas sp.,Desulfuromonas versatilis,Desulfuromonas sp. DDH964,Desulfuromonas sp. AOP6,Desulfuromonas thiophila,Syntrophotalea acetylenica,Syntrophotalea carbinolica,Syntrophotalea acetylenivorans,Desulfogranum marinum,Desulfurivibrio alkaliphilus,Desulfolithobacter dissulfuricans,Candidatus Electrothrix sp. GW3-4,Desulfobulbus oligotrophicus,Desulfobulbus oralis,Desulfobulbus propionicus,uncultured Desulfobulbus sp.,Desulfofustis limnaeus,Desulfopila sp. IMCC35008,Desulfotalea psychrophila,Desulfosediminicola flagellatus,Desulfosediminicola ganghwensis,Desulfohalobium retbaense,Desulfomicrobium orale,Thermodesulfomicrobium sp. WS,Desulfolutivibrio sulfoxidireducens,Oleidesulfovibrio alaskensis,Oceanidesulfovibrio marinus,uncultured Mailhella sp.,Salidesulfovibrio onnuriiensis,Nitratidesulfovibrio vulgaris,Maridesulfovibrio sp.,Desulfocurvibacter africanus,Lawsonia intracellularis,Megalodesulfovibrio gigas,uncultured Pseudodesulfovibrio sp.,Pseudodesulfovibrio mercurii,Pseudodesulfovibrio sp. zrk46,Pseudodesulfovibrio tunisiensis,Pseudodesulfovibrio profundus,Pseudodesulfovibrio portus,Pseudodesulfovibrio piezophilus,Pseudodesulfovibrio sp. 5S69,Pseudodesulfovibrio cashew,Pseudodesulfovibrio aespoeensis,Taurinivorans muris,Desulfovibrio piger,Desulfovibrio ferrophilus,Desulfovibrio sp. G11,Solidesulfovibrio carbinolicus,Hippea maritima,Nautilia sp. PV-1,Caminibacter mediatlanticus,Caminibacter pacificus,Nitratiruptor sp. YY09-18,Nitrosophilus labii,Nitratifractor salsuginis,Sulfurovum mangrovi,Sulfurovum indicum,Poseidonibacter lekithochrous,Malaciobacter pacificus,Malaciobacter halophilus,Arcobacter acticola,Aliarcobacter lanthieri,Aliarcobacter cibarius,Aliarcobacter cryaerophilus,Aliarcobacter skirrowii,Halarcobacter bivalviorum,Halarcobacter ebronensis,Halarcobacter anaerophilus,Sulfurimonas aquatica,Sulfurimonas lithotrophica,Sulfurimonas paralvinellae,Sulfurimonas hydrogeniphila,Sulfurimonas sp. HSL-3221,Sulfurimonas sp.,Sulfurimonas marina,Hydrogenimonas urashimensis,Hydrogenimonas cancrithermarum,Sulfurospirillum cavolei,Sulfurospirillum sp. 1612,Sulfurospirillum multivorans,Sulfurospirillum diekertiae,Wolinella succinogenes,Helicobacter apodemus,Helicobacter acinonychis,Helicobacter mastomyrinus,Helicobacter enhydrae,Helicobacter suis,Helicobacter felis,Helicobacter heilmannii,Helicobacter hepaticus,Helicobacter himalayensis,Helicobacter mustelae,Helicobacter canis,Helicobacter bizzozeronii,Helicobacter sp. NHP19-003,Helicobacter cinaedi,Helicobacter pylori,Campylobacter sp. RM12651,Campylobacter blaseri,Campylobacter novaezeelandiae,Campylobacter sp. RM5004,Campylobacter sputorum,Campylobacter sp. RM6137,Campylobacter pinnipediorum,Campylobacter hominis,Candidatus Campylobacter infans,Campylobacter gracilis,Campylobacter concisus,Campylobacter canadensis,Campylobacter geochelonis,Campylobacter avium,Campylobacter lari,Campylobacter cuniculorum,Campylobacter coli,Campylobacter jejuni,unidentified bacterial endosymbiont,Candidatus Cloacimonas acidaminovorans,Fibrobacter succinogenes,Gemmatirosa kalamazoonensis,Gemmatimonas phototrophica,Gemmatimonas groenlandica,Cyclonatronum proteinivorum,Salinibacter ruber,Rhodothermus marinus,Rhodocaloribacter litoris,Melioribacter roseus,Ignavibacterium sp.,Chloroherpeton thalassium,Pelodictyon phaeoclathratiforme,Chlorobium phaeobacteroides,Chlorobium limicola,Prosthecochloris sp. SCSIO W1103,Candidatus Sulfidibacterium hydrothermale,Haliscomenobacter hydrossis,Aureispira sp. CCB-E,Aureispira anguillae,Saprospira sp. CCB-QB6,Panacibacter ginsenosidivorans,Ferruginibacter lapsinanis,Arachidicoccus sp. BS20,Arachidicoccus ginsenosidivorans,Niabella yanshanensis,Niabella soli,Phnomibacter ginsenosidimutans,Sediminibacterium sp. TEGAF015,Pseudocnuella soli,Flavisolibacter ginsenosidimutans,Longitalea sp. SCSIO 12813,Rhizosphaericola mali,Filimonas lacunae,Thermoflavifilum sp.,Chitinophaga sp. MD30,Chitinophaga caeni,Chitinophaga niabensis,Chitinophaga sancti,Chitinophaga sp. XS-30,Chitinophaga agri,Aurantibacillus circumpalustris,Olivibacter sp. SDN3,Pseudopedobacter saltans,Anseongella ginsenosidimutans,Solitalea canadensis,Pedobacter heparinus,Pedobacter ginsengisoli,Pedobacter aquae,Pedobacter schmidteae,Pedobacter sp. G11,Pedobacter sp. PACM 27299,Pedobacter mucosus,Pedobacter sp. SL55,Mucilaginibacter robiniae,Mucilaginibacter sp. 14171R-50,Mucilaginibacter mallensis,Mucilaginibacter mali,Mucilaginibacter ginsenosidivorax,Mucilaginibacter rubeus,Mucilaginibacter xinganensis,Mucilaginibacter ginsenosidivorans,Mucilaginibacter ginkgonis,Mucilaginibacter paludis,Mucilaginibacter sp. CSA2-8R,Sphingobacterium psychroaquaticum,Sphingobacterium sp. SRCM116780,Sphingobacterium mizutaii,Sphingobacterium daejeonense,Sphingobacterium sp. E70,Sphingobacterium sp. BN32,Sphingobacterium bambusae,Sphingobacterium sp. PCS056,Sphingobacterium sp. UDSM-2020,Sphingobacterium sp. WM,Sphingobacterium sp. DR205,Sphingobacterium multivorum,Roseivirga spongicola,Reichenbachiella agarivorans,Mangrovivirga cuniculi,Marivirga sp. BDSF4-3,Catalinimonas niigatensis,Tunicatimonas pelagia,Chryseolinea soli,Fulvivirga ulvae,Fulvivirga maritima,Aquirufa lenticrescens,Mongoliitalea daihaiensis,Echinicola soli,Echinicola strongylocentroti,Echinicola marina,Aquiflexum balticum,Belliella baltica,Cyclobacterium marinum,Algoriphagus machipongonensis,Algoriphagus sanaruensis,Fibrella aestuarina,Runella rosea,Larkinella insperata,Tellurirhabdus rosea,Tellurirhabdus bombi,Dyadobacter chenwenxiniae,Dyadobacter sp. NIV53,Dyadobacter fanqingshengii,Dyadobacter fermentans,Dyadobacter chenhuakuii,Leadbetterella byssophila,Marinilongibacter aquaticus,Emticicia oligotrophica,Emticicia sp. 21SJ11W-3,Arcticibacterium luteifluviistationis,Persicobacter psychrovividus,Fulvitalea axinellae,Aureibacter tunicatorum,Cardinium endosymbiont of Encarsia pergandiella,Candidatus Cardinium hertigii,Cardinium endosymbiont of Tipula unca,Candidatus Amoebophilus asiaticus,Adhaeribacter swui,Hymenobacter tibetensis,Hymenobacter volaticus,Hymenobacter canadensis,Hymenobacter sp. DG25A,Hymenobacter oligotrophus,Hymenobacter sp. BRD67,Hymenobacter nivis,Hymenobacter jejuensis,Hymenobacter sedentarius,Hymenobacter sp. YIM 151858-1,Hymenobacter swuensis,Hymenobacter sp. BRD128,Hymenobacter sp. BT18,Pontibacter korlensis,Pontibacter pudoricolor,Pontibacter actiniarum,Pontibacter sp. SGAir0037,Pontibacter sp. G13,Chondrinema litorale,Imperialibacter roseus,Flammeovirga yaeyamensis,Flammeovirga kamogawensis,Flammeovirga pectinis,Rhodocytophaga rosea,Spirosoma sp. SC4-14,Spirosoma montaniterrae,Spirosoma sp. KUDC1026,Spirosoma pollinicola,Spirosoma foliorum,Spirosoma aerolatum,Spirosoma taeanense,Spirosoma oryzicola,Spirosoma radiotolerans,Spirosoma endbachense,Ichthyobacterium seriolicida,Owenweeksia hongkongensis,Parvicella tangerina,Paracrocinitomix mangrovi,Fluviicola taffensis,Candidatus Karelsulcia muelleri,Candidatus Walczuchella endosymbiont of Icerya purchasi,Candidatus Walczuchella monophlebidarum,Blattabacterium sp. (Cryptocercus punctulatus) str. Cpu,Blattabacterium sp. (Mastotermes darwiniensis),Blattabacterium cuenoti,Empedobacter falsenii,Empedobacter brevis,Kaistella antarctica,Candidatus Ornithobacterium hominis,Cruoricaptor ignavus,Chryseobacterium arthrosphaerae,Chryseobacterium bernardetii,Chryseobacterium scophthalmum,Chryseobacterium taklimakanense,Chryseobacterium sp. POL2,Chryseobacterium sp. ZHDP1,Chryseobacterium sp. MEBOG07,Chryseobacterium sp. SG20098,Chryseobacterium indologenes,Chryseobacterium sp. Y16C,Chryseobacterium lactis,Chryseobacterium sp. MYb264,Chryseobacterium piperi,Chryseobacterium shandongense,Chryseobacterium sp. PET-29,Elizabethkingia sp. 2-6,Elizabethkingia anophelis,Apibacter sp. ESL0404,Apibacter raozihei,Bergeyella porcorum,Bergeyella cardium,Riemerella anatipestifer,Weeksella virosa,Faecalibacter sp. LW9,Pukyongia salina,Hwangdonia sp. SCSIO 19198,Oceanihabitans sp. IOP 32,Antarcticibacterium sp. 1MA-6-2,Candidatus Arcticimaribacter forsetii,Lacinutrix venerupis,Aequorivita sp. H23M31,Aegicerativicinus sediminis,Psychroflexus torquis,Sediminicola sp. YIK13,Urechidicola croceus,Flavivirga abyssicola,Tamlana sp. s12,Mesoflavibacter sp. SCSIO 43206,Mariniflexile sp. TRM1-10,Marixanthomonas sp. SCSIO 43207,Christiangramia sp. OXR-203,Christiangramia fulva,Christiangramia flava,Christiangramia oceanisediminis,Algibacter sp. L1A34,Algibacter luteus,Zunongwangia sp. SCSIO 43204,Aestuariibaculum sp. YM273,Olleya sp. HaHaR 3 96,Olleya sp. YS,Olleya sp. Bg11-27,Tenacibaculum finnmarkense,Tenacibaculum pacificus,Tenacibaculum ovolyticum,Tenacibaculum jejuense,Tenacibaculum sp. AHE14PA,Tenacibaculum sp. SZ-18,Euzebyella marina,Robiginitalea biformata,Cellulophaga algicola,Polaribacter vadi,Polaribacter atrinae,Polaribacter sp. HL-MS24,Polaribacter sp. KT25b,Polaribacter haliotis,Imtechella halotolerans,Muricauda sp. SCSIO 65647,Muricauda sp. SCSIO 64092,Abyssalbus ytuae,Croceibacter atlanticus,Siansivirga zeaxanthinifaciens,Wenyingzhuangia fucanilytica,Psychroserpens sp. NJDZ02,Arenibacter algicola,Capnocytophaga sputigena,Capnocytophaga haemolytica,Capnocytophaga stomatis,Capnocytophaga gingivalis,Capnocytophaga canimorsus,Aquimarina sp. AD10,Aquimarina sp. AD1,Aquimarina sp. ERC-38,Lutibacter sp. A80,Lutibacter profundi,Salinimicrobium tongyeongense,Nonlabens dokdonensis,Nonlabens sp. Ci31,Nonlabens ulvanivorans,Nonlabens sp. Hel1 33 55,Aureibaculum algae,Dokdonia sp. 4H-3-7-5,Maribacter halichondriae,Maribacter litopenaei,Maribacter dokdonensis,Flagellimonas maritima,Kordia antarctica,Kordia sp. SMS9,Myroides sp. JBRI-B21084,Myroides albus,Myroides odoratus,Myroides sp. mNGS23 01,Winogradskyella sp. PG-2,Winogradskyella helgolandensis,Winogradskyella forsetii,Flavobacterium galactosidilyticum,Flavobacterium crocinum,Flavobacterium sp. N1736,Flavobacterium bizetiae,Flavobacterium gelatinilyticum,Flavobacterium kingsejongi,Flavobacterium oreochromis,Flavobacterium nitratireducens,Flavobacterium cyclinae,Flavobacterium sp. N2820,Flavobacterium sp. NG2,Flavobacterium limnophilum,uncultured Flavobacterium sp.,Flavobacterium sp. N1994,Flavobacterium agricola,Flavobacterium commune,Flavobacterium johnsoniae,Flavobacterium covae,Flavobacterium channae,Flavobacterium okayamense,Flavobacterium davisii,Flavobacterium sp. I3-2,Flavobacterium sp. M31R6,Flavobacterium sp. IMCC34852,Flavobacterium sp. N3904,Flavobacterium sp. K5-23,Flavobacterium sp. CLA17,Flavobacterium columnare,Flavobacterium psychrophilum,Marinifilum fragile,Labilibaculum sp.,Maribellus comscasis,Mangrovibacterium marinum,uncultured Draconibacterium sp.,uncultured Sunxiuqinia sp.,Aquipluma nitroreducens,Xiashengella succiniciproducens,Alkalitalea saponilacus,uncultured Carboxylicivirga sp.,Salinivirga cyanobacteriivorans,Tenuifilum thalassicum,Paludibacter propionicigenes,Parabacteroides johnsonii,Parabacteroides chongii,Parabacteroides sp. AD58,Parabacteroides goldsteinii,Parabacteroides distasonis,Parabacteroides merdae,Barnesiella viscericola,Coprobacter secundus,Paramuribaculum intestinale,Sodaliphilus pleomorphus,Muribaculum intestinale,Butyricimonas virosa,Odoribacter splanchnicus,uncultured Macellibacteroides sp.,Porphyromonas endodontalis,Porphyromonas pogonae,Porphyromonas asaccharolytica,Porphyromonas sp. oral taxon 275,Porphyromonas crevioricanis,Porphyromonas somerae,Porphyromonas cangingivalis,Porphyromonas gingivalis,uncultured Acetobacteroides sp.,Alistipes communis,Alistipes indistinctus,Alistipes shahii,Alistipes onderdonkii,Alistipes dispar,Alistipes ihumii,Pseudoprevotella muciniphila,Xylanibacter ruminicola,Paraprevotella xylaniphila,Hoylesella enoeca,Hoylesella buccalis,Segatella hominis,Segatella copri,Prevotella sp. E15-22,Prevotella fusca,Prevotella melaninogenica,Prevotella sp. E9-3,Prevotella bivia,Prevotella jejuni,Prevotella communis,Prevotella intermedia,Prevotella denticola,Prevotella herbatica,Prevotella sp. oral taxon 299,Prevotella sp. E13-17,Prevotella sp. Rep29,Prevotella dentalis,Prevotella corporis,Prevotella multiformis,Proteiniphilum saccharofermentans,Petrimonas mucosa,Petrimonas sp.,Dysgonomonas sp. HDW5A,Dysgonomonas capnocytophagoides,Phocaeicola vulgatus,Phocaeicola salanitronis,Phocaeicola dorei,Bacteroides zoogleoformans,Bacteroides luhongzhouii,Bacteroides xylanisolvens,Bacteroides sp. MSB163,uncultured Bacteroides sp.,Bacteroides stercoris,Bacteroides cellulosilyticus,Bacteroides faecis,Bacteroides intestinalis,Bacteroides ovatus,Bacteroides salyersiae,Bacteroides uniformis,Bacteroides sp. DH3716P,Bacteroides thetaiotaomicron,Bacteroides fragilis,Truepera radiovictrix,Deinococcus sp. QL22,Deinococcus psychrotolerans,Deinococcus puniceus,Deinococcus metallilatus,Deinococcus sp. AJ005,Deinococcus aetherius,Deinococcus radiodurans,Deinococcus rubellus,Deinococcus deserti,Deinococcus ficus,Deinococcus sp. AB2017081,Deinococcus geothermalis,Deinococcus peraridilitoris,Deinococcus sp. KNUC1210,Deinococcus gobiensis,Deinococcus maricopensis,Deinococcus wulumuqiensis,Deinococcus radiophilus,Marinithermus hydrothermalis,Allomeiothermus silvanus,Oceanithermus profundus,Meiothermus taiwanensis,Thermus thermophilus,Thermus aquaticus,Thermus scotoductus,Sphaerobacter thermophilus,Thermomicrobium roseum,Fimbriimonas ginsengisoli,Chthonomonas calidirosea,Capsulimonas corticalis,Candidatus Promineifilum breve,Caldilinea aerophila,Thermobaculum terrenum,Tepidiforma flava,Tepidiforma bonchosmolovskayae,Thermoflexus hugenholtzii,Ktedonosporobacter rubrisoli,Dehalogenimonas sp. W,Dehalococcoides mccartyi,Candidatus Lucifugimonas marina,Brevefilum fermentans,Anaerolinea thermophila,Pelolinea submarina,Phototrophicus methaneseepsis,Candidatus Chlorohelix allophototropha,Chloroflexus aurantiacus,Chloroflexus aggregans,Roseiflexus castenholzii,Roseiflexus sp. RS-1,cyanobacterium endosymbiont of Epithemia turgida,cyanobacterium endosymbiont of Epithemia clementina EcSB,Acaryochloris sp. 'Moss Beach',Acaryochloris marina,Thermostichus lividus,Chroococcidiopsis sp. CCMEE 29,Allocoleopsis franciscana,Chamaesiphon minutus,Crinalium epipsammum,Pseudanabaena sp. ABRG5-3,Pseudanabaena galeata,Pseudanabaena sp. PCC 7367,Geitlerinema sp. PCC 7407,Gloeobacter violaceus,Gloeobacter morelensis,Gloeobacter kilaueensis,Anthocerotibacter panamensis,Trichocoleus desertorum,Trichothermofontia sichuanensis,Leptothermofonsia sichuanensis,Kovacikia minuta,Leptolyngbya sp. O-77,Leptolyngbya sp. 7M,Leptolyngbya boryana,Leptolyngbya sp. BL0902,Parasynechococcus marenigrum,Cyanobium sp. NS01,Cyanobium sp. NIES-981,Prochlorococcus sp. MIT 1307,Prochlorococcus marinus,Dactylococcopsis salina,Synechococcus sp. CBW1004,Synechococcus sp. PCC 7502,Synechococcus sp. CBW1107,Synechococcus sp. A15-62,Synechococcus sp. SynAce01,Synechococcus sp. PROS-U-1,Synechococcus sp. NB0720 010,Synechococcus sp. JA-3-3Ab,Synechococcus sp. JA-2-3B'a(2-13),Synechococcus sp. PCC 6312,Synechococcus sp. PCC 7336,Synechococcus sp. NOUM97013,Synechococcus elongatus,Stanieria cyanosphaera,Pleurocapsa sp. FMAR1,Pleurocapsa sp. PCC 7327,Nodosilinea sp. E11,[Phormidium] sp. ETS-05,Phormidium yuhuli,Moorena producens,Oscillatoria nigro-viridis,Oscillatoria acuminata,Limnospira indica,Limnospira fusiformis,Oxynema aestuarii,Planktothrix agardhii,Gloeocapsopsis dulcis,Euhalothece natronophila,Halothece sp. PCC 7418,Microcystis sp. MC19,[Leptolyngbya] sp. PCC 7376,Picosynechococcus sp. PCC 7003,Geminocystis sp. NIES-3708,Geminocystis herdmanii,Geminocystis sp. NIES-3709,Rippkaea orientalis,Crocosphaera subtropica,Gloeothece citriformis,Gloeothece verrucosa,Candidatus Atelocyanobacterium thalassa,Anabaenopsis elenkinii,Nodularia sphaerocarpa,Nodularia spumigena,Cylindrospermopsis curvispora,Cylindrospermopsis raciborskii,Rivularia sp. PCC 7116,Calothrix sp. PCC 6303,Calothrix sp. PCC 7507,Calothrix sp. 336/3,Calothrix sp. NIES-3974,Brasilonema sennae,Tolypothrix sp. PCC 7601,Tolypothrix sp. PCC 7910,Trichormus variabilis,Nostoc sp. C057,Nostoc sphaeroides,Nostoc punctiforme,Nostoc sp. TCL26-01,Nostoc edaphicum,Nostoc sp. PCC 7107,Nostoc flagelliforme,Nostoc sp. UHCC 0302,Nostoc sp. TCL240-02,Nostoc sp. CENA543,Anabaena sp. YBS01,Candidatus Xianfuyuplasma coldseepsis,Hujiaoplasma nucleasis,endosymbiont DhMRE of Dentiscutata heterogama,Candidatus Hepatoplasma crinochetorum,Mycoplasma miroungigenitalium,Mycoplasma sp. 1018B,Mycoplasma sp. Ms02,Mycoplasma wenyonii,Mycoplasma crocodyli,Mycoplasma amphoriforme,Mycoplasma miroungirhinis,Mycoplasma haemofelis,Mycoplasma suis,Mycoplasma ovis,Mycoplasma seminis,Candidatus Mycoplasma haematolamae,Mycoplasma sp. 888,Mycoplasma sp. SG1,Mycoplasma mycoides,Mycoplasma iguanae,Mycoplasma anserisalpingitidis,Mycoplasma phocoenae,Mycoplasma feriruminatoris,Mycoplasma capricolum,Mycoplasma sp. (ex Biomphalaria glabrata),Mycoplasma sp. NEAQ87857,Candidatus Mycoplasma mahonii,Williamsoniiplasma somnilux,Williamsoniiplasma luminosum,Mesoplasma florum,Mesoplasma syrphidae,Mesoplasma lactucae,Spiroplasma alleghenense,Spiroplasma syrphidicola,Spiroplasma ixodetis,Spiroplasma kunkelii,Spiroplasma endosymbiont of Nomada ruficornis,Spiroplasma endosymbiont of Poecilobothrus nobilitatus,Spiroplasma taiwanense,Spiroplasma endosymbiont of Aspidapion aeneum,Spiroplasma endosymbiont of Notiophilus biguttatus,Spiroplasma endosymbiont of Agriotes lineatus,Spiroplasma endosymbiont of Nebria brevicollis,Spiroplasma endosymbiont of Villa modesta,Spiroplasma culicicola,Spiroplasma clarkii,Spiroplasma endosymbiont of Nephrotoma flavescens,Spiroplasma endosymbiont of Monopis laevigella,Spiroplasma helicoides,Spiroplasma sabaudiense,Spiroplasma turonicum,Spiroplasma chinense,Spiroplasma gladiatoris,Spiroplasma platyhelix,Spiroplasma apis,Spiroplasma endosymbiont of Othius punctulatus,Spiroplasma endosymbiont of Zeiraphera isertana,Spiroplasma endosymbiont of Asaphidion curtum,Spiroplasma endosymbiont of Polydrusus cervinus,Spiroplasma endosymbiont of Colias croceus,Spiroplasma endosymbiont of 'Nebria riversi',Spiroplasma endosymbiont of Tiphia femorata,Spiroplasma endosymbiont of Labia minor,Spiroplasma corruscae,Spiroplasma endosymbiont of Crioceris asparagi,Spiroplasma endosymbiont of Sarcophaga carnaria,Spiroplasma endosymbiont of Lasioglossum villosulum,Paracholeplasma brassicae,Alteracholeplasma palmae,Haploplasma axanthum,Mulberry dwarf phytoplasma,Paulownia witches'-broom phytoplasma,Candidatus Phytoplasma rubi,Phytoplasma sp.,Candidatus Phytoplasma australiense,Candidatus Phytoplasma ziziphi,Candidatus Phytoplasma luffae,Candidatus Phytoplasma mali,Mariniplasma anaerobium,Acholeplasma laidlawii,Acholeplasma hippikon,Ureaplasma diversum,Ureaplasma parvum,Ureaplasma urealyticum,Mycoplasmoides pneumoniae,Mycoplasmoides gallisepticum,Mycoplasmoides fastidiosum,Malacoplasma iowae,Malacoplasma penetrans,[Mycoplasma] phocae,Metamycoplasma salivarium,Metamycoplasma alkalescens,Metamycoplasma arthritidis,[Mycoplasma] gypis,Metamycoplasma hominis,Metamycoplasma subdolum,Metamycoplasma orale,Mesomycoplasma lagogenitalium,Mesomycoplasma hyorhinis,Mesomycoplasma ovipneumoniae,[Mycoplasma] mobile,Mesomycoplasma molare,Mesomycoplasma dispar,Mesomycoplasma conjunctivae,Mesomycoplasma neurolyticum,Mycoplasmopsis californica,Mycoplasmopsis synoviae,Mycoplasmopsis bovirhinis,Mycoplasmopsis canis,Mycoplasmopsis pulmonis,Mycoplasmopsis felifaucium,Mycoplasmopsis arginini,Mycoplasmopsis fermentans,Mycoplasmopsis agalactiae,Mycoplasmopsis verecunda,Mycoplasmopsis cynos,Mycoplasmopsis caviae,Mycoplasmopsis felis,Mycoplasmopsis gallopavonis,Mycoplasmopsis bovis,Mycoplasmopsis meleagridis,Mycoplasmopsis pullorum,Mycoplasmopsis equigenitalium,Mycoplasmopsis columbinasalis,Egibacter rhizosphaerae,Euzebya pacifica,Egicoccus halophilus,Miltoncostaea oceani,Thermoleophilum album,Paraconexibacter antarcticus,Capillimicrobium parvum,Conexibacter sp. S30A1,Conexibacter woesei,Conexibacter sp. SYSU D00693,Rubrobacter tropicus,Rubrobacter marinus,Rubrobacter radiotolerans,Rubrobacter xylanophilus,Acidimicrobium ferrooxidans,Ilumatobacter coccineus,Aquihabitans sp. G128,Dermatobacter hominis,Iamia majanohamensis,Iamia sp. SCSIO 61187,Actinomarinicola tropica,Enorma phocaeensis,Collinsella sp. zg1085,Collinsella stercoris,Collinsella aerofaciens,Coriobacterium glomerans,Thermophilibacter mediterraneus,Fannyhessea vaginae,Parafannyhessea umbonata,Lancefieldella sp. Marseille-Q7238,Lancefieldella parvula,Olsenella timonensis,Olsenella uli,Atopobium sp. oral taxon 416,Parolsenella massiliensis,Parolsenella catena,Denitrobacterium detoxificans,Phoenicibacter congonensis,Berryella wangjianweii,Gordonibacter urolithinfaciens,Gordonibacter pamelaeae,Cryptobacterium curtum,Xiamenia xianingshaonis,Raoultibacter timonensis,Arabiibacter massiliensis,Slackia heliotrinireducens,Eggerthella lenta,Eggerthella sp. YY7918,Epidermidibacterium keratini,Jiangella alkaliphila,Acidothermus cellulolyticus,Catenulispora acidiphila,Nakamurella multipartita,Nakamurella antarctica,Candidatus Protofrankia datiscae,Frankia sp. ArI3,Frankia casuarinae,Frankia alni,Modestobacter sp. L9-4,Blastococcus sp. PRF04-17,Blastococcus brunescens,Natronoglycomyces albus,Stackebrandtia nassauensis,Candidatus Nanopelagicus limnes,Candidatus Planktophila versatilis,Candidatus Planktophila lacus,Actinopolyspora erythraea,Jatrophihabitans cynanchi,Jatrophihabitans telluris,Jatrophihabitans sp. GAS493,Spirillospora sp. NBC 00431,Thermomonospora curvata,Thermomonospora amylolytica,Actinoallomurus sp. NBC 01490,Actinomadura sp. WMMA1423,Actinomadura madurae,Streptosporangium roseum,Nonomuraea sp. NBC 01738,Nonomuraea coxensis,Nonomuraea phyllanthi,Microbispora sp. NBC 01189,Microbispora sp. ZYX-F-249,Microbispora hainanensis,Thermobispora bispora,Streptomonospora litoralis,Spiractinospora alimapuensis,Nocardiopsis alba,Nocardiopsis gilva,Nocardiopsis dassonvillei,Thermobifida alba,Thermobifida fusca,Phytohabitans flavus,Solwaraspora sp. WMMA2056,Couchioplanes caeruleus,Dactylosporangium sp. AC04546,Natronosporangium hydrolyticum,Actinoplanes sp. NBC 00393,Actinoplanes sp. SE50,Actinoplanes derwentensis,Actinoplanes missouriensis,Plantactinospora sp. BC1,Plantactinospora sp. BB1,Micromonospora maris,Micromonospora chokoriensis,Micromonospora craniellae,Micromonospora sp. WMMC415,Micromonospora sp. WMMD812,Micromonospora sp. NBC 01699,Micromonospora chalcea,Micromonospora sp. LH3U1,Micromonospora ureilytica,Micromonospora sp. HUAS LYJ1,Micromonospora sp. WMMD882,Micromonospora auratinigra,Micromonospora endophytica,Micromonospora terminaliae,Micromonospora carbonacea,Micromonospora sp. NBC 01813,Micromonospora sp. NBC 00330,Micromonospora profundi,Micromonospora coxensis,Micromonospora sp. NBC 01796,Kutzneria sp. CA-103260,Actinoalloteichus hymeniacidonis,Actinomycetospora sp. NBC 00405,Kibdelosporangium phytohabitans,Allokutzneria albata,Actinosynnema mirum,Actinosynnema pretiosum,Pseudonocardia broussonetiae,Pseudonocardia sp. AL041005-10,Pseudonocardia sp. HH130629-09,Pseudonocardia sp. DSM 110487,Pseudonocardia petroleophila,Pseudonocardia sp. HH130630-07,Pseudonocardia sp. EC080625-04,Lentzea sp. NBC 00516,Umezawaea sp. Da 62-37,Saccharopolyspora sp. ID03-671,Saccharopolyspora gregorii,Saccharopolyspora spinosa,Saccharopolyspora rosea,Saccharopolyspora erythraea,Saccharopolyspora sp. SCSIO 74807,Amycolatopsis thermalba,Amycolatopsis roodepoortensis,Amycolatopsis mediterranei,Amycolatopsis sp. CA-230715,Amycolatopsis sp. FBCC-B4732,Amycolatopsis cynarae,Amycolatopsis sp. NBC 01488,Amycolatopsis sp. AA4,Amycolatopsis sp. NBC 01480,Amycolatopsis sp. EV170708-02-1,Amycolatopsis sp. Hca4,Amycolatopsis coloradensis,Amycolatopsis acidiphila,Saccharomonospora azurea,Saccharomonospora cyanea,Saccharomonospora marina,Actinopolymorpha singaporensis,Kribbella flavida,Kribbella sp. NBC 01484,Kribbella sp. NBC 01245,Kribbella sp. NBC 00482,Raineyella fluvialis,Brooklawnia propionicigenes,Propioniciclava coleopterorum,Microlunatus elymi,Microlunatus soli,Microlunatus sp. Gsoil 973,Microlunatus sagamiharensis,Microlunatus phosphovorus,Arachnia rubra,Arachnia propionica,Auraticoccus monumenti,Vaginimicrobium propionicum,Cutibacterium equinum,Cutibacterium granulosum,Cutibacterium avidum,Cutibacterium modestum,Cutibacterium acnes,Acidipropionibacterium acidipropionici,Acidipropionibacterium jensenii,Tessaracoccus timonensis,Tessaracoccus flavescens,Tessaracoccus sp. MC1865,Tessaracoccus defluvii,Propionibacterium freudenreichii,Propionibacterium acidifaciens,Mumia sp. ZJ1417,Solicola gregarius,Pimelobacter simplex,Friedmanniella luteola,Aeromicrobium duanguangcaii,Aeromicrobium marinum,Aeromicrobium choanae,Nocardioides dokdonensis,Nocardioides humi,Nocardioides euryhalodurans,Nocardioides baekrokdamisoli,Nocardioides sp. TF02-7,Nocardioides sp. CF8,Nocardioides sp. S-1144,Nocardioides sp. Arc9.136,Nocardioides sp. cx-173,Nocardioides sp. InS609-2,Nocardioides sp. zg-1228,Nocardioides sp. HDW12B,Nocardioides sp. Kera G14,Nocardioides sp. NBC 00368,Nocardioides ochotonae,Nocardioides okcheonensis,Nocardioides marmotae,Nocardioides panacisoli,Nocardioides cynanchi,Nocardioides aquaticus,Nocardioides rotundus,Nocardioides sp. B-3,Nocardioides aromaticivorans,Nocardioides faecalis,Changpingibacter yushuensis,Pauljensenia hongkongensis,Flaviflexus equikiangi,Flaviflexus ciconiae,Nanchangia anserum,Actinotignum urinale,Winkia neuii,Arcanobacterium haemolyticum,Arcanobacterium pinnipediorum,Actinobaculum sp. 313,Gleimia hominis,Gleimia europaea,Trueperella bialowiezensis,Trueperella pyogenes,Varibaculum prostatecancerukia,Schaalia odontolytica,Schaalia radingae,Schaalia sp. ZJ405,Schaalia turicensis,Schaalia meyeri,Schaalia sp. 19OD2882,Schaalia sp. JY-X169,Actinomyces sp. oral taxon 169,Actinomyces oris,Actinomyces massiliensis,Actinomyces sp. Z16,Actinomyces trachealis,Actinomyces gaoshouyii,Actinomyces lilanjuaniae,Actinomyces israelii,Actinomyces sp. oral taxon 414,Actinomyces sp. zg-332,Actinomyces sp. 432,Xylanimonas allomyrinae,Dermatophilus congolensis,Gephyromycinifex aptenodytis,Austwickia chelonae,Jonesia denitrificans,Dermacoccus nishinomiyaensis,Allobranchiibius sp. GilTou73,Yimella sp. cx-51,Kytococcus sedentarius,Demequina sediminis,Demequina sp. TMPB413,Sanguibacter sp. HDW7,Ruania suaedae,Ornithinimicrobium flavum,Ornithinimicrobium avium,Ornithinimicrobium ciconiae,Serinicoccus marinus,Pedococcus dokdonensis,Arsenicicoccus sp. oral taxon 190,Intrasporangium calvum,Janibacter sp. CX7,Janibacter sp. YB324,Janibacter limosus,Phycicoccus endophyticus,Brevibacterium luteolum,Brevibacterium spongiae,Brevibacterium pigmentatum,Brevibacterium sandarakinum,Brevibacterium siliguriense,Brevibacterium limosum,Brevibacterium sp. 'Marine',Brevibacterium sp. BRM-1,Brevibacterium sp. JSBI002,Brevibacterium zhoupengii,Brevibacterium sp. CS2,Brevibacterium casei,Brevibacterium aurantiacum,Brevibacterium sp. SMBL HHYL HB1,Tropheryma whipplei,Helcobacillus massiliensis,Dermabacter vaginalis,Dermabacter jinjuensis,Brachybacterium kimchii,Brachybacterium huguangmaarense,Brachybacterium sp. NBEC-018,Brachybacterium sp. SGAir0954,Brachybacterium sp. Z12,Brachybacterium sp. GPGPB12,Brachybacterium halotolerans,Pseudactinotalea sp. HY158,Oerskovia sp. KBS0722,Actinotalea sp. JY-7876,Cellulomonas sp. NS3,Cellulomonas shaoxiangyii,Cellulomonas wangsupingiae,Cellulomonas sp. C5510,Cellulomonas fengjieae,Cellulomonas sp. Y8,Cellulomonas gilvus,Cellulomonas sp. JZ18,Cellulomonas flavigena,Georgenia faecalis,Georgenia sp. TF02-10,Paeniglutamicibacter sp. ZC-3,Psychromicrobium lacuslunae,Sinomonas atrocyanea,Nesterenkonia sp. NBAIMH1,Citricoccus sp. SGAir0253,Pseudoglutamicibacter albus,Auritidibacter ignavus,Pseudarthrobacter sp. L1SW,Pseudarthrobacter sp. NS4,Pseudarthrobacter sulfonivorans,Pseudarthrobacter phenanthrenivorans,Paenarthrobacter sp. JL.01a,Kocuria rhizophila,Kocuria rosea,Kocuria varians,Kocuria palustris,Kocuria indica,Kocuria sp. TGY1127 2,Micrococcus sp. 2A,Micrococcus porci,Micrococcus lylae,Micrococcus terreus,Micrococcus luteus,Glutamicibacter sp. JL.03c,Glutamicibacter sp. ZJUTW,Glutamicibacter halophytocola,Glutamicibacter mishrai,Glutamicibacter creatinolyticus,Glutamicibacter nicotianae,Neomicrococcus aestuarii,Rothia terrae,Rothia amarae,Rothia dentocariosa,Rothia mucilaginosa,Rothia sp. SD9660Na,Rothia kristinae,Rothia aeria,Arthrobacter sp. PAMC25284,Arthrobacter caoxuetaonis,Arthrobacter polaris,Arthrobacter sulfonylureivorans,Arthrobacter koreensis,Arthrobacter woluwensis,Arthrobacter agilis,Arthrobacter zhangbolii,Arthrobacter antioxidans,Arthrobacter sp. FW306-06-A,Arthrobacter sp. StoSoilB22,Arthrobacter jiangjiafuii,Arthrobacter sp. AK-1,Arthrobacter sp. zg-Y1171,Arthrobacter sp. JZ12,Arthrobacter sp. Rue61a,Arthrobacter gengyunqii,Arthrobacter sp. TMP15,Arthrobacter citreus,Arthrobacter alpinus,Arthrobacter crystallopoietes,Arthrobacter sp. StoSoilB13,Arthrobacter sp. ATA002,Arthrobacter sp. Helios,Pontimonas salivibrio,Antiquaquibacter oligotrophicus,Lysinibacter sp. HNR,Agromyces sp. LHK192,Clavibacter sepedonicus,Gulosibacter sediminis,Microterricola viridarii,Microcella humidisoli,Microcella alkaliphila,Rhodoluna lacicola,Cryobacterium sp. 10S3,Glaciihabitans sp. INWT7,Salinibacterium hongtaonis,Salinibacterium sp. M195,Salinibacterium sp. dk2585,Frigoribacterium sp. NBH87,Homoserinibacter sp. YIM 151385,Aquiluna sp. KACHI24,Rathayibacter sp. VKM Ac-2804,Rathayibacter toxicus,Leifsonia sp. PS1209,Leifsonia shinshuensis,Leifsonia sp. ZF2019,Leucobacter tenebrionis,Leucobacter aridicollis,Leucobacter sp. Psy1,Leucobacter triazinivorans,Leucobacter denitrificans,Agrococcus sp. SCSIO52902,Agrococcus carbonis,Agrococcus sp. Marseille-Q4369,Agrococcus jejuensis,Agrococcus beijingensis,Herbiconiux sp. L3-i23,Microbacterium hydrocarbonoxydans,Microbacterium oryzae,Microbacterium testaceum,Microbacterium chengjingii,Microbacterium sp. CGR1,Microbacterium sp. AB,Microbacterium sp. cx-55,Microbacterium sp. str. 'China',Microbacterium limosum,Microbacterium abyssi,Microbacterium lemovicicum,Microbacterium oxydans,Microbacterium schleiferi,Microbacterium amylolyticum,Microbacterium sp. zg-B185,Microbacterium sp. H1-D42,Microbacterium sp. LWO13-1.2,Microbacterium sediminis,Microbacterium esteraromaticum,Microbacterium hominis,Microbacterium resistens,Microbacterium sp. ABRD28,Microbacterium galbinum,Aurantimicrobium photophilum,Curtobacterium sp. MCBA15 004,Curtobacterium sp. Csp1,Curtobacterium sp. MCSS17 015,Curtobacterium sp. MCJR17 020,Curtobacterium sp. MCBA15 012,Curtobacterium sp. 9128,Curtobacterium sp. Csp2,Scardovia inopinata,Gardnerella vaginalis,Parascardovia denticolens,Bifidobacterium sp. ESL0798,Bifidobacterium thermophilum,Bifidobacterium sp. ESL0682,Bifidobacterium pseudocatenulatum,Bifidobacterium dentium,Bifidobacterium breve,Bifidobacterium asteroides,Bifidobacterium sp. ESL0690,Bifidobacterium animalis,Bifidobacterium adolescentis,Bifidobacterium longum,Bifidobacterium pseudolongum,Actinacidiphila glaucinigra,Actinacidiphila bryophytorum,Streptantibioticus cattleyicolor,Yinghuangia sp. ASG 101,Kitasatospora sp. NBC 01266,Kitasatospora aureofaciens,Kitasatospora purpeofusca,Kitasatospora sp. MMS16-BH015,Kitasatospora setae,Peterkaempfera bronchialis,Streptomyces bobili,Streptomyces decoyicus,Streptomyces tubercidicus,Streptomyces sp. Q6,Streptomyces sp. NBC 01235,Streptomyces sp. DSM 40750,Streptomyces sp. XC 2026,Streptomyces sp. NBC 00310,Streptomyces sp. NA04227,Streptomyces goshikiensis,Streptomyces finlayi,Streptomyces drozdowiczii,Streptomyces cavourensis,Streptomyces luteoverticillatus,Streptomyces albus,Streptomyces lydicus,Streptomyces xinghaiensis,Streptomyces laculatispora,Streptomyces flavofungini,Streptomyces niveus,Streptomyces dangxiongensis,Streptomyces noursei,Streptomyces liliifuscus,Streptomyces violaceusniger,Streptomyces sp. YPW6,Streptomyces sp. NBC 00234,Streptomyces sp. DG1A-41,Streptomyces sp. NBC 00461,Streptomyces sp. NBC 01324,Streptomyces sp. NBC 01708,Streptomyces sp. LBUM 1482,Streptomyces sp. NBC 01198,Streptomyces sp. CB09001,Streptomyces sp. NBC 01591,Streptomyces sp. AMCC400023,Streptomyces sp. NBC 00683,Streptomyces sp. NBC 00442,Streptomyces sp. P9-2B-2,Streptomyces sp. NBC 00386,Streptomyces sp. NBC 00414,Streptomyces sp. CB04723,Streptomyces sp. Mut1,Streptomyces sp. NBC 01260,Streptomyces sp. AM 4-1-1,Streptomyces sp. NBC 00984,Streptomyces sp. MRC013,Streptomyces melanogenes,Streptomyces lincolnensis,Streptomyces tirandamycinicus,Streptomyces anthocyanicus,Streptomyces katrae,Streptomyces sp. NBC 00250,Streptomyces sp. INR7,Streptomyces sp. So13.3,Streptomyces sp. TLI 053,Streptomyces sp. NBC 01237,Streptomyces sp. C8S0,Streptomyces antibioticus,Streptomyces phaeochromogenes,Streptomyces capitiformicae,Streptomyces anulatus,Streptomyces collinus,Streptomyces tsukubensis,Streptomyces koyangensis,Streptomyces spongiicola,Streptomyces xanthii,Streptomyces sp. ITFR-16,Streptomyces sp. CGMCC 4.1772,Streptomyces sp. NBC 01321,Streptomyces sp. NBC 01478,Streptomyces sp. SirexAA-E,Streptomyces sp. NBC 00576,Streptomyces sp. NBC 00322,Streptomyces sp. NBC 01750,Streptomyces sp. NHF165,Streptomyces sp. NBC 00400,Streptomyces sp. KMM 9044,Streptomyces sp. NBC 01497,Streptomyces sp. HUAS 15-9,Streptomyces sp. NBC 01232,Streptomyces sp. ST1015,Streptomyces sp. 2P-4,Streptomyces sp. NBC 00273,Streptomyces coeruleorubidus,Streptomyces formicae,Streptomyces brevispora,Streptomyces erythrochromogenes,Streptomyces sp. TG1A-60,Streptomyces sp. NBC 01352,Streptomyces sp. BB1-1-1,Streptomyces sp. NBC 00304,Streptomyces sp. P3,Streptomyces clavuligerus,Streptomyces sp. BRB040,Streptomyces sp. NBC 01803,Streptomyces sp. NBC 00444,Streptomyces sp. NBC 00498,Streptomyces sp. NBC 00557,Streptomyces fradiae,Streptomyces rimosus,Streptomyces virginiae,Streptomyces incarnatus,Streptomyces sp. CdTB01,Streptomyces sp. NBC 01450,Streptomyces sp. WY228,Streptomyces sp. NBC 01281,Streptomyces sp. S8,Streptomyces sp. CCM MD2014,Streptomyces sp. NBC 00316,Streptomyces sp. AM2-3-1,Streptomyces sp. HUAS YS2,Streptomyces sp. GMY02,Streptomyces sp. S1D4-20,Streptomyces lunaelactis,Streptomyces halobius,Streptomyces parvulus,Streptomyces sviceus,Streptomyces profundus,Streptomyces nojiriensis,Streptomyces thermocarboxydus,Streptomyces fagopyri,Streptomyces venezuelae,Streptomyces ambofaciens,Streptomyces mobaraensis,Streptomyces murinus,Streptomyces nitrosporeus,Streptomyces hygroscopicus,Streptomyces cyaneogriseus,Streptomyces sp. NBC 00536,Streptomyces sp. FR-008,Streptomyces sp. S1A1-8,Streptomyces sp. NBC 01717,Streptomyces sp. SCA4-21,Streptomyces sp. M92,Streptomyces sp. BPTC-684,Streptomyces sp. NBC 00344,Streptomyces sp. N50,Streptomyces sp. Li-HN-5-11,Streptomyces sp. SAT1,Streptomyces sp. 3214.6,Streptomyces sp. Tu 2975,Streptomyces sp. NEAU-S7GS2,Streptomyces sp. NBC 01244,Streptomyces sp. RerS4,Streptomyces sp. AM8-1-1,Streptomyces sp. T12,Streptomyces aurantiacus,Streptomyces caniscabiei,Streptomyces glaucescens,Streptomyces leeuwenhoekii,Streptomyces nodosus,Streptomyces albidoflavus,Streptomyces sudanensis,Streptomyces sp. NBC 00690,Streptomyces sp. CB01881,Streptomyces sp. MMBL 11-1,Streptomyces sp. FXY-T5,Streptomyces sp. NBC 00287,Streptomyces sp. AgN23,Streptomyces sp. CB00271,Streptomyces sp. JB150,Streptomyces sp. HNA39,Streptomyces sp. HUAS CX7,Streptomyces sp. ICC4,Streptomyces sp. ICC1,Streptomyces armeniacus,Hoyosella subflava,Lawsonella clevelandensis,Tomitella fengzijianii,Tsukamurella pulmonis,Dietzia timorensis,Dietzia kunjamensis,Segniliparus rotundus,Skermania piniformis,Gordonia mangrovi,Gordonia otitidis,Gordonia jinghuaiqii,Gordonia iterans,Gordonia hydrophobica,Gordonia malaquae,Gordonia sp. PP30,Gordonia sp. YC-JH1,Gordonia sp. PDNC005,Gordonia sp. X0973,Gordonia zhaorongruii,Gordonia sp. w5E2,Gordonia pseudamarae,Gordonia polyisoprenivorans,Corynebacterium testudinoris,Corynebacterium sp. BD556,Corynebacterium mustelae,Corynebacterium occultum,Corynebacterium amycolatum,Corynebacterium zhongnanshanii,Corynebacterium macginleyi,Corynebacterium felinum,Corynebacterium freneyi,Corynebacterium endometrii,Corynebacterium hansenii,Corynebacterium pseudopelargi,Corynebacterium heidelbergense,Corynebacterium propinquum,Corynebacterium cyclohexanicum,Corynebacterium ureicelerivorans,Corynebacterium accolens,Corynebacterium kefirresidentii,Corynebacterium capitovis,Corynebacterium confusum,Corynebacterium afermentans,Corynebacterium renale,Corynebacterium pseudokroppenstedtii,Corynebacterium aurimucosum,Corynebacterium atrinae,Corynebacterium callunae,Corynebacterium coyleae,Corynebacterium poyangense,Corynebacterium frankenforstense,Corynebacterium humireducens,Corynebacterium hindlerae,Corynebacterium canis,Corynebacterium aquilae,Corynebacterium doosanense,Corynebacterium argentoratense,Corynebacterium sp. sy039,Corynebacterium crudilactis,Corynebacterium variabile,Corynebacterium comes,Corynebacterium kalinowskii,Corynebacterium tuberculostearicum,Corynebacterium urogenitale,Corynebacterium jeddahense,Corynebacterium phocae,Corynebacterium xerosis,Corynebacterium hesseae,Corynebacterium vitaeruminis,Corynebacterium sphenisci,Corynebacterium yudongzhengii,Corynebacterium suedekumii,Corynebacterium pseudodiphtheriticum,Corynebacterium minutissimum,Corynebacterium auris,Corynebacterium atypicum,Corynebacterium singulare,Corynebacterium imitans,Corynebacterium uterequi,Corynebacterium terpenotabidum,Corynebacterium guangdongense,Corynebacterium appendicis,Corynebacterium cystitidis,Corynebacterium rouxii,Corynebacterium sp. CNCTC7651,Corynebacterium lujinxingii,Corynebacterium choanae,Corynebacterium breve,Corynebacterium flavescens,Corynebacterium kutscheri,Corynebacterium genitalium,Corynebacterium pseudotuberculosis,Corynebacterium stationis,Corynebacterium glucuronolyticum,Corynebacterium fournieri,Corynebacterium gerontici,Corynebacterium falsenii,Corynebacterium glyciniphilum,Corynebacterium striatum,Corynebacterium sanguinis,Corynebacterium jeikeium,Corynebacterium ciconiae,Corynebacterium caspium,Corynebacterium sp. ATCC 6931,Corynebacterium sp. SCR221107,Corynebacterium halotolerans,Corynebacterium suranareeae,Corynebacterium aquatimens,Corynebacterium timonense,Corynebacterium massiliense,Corynebacterium matruchotii,Corynebacterium glutamicum,Corynebacterium ulcerans,Corynebacterium kroppenstedtii,Corynebacterium uberis,Corynebacterium diphtheriae,Corynebacterium epidermidicanis,Corynebacterium durum,Corynebacterium incognita,Corynebacterium nuruki,Corynebacterium urealyticum,Nocardia terpenica,Nocardia seriolae,Nocardia yunnanensis,Nocardia farcinica,Nocardia brasiliensis,Nocardia sp. CS682,Nocardia asteroides,Nocardia arthritidis,Nocardia vinacea,Nocardia tengchongensis,Rhodococcus sp. ZPP,Rhodococcus pseudokoreensis,Rhodococcus antarcticus,Rhodococcus sp. X156,Rhodococcus sp. W8901,Rhodococcus aetherivorans,Rhodococcus koreensis,Rhodococcus pyridinivorans,Rhodococcus fascians,Rhodococcus rhodochrous,Rhodococcus sp. WAY2,Rhodococcus erythropolis,Rhodococcus sp. Z13,Rhodococcus sp. USK10,Rhodococcus sp. DMF-1,Rhodococcus sp. WMMA185,Rhodococcus sovatensis,Rhodococcus ruber,Rhodococcus sp. MTM3W5.2,Rhodococcus sp. ABRD24,Rhodococcus qingshengii,Rhodococcus opacus,Prescottella equi,Mycolicibacter hiberniae,Mycobacteroides salmoniphilum,Mycobacteroides abscessus,Mycobacterium xenopi,Mycobacterium gordonae,Mycobacterium basiliense,Mycobacterium sp. ITM-2016-00318,Mycobacterium sp. Aquia 213,Mycobacterium heckeshornense,Mycobacterium sp. ELW1,Mycobacterium parmense,Mycobacterium sp. MS1601,Mycobacterium marseillense,Mycobacterium intracellulare,Mycobacterium branderi,Mycobacterium sp. Z3061,Mycobacterium sp. ITM-2016-00317,Mycobacterium kansasii,Mycobacterium noviomagense,Mycobacterium vicinigordonae,Mycobacterium malmoense,Mycobacterium lepromatosis,Mycobacterium heidelbergense,Mycobacterium tuberculosis,Mycobacterium avium,Mycolicibacterium mucogenicum,Mycolicibacterium gadium,Mycolicibacterium anyangense,Mycolicibacterium phocaicum,Mycolicibacterium aubagnense,Mycolicibacterium neoaurum,Mycolicibacterium moriokaense,Mycolicibacterium rufum,Mycolicibacterium sp. MU0050,Mycolicibacterium rutilum,Mycolicibacterium aichiense,Mycolicibacterium brumae,Mycolicibacterium sp. YH-1,Mycolicibacterium litorale,Mycolicibacterium diernhoferi,Mycolicibacterium chitae,Mycolicibacterium fluoranthenivorans,Mycolicibacterium duvalii,Mycolicibacterium holsaticum,Mycolicibacterium doricum,Mycolicibacterium insubricum,Mycolicibacterium thermoresistibile,Mycolicibacterium sediminis,Mycolicibacterium austroafricanum,Candidatus Contubernalis alkalaceticus,endosymbiont 'TC1' of Trimyema compressum,Limnochorda sp. L945t,Limnochorda sp. LNt,Limnochorda pilosa,Ndongobacter massiliensis,Caldicellulosiruptor danielii,Caldicellulosiruptor naganoensis,Caldicellulosiruptor morganii,Ezakiella coagulans,Ezakiella massiliensis,Sedimentibacter sp. zth1,Sedimentibacter sp. MB31-C6,Sedimentibacter sp. MB35-C1,Gottschalkia acidurici,Acidilutibacter cellobiosedens,Caloranaerobacter azorensis,Gudongella oleilytica,Tissierella sp. Yu-01,Tissierella sp. MB52-C2,Schnuerera ultunensis,Keratinibaculum paraultunense,Parvimonas micra,Finegoldia magna,Murdochiella vaginalis,Helcococcus ovis,Miniphocaeibacter halophilus,Anaerococcus prevotii,Anaerococcus mediterraneensis,Anaerococcus sp. Marseille-Q7828,Peptoniphilus harei,Peptonophilus genitalis,Peptoniphilus equinus,Peptoniphilus ivorii,Dialister succinatiphilus,Dialister pneumosintes,Veillonella parvula,Veillonella nakazawae,Veillonella rogosae,Megasphaera hexanoica,Megasphaera elsdenii,Megasphaera massiliensis,Megasphaera stantonii,Phascolarctobacterium faecium,Phascolarctobacterium succinatutens,Acidaminococcus fermentans,uncultured Anaeromusa sp.,Pelosinus sp. UFO1,Pelosinus fermentans,Methylomusa anaerophila,uncultured Sporomusa sp.,Sporomusa ovata,Sporomusa termitida,Pectinatus frisingensis,Selenobaculum gbiensis,Megamonas hypermegale,Megamonas funiformis,Selenomonas timonae,Selenomonas dianae,Selenomonas sp. oral taxon 136,Selenomonas sp. TAMA-11512,Selenomonas ruminantium,Selenomonas sputigena,Turicibacter sanguinis,Turicibacter bilis,Turicibacter sp. H121,Turicibacter faecis,Tannockella kyphosi,Erysipelatoclostridium sp. An173,Thomasclavelia ramosa,Thomasclavelia spiroformis,Faecalibacillus intestinalis,Catenibacterium mitsuokai,Catenibacterium sp. co 0103,Longicatena caecimuris,Faecalibaculum rodentium,Amedibacterium intestinale,Bulleidia sp. zg-1006,[Clostridium] innocuum,Allocoprobacillus halotolerans,Allobaculum sp. Allo2,Allobaculum mucilyticum,Intestinibaculum porci,Erysipelothrix sp. P66,Erysipelothrix inopinata,Erysipelothrix piscisicarius,Erysipelothrix sp. HDW6C,Erysipelothrix sp. HDW6A,Erysipelothrix rhusiopathiae,Erysipelothrix larvae,Solobacterium moorei,Christensenella minuta,Koleobacter methoxysyntrophicus,Helicovermis profundi,Thermosediminibacter oceani,Tepidanaerobacter acetatoxydans,Biomaibacter acetigenes,Halothermothrix orenii,Anoxybacter fermentans,Halocella sp. SP3-1,Halanaerobium hydrogeniformans,Halanaerobium praevalens,Halobacteroides halobius,Acetohalobium arabaticum,Monoglobus pectinilyticus,Thermanaeromonas toyohensis,Moorella humiferrea,Moorella thermoacetica,Moorella sp. Hama-1,Zhaonella formicivorans,Natranaerofaba carboxydovora,Natranaerobius thermophilus,Mahella australiensis,Caldanaerobacter subterraneus,Aceticella autotrophica,Gelria sp. Kuro-4,Thermacetogenium phaeum,Ammonifex degensii,Thermoanaerobacterium xylanolyticum,Thermoanaerobacterium saccharolyticum,Thermoanaerobacterium sp. CMT5567-10,Thermoanaerobacterium sp. RBIITD,Thermoanaerobacterium thermosaccharolyticum,Thermoanaerobacter wiegelii,Thermoanaerobacter siderophilus,Thermoanaerobacter kivui,Carboxydothermus hydrogenoformans,Anaerotignum propionicum,Anaerotignum sp. MB30-C6,Defluviitalea saccharophila,Petrocella atlantisensis,Vallitalea guaymasensis,Vallitalea pronyensis,Cellulosilyticum sp. WCF-2,Cellulosilyticum lentocellum,Wujia chipingensis,Wansuia hejianensis,Herbinix luporum,Anaeromicropila herbilytica,[Clostridium] colinum,Anaerocolumna sp. MB42-C2,Stomatobaculum sp. F0698,Chordicoccus furentiruminis,Dorea longicatena,Kineothrix sp. IPX-CK,Kineothrix sp. MB12-C1,Enterocloster clostridioformis,Enterocloster asparagiformis,Enterocloster bolteae,Simiaoa sunii,Claveliimonas bilis,Lacrimispora xylanolytica,Anaeropeptidivorans aminofermentans,Anaerobutyricum hallii,Pseudobutyrivibrio xylanivorans,Butyrivibrio hungatei,Butyrivibrio crossotus,Butyrivibrio proteoclasticus,Roseburia sp. 831b,Roseburia intestinalis,Roseburia hominis,Roseburia sp. 499,Lachnoanaerobaculum umeaense,Lachnoclostridium phocaeense,[Clostridium] scindens,Lachnoclostridium phytofermentans,[Clostridium] hylemonae,Marvinbryantia formatexigens,Coprococcus eutactus,Coprococcus sp. ART55/1,Coprococcus comes,Coprococcus catus,Lachnospira eligens,Qiania dongpingensis,Anaerostipes rhamnosivorans,Anaerostipes hadrus,Anaerostipes sp. PC18,Anaerostipes caccae,Candidatus Epulonipiscium viviparus,Chakrabartyella piscis,Blautia luti,Blautia wexlerae,Blautia obeum,Blautia argi,Blautia pseudococcoides,Blautia sp. SC05B48,[Ruminococcus] lactaris,[Ruminococcus] torques,Mediterraneibacter gnavus,Geosporobacter ferrireducens,Caminicella sporogenes,Aminipila terrae,Aminipila butyrica,Emergencia timonensis,Emergencia sp. JLR.KK010,Acetoanaerobium sticklandii,Filifactor alocis,Peptoclostridium acidaminophilum,Alkaliphilus metalliredigens,Alkaliphilus oremlandii,Alkaliphilus sp. B6464,Serpentinicella alkaliphila,Peptostreptococcus equinus,Peptacetobacter hiranonis,Terrisporobacter petrolearius,Terrisporobacter hibernicus,Tepidibacter aestuarii,Tepidibacter hydrothermalis,Intestinibacter bartlettii,Romboutsia ilealis,Romboutsia sp. CE17,Romboutsia sp. 13368,Romboutsia hominis,Clostridioides difficile,Paraclostridium bifermentans,Paraclostridium sordellii,Caproicibacter fermentans,Caproiciproducens sp. CPB-2,uncultured Caproiciproducens sp.,Carboxydocella thermautotrophica,Thermincola potens,Desulfotomaculum nigrificans,Alkalicella caledoniensis,Syntrophothermus lipocalidus,Candidatus Syntrophocurvum alkaliphilum,Syntrophomonas wolfei,Heliorestis convoluta,Heliomicrobium modesticaldum,Intestinibacillus sp. NTUH-41-i26,Agathobaculum sp. NTUH-O15-33,Desulfoscipio gibsoniae,Massilistercora timonensis,Fenollaria sporofastidiosus,Fenollaria massiliensis,Intestinimonas butyriciproducens,Sinanaerobacter sp. ZZT-01,Proteiniborus sp. MB09-C3,Maliibacterium massiliense,Aristaeella hokkaidonensis,Aristaeella lactis,Caldinitratiruptor microaerophilus,Symbiobacterium thermophilum,Thermaerobacter marianensis,Thermaerobacter sp. PB12/4term,Dehalobacterium formicoaceticum,Thermanaerosceptrum fracticalcis,Acididesulfobacillus acetoxydans,Candidatus Desulforudis audaxviator,Desulforamulus ferrireducens,Desulforamulus reducens,Desulforamulus ruminis,Candidatus Formimonas warabiya,Desulfofarcimen acetoxidans,Alkalibacter rhizosphaerae,uncultured Acetobacterium sp.,Acetobacterium woodii,Acetobacterium sp. KB-1,Acetobacterium wieringae,Eubacterium sp. MSJ-33,Eubacterium ventriosum,Eubacterium callanderi,Syntrophobotulus glycolicus,Dehalobacter sp. DCM,Desulfosporosinus orientis,Desulfosporosinus youngiae,Desulfosporosinus meridiei,Desulfitobacterium dichloroeliminans,Desulfitobacterium hafniense,Desulfitobacterium metallireducens,Desulfitobacterium dehalogenans,Lawsonibacter asaccharolyticus,Pusillibacter faecalis,uncultured Subdoligranulum sp.,Subdoligranulum variabile,Ethanoligenens harbinense,Ruthenibacterium lactatiformans,Faecalibacterium sp. I3-3-33,Faecalibacterium prausnitzii,Faecalibacterium sp. IP-3-29,Faecalibacterium sp. CYL33,Anaerotruncus colihominis,Solibaculum mannosilyticum,Thermoclostridium stercorarium,Vescimonas coprocola,Vescimonas fastidiosa,Paludicola sp. MB14-C6,Fastidiosipila sanguinis,Ruminiclostridium herbifermentans,Ruminiclostridium papyrosolvens,Oscillibacter hominis,Ruminococcus albus,Ruminococcus bicirculans (ex Wegman et al. 2014),Ruminococcus gauvreauii,Ruminococcus bovis,Ruminococcus champanellensis,Flavonifractor plautii,Caproicibacterium lactatifermentans,Caproicibacterium argilliputei,Caproicibacterium amylolyticum,Caproicibacterium sp. BJN0003,Amygdalobacter nucleatus,Amygdalobacter indicium,Mageeibacillus indolicus,Acetivibrio clariflavus,Acetivibrio saccincola,Acetivibrio thermocellus,Hungatella hathewayi,Crassaminicella indica,Crassaminicella profunda,Crassaminicella thermophila,Proteiniclasticum sp. QWL-01,Candidatus Arthromitus sp. SFB-mouse,Candidatus Arthromitus sp. SFB-mouse-NL,Candidatus Arthromitus sp. SFB-rat-Yit,Hathewaya histolytica,Oceanirhabdus sp. W0125-5,Sarcina sp. JB2,Caloramator sp. mosi 1,Caloramator sp. Dgby cultured 2,Caloramator sp. E03,Clostridium tagluense,Clostridium autoethanogenum,Clostridium sp. M62/1,Clostridium sp. C1,Clostridium cochlearium,Clostridium saccharoperbutylacetonicum,Clostridium formicaceticum,Clostridium sporogenes,Clostridium saccharobutylicum,Clostridium carboxidivorans,Clostridium sp. 16K-1-R1,Clostridium sp. MT351,Clostridium sp. DL-VIII,Clostridium sp. AWRP,Clostridium sp. MB40-C1,Clostridium sp. SY8519,Clostridium drakei,Clostridium scatologenes,Clostridium gelidum,Clostridium fermenticellae,Clostridium chauvoei,Clostridium kluyveri,Clostridium pasteurianum,Clostridium tyrobutyricum,Clostridium taeniosporum,Clostridium tetani,Clostridium argentinense,Clostridium novyi,Clostridium cellulovorans,Clostridium acetobutylicum,Clostridium gasigenes,Clostridium felsineum,Clostridium butyricum,Clostridium thermarum,Clostridium manihotivorum,Clostridium intestinale,Clostridium botulinum,Clostridium cadaveris,Clostridium sp. LQ25,Clostridium sp. OS1-26,Clostridium sp. MD294,Clostridium sp. MF28,Clostridium sp. JN-1,Clostridium sp. 'deep sea',Clostridium sp. BJN0001,Clostridium sp. JN-9,Clostridium beijerinckii,Clostridium isatidis,Clostridium perfringens,Clostridium septicum,Clostridium bornimense,Clostridium baratii,Abiotrophia defectiva,Fundicoccus culcitae,Facklamia hominis,Ignavigranum ruoffiae,Suicoccus acidiformans,Globicatella sp. PHS-GS-PNBC-21-1553,Globicatella sanguinis,Ruoffia tabacinasalis,Aerococcus loyolae,Aerococcus urinaeequi,Aerococcus sp. Group 1,Aerococcus urinae,Aerococcus mictus,Aerococcus sanguinicola,Aerococcus tenax,Aerococcus urinaehominis,Aerococcus christensenii,Aerococcus viridans,Marinilactibacillus sp. 15R,Dolosigranulum pigrum,Jeotgalibaca dankookensis,Jeotgalibaca sp. PTS2502,Jeotgalibaca sp. MA1X17-3,Jeotgalibaca ciconiae,Jeotgalibaca porci,Trichococcus flocculiformis,Trichococcus shcherbakoviae,uncultured Trichococcus sp.,Desemzia incerta,Granulicatella adiacens,Granulicatella elegans,Carnobacterium sp. CP1,Carnobacterium viridans,Carnobacterium divergens,Carnobacterium inhibens,Carnobacterium sp. 17-4,Carnobacterium maltaromaticum,Fructobacillus americanaquae,Nicoliella spurrieriana,Paucilactobacillus nenjiangensis,Paucilactobacillus oligofermentans,Paucilactobacillus hokkaidonensis,Amylolactobacillus amylophilus,Secundilactobacillus paracollinoides,Secundilactobacillus malefermentans,Lapidilactobacillus dextrinicus,Furfurilactobacillus rossiae,Schleiferilactobacillus harbinensis,Acetilactobacillus jinshanensis,Bombilactobacillus thymidiniphilus,Bombilactobacillus bombi,Bombilactobacillus folatiphilus,Periweissella cryptocerci,Apilactobacillus bombintestini,Apilactobacillus apinorum,Apilactobacillus apisilvae,Loigolactobacillus bifermentans,Loigolactobacillus coryniformis,Loigolactobacillus backii,Lentilactobacillus hilgardii,Lentilactobacillus kefiri,Lentilactobacillus laojiaonis,Lentilactobacillus buchneri,Lentilactobacillus curieae,Lentilactobacillus parabuchneri,Xylocopilactobacillus apis,Xylocopilactobacillus apicola,Oenococcus kitaharae,Oenococcus sicerae,Oenococcus oeni,Liquorilactobacillus nagelii,Liquorilactobacillus hordei,Liquorilactobacillus mali,Ligilactobacillus faecis,Ligilactobacillus saerimneri,Ligilactobacillus animalis,Ligilactobacillus cholophilus,Ligilactobacillus aviarius,Ligilactobacillus acidipiscis,Ligilactobacillus ruminis,Ligilactobacillus murinus,Ligilactobacillus agilis,Ligilactobacillus salivarius,Leuconostoc garlicum,Leuconostoc sp. LN180020,Leuconostoc citreum,Leuconostoc carnosum,Leuconostoc falkenbergense,Leuconostoc pseudomesenteroides,Leuconostoc gasicomitatum,Leuconostoc gelidum,Leuconostoc sp. MTCC 10508,Leuconostoc sp. C2,Leuconostoc mesenteroides,Leuconostoc lactis,Limosilactobacillus portuensis,Limosilactobacillus frumenti,Limosilactobacillus panis,Limosilactobacillus oris,Limosilactobacillus mucosae,Limosilactobacillus gastricus,Limosilactobacillus pontis,Limosilactobacillus vaginalis,Limosilactobacillus reuteri,Limosilactobacillus fermentum,Lactiplantibacillus argentoratensis,Lactiplantibacillus paraplantarum,Lactiplantibacillus carotarum,Lactiplantibacillus pentosus,Lactiplantibacillus plantarum,Latilactobacillus graminis,Latilactobacillus fuchuensis,Latilactobacillus curvatus,Latilactobacillus sakei,Companilactobacillus zhachilii,Companilactobacillus heilongjiangensis,Companilactobacillus farciminis,Companilactobacillus paralimentarius,Companilactobacillus ginsenosidimutans,Companilactobacillus allii,Companilactobacillus crustorum,Companilactobacillus alimentarius,Companilactobacillus futsaii,Fructilactobacillus myrtifloralis,Fructilactobacillus cliffordii,Fructilactobacillus ixorae,Fructilactobacillus carniphilus,Fructilactobacillus hinvesii,Fructilactobacillus fructivorans,Fructilactobacillus sanfranciscensis,Fructilactobacillus lindneri,Weissella tructae,Weissella koreensis,Weissella coleopterorum,Weissella viridescens,Weissella diestrammenae,Weissella soli,Weissella confusa,Weissella jogaejeotgali,Weissella paramesenteroides,Weissella ceti,Weissella cibaria,Lacticaseibacillus chiayiensis,Lacticaseibacillus sp. NCIMB 15474,Lacticaseibacillus casei,Lacticaseibacillus huelsenbergensis,Lacticaseibacillus zeae,Lacticaseibacillus pantheris,Lacticaseibacillus manihotivorans,Lacticaseibacillus pabuli,Lacticaseibacillus paracasei,Lacticaseibacillus rhamnosus,Pediococcus inopinatus,Pediococcus sp. AC40,Pediococcus claussenii,Pediococcus acidilactici,Pediococcus damnosus,Pediococcus pentosaceus,Lactobacillus taiwanensis,Lactobacillus paragasseri,Lactobacillus sp. CBA3605,Lactobacillus sp. ESL0684,Lactobacillus sp. PV034,Lactobacillus sp. ESL0680,Lactobacillus sp. ESL0700,Lactobacillus sp. JM1,Lactobacillus amylolyticus,Lactobacillus apis,Lactobacillus terrae,Lactobacillus amylovorus,Lactobacillus panisapium,Lactobacillus ultunensis,Lactobacillus kefiranofaciens,Lactobacillus xylocopicola,Lactobacillus kullabergensis,Lactobacillus acetotolerans,Lactobacillus sp. ESL0677,Lactobacillus sp. ESL0681,Lactobacillus sp. ESL0731,Lactobacillus sp. ESL0785,Lactobacillus johnsonii,Lactobacillus intestinalis,Lactobacillus iners,Lactobacillus jensenii,Lactobacillus gasseri,Lactobacillus helveticus,Lactobacillus acidophilus,Lactobacillus crispatus,Lactobacillus delbrueckii,Lactobacillus sp. IBH004,Lactobacillus sp. 3B(2020),Levilactobacillus zymae,Levilactobacillus suantsaii,Levilactobacillus brevis,Levilactobacillus namurensis,Levilactobacillus koreensis,Melissococcus plutonius,Tetragenococcus koreensis,Tetragenococcus halophilus,Tetragenococcus osmophilus,Vagococcus luciliae,Vagococcus xieshaowenii,Vagococcus teuberi,Vagococcus sp. CY52-2,Vagococcus sp. B2T-5,Vagococcus penaei,Vagococcus hydrophili,Vagococcus lutrae,Vagococcus zengguangii,Vagococcus carniphilus,Vagococcus coleopterorum,Vagococcus fluvialis,Vagococcus intermedius,Enterococcus rotai,Enterococcus saccharolyticus,Enterococcus montenegrensis,Enterococcus dispar,Enterococcus sp. CR-Ec1,Enterococcus sp. 7F3 DIV0205,Enterococcus sp. 9D6 DIV0238,Enterococcus sp. FDAARGOS 375,Enterococcus sp. DIV0849a,Enterococcus saigonensis,Enterococcus avium,Enterococcus gilvus,Enterococcus lactis,Enterococcus durans,Enterococcus casseliflavus,Enterococcus thailandicus,Enterococcus mundtii,Enterococcus raffinosus,Enterococcus hirae,Enterococcus gallinarum,Enterococcus cecorum,Enterococcus sp. DIV1094,Enterococcus sp. DIV2402,Enterococcus sp. 12C11 DIV0727,Enterococcus sp. 9E7 DIV0242,uncultured Enterococcus sp.,Enterococcus faecium,Enterococcus faecalis,Enterococcus wangshanyuanii,Floricoccus penangensis,Streptococcus sp. FSL R7-0248,Streptococcus lactarius,Streptococcus himalayensis,Streptococcus halotolerans,Streptococcus merionis,Streptococcus milleri,Streptococcus marmotae,Streptococcus uberis,Streptococcus sp. KS 6,Streptococcus sp. 29887,Streptococcus sp. Marseille-Q6470,Streptococcus australis,Streptococcus canis,Streptococcus parasanguinis,Streptococcus didelphis,Streptococcus parauberis,Streptococcus periodonticum,Streptococcus ilei,Streptococcus oriscaviae,Streptococcus lutetiensis,Streptococcus equinus,Streptococcus halichoeri,Streptococcus acidominimus,Streptococcus porcinus,Streptococcus pseudoporcinus,Streptococcus parasuis,Streptococcus pasteurianus,Streptococcus ferus,Streptococcus ratti,Streptococcus sanguinis,Streptococcus gordonii,Streptococcus sp. FDAARGOS 192,Streptococcus sp. 116-D4,Streptococcus sp. NSJ-72,Streptococcus sp. zg-86,Streptococcus sp. LPB0220,Streptococcus sp. NPS 308,Streptococcus sp. oral taxon 061,Streptococcus sp. 'group B',Streptococcus sp. FDAARGOS 521,Streptococcus constellatus,Streptococcus ruminicola,Streptococcus chenjunshii,Streptococcus mitis,Streptococcus oralis,Streptococcus urinalis,Streptococcus cristatus,Streptococcus troglodytae,Streptococcus pluranimalium,Streptococcus sp. FDAARGOS 522,Streptococcus intermedius,Streptococcus anginosus,Streptococcus respiraculi,Streptococcus pantholopis,Streptococcus sobrinus,Streptococcus suis,Streptococcus salivarius,Streptococcus iniae,Streptococcus mutans,Streptococcus pneumoniae,Streptococcus agalactiae,Streptococcus infantis,Streptococcus dysgalactiae,Streptococcus equi,Streptococcus thermophilus,Streptococcus pyogenes,Lactococcus sp. LG606,Lactococcus piscium,Lactococcus sp. LG1267,Lactococcus sp. NH2-7C,Lactococcus sp. LG1074,Lactococcus sp. bn62,Lactococcus paracarnosus,Lactococcus protaetiae,Lactococcus allomyrinae,Lactococcus raffinolactis,Lactococcus petauri,Lactococcus formosensis,Lactococcus cremoris,Lactococcus lactis,Lactococcus taiwanensis,Lactococcus garvieae,Hydrogenibacillus sp. N12,Abyssicoccus albus,Pullulanibacillus sp. KACC 23026,Sporolactobacillus terrae,Gemella sanguinis,Gemella sp. zg-570,Gemella haemolysans,Exiguobacterium sp. U13-1,Exiguobacterium alkaliphilum,Exiguobacterium aurantiacum,Exiguobacterium antarcticum,Exiguobacterium sp. PFWT01,Exiguobacterium sp. 9-2,Exiguobacterium sp. AT1b,Tumebacillus algifaecis,Tumebacillus avium,Effusibacillus dendaii,Kyrpidia spormannii,Kyrpidia tusciae,Alicyclobacillus cycloheptanicus,Alicyclobacillus sp. ALC3,Alicyclobacillus sp. SO9,Alicyclobacillus acidoterrestris,Alicyclobacillus acidocaldarius,Alicyclobacillus dauci,Alicyclobacillus sp. TC,Alicyclobacillus fastidiosus,Alicyclobacillus mengziensis,Thermoactinomyces vulgaris,Polycladomyces abyssicola,Kroppenstedtia pulmonis,Kroppenstedtia eburnea,Staphylospora marina,Novibacillus thermophilus,Laceyella sacchari,Metasolibacillus sp. FSL H7-0170,Kurthia zopfii,Kurthia sp. YJT4,Kurthia gibsonii,Paenisporosarcina sp. FSL H8-0542,Paenisporosarcina antarctica,Paenisporosarcina cavernae,Chryseomicrobium sp. FSL W7-1435,Viridibacillus sp. JNUCC-6,Ureibacillus sp. FSL K6-8385,Ureibacillus thermosphaericus,Ureibacillus thermophilus,Solibacillus sp. R5-41,Solibacillus daqui,Solibacillus sp. FSL H8-0523,Solibacillus silvestris,Planococcus rifietoensis,Planococcus halocryophilus,Planococcus antarcticus,Planococcus halotolerans,Planococcus donghaensis,Planococcus maritimus,Planococcus lenghuensis,Planococcus versutus,Planococcus glaciei,Planococcus sp. N022,Planococcus sp. 107-1,Planococcus sp. MB-3u-03,Sporosarcina sp. B2O-1,Sporosarcina sp. P33,Sporosarcina psychrophila,Sporosarcina sp. FSL K6-3508,Sporosarcina sp. 0.2-SM1T-5,Sporosarcina thermotolerans,Sporosarcina pasteurii,Sporosarcina sp. FSL W8-0480,Sporosarcina sp. Marseille-Q4063,Sporosarcina sp. Marseille-Q4943,Sporosarcina ureae,Sporosarcina sp. P37,Sporosarcina sp. PTS2304,Listeria welshimeri,Listeria newyorkensis,Listeria weihenstephanensis,Listeria ivanovii,Listeria innocua,Listeria sp. PSOL-1,Listeria seeligeri,Listeria grayi,Listeria monocytogenes,Brochothrix thermosphacta,Thermobacillus composti,Cohnella cholangitidis,Cohnella sp. LGH,Cohnella candidum,Cohnella abietis,Brevibacillus sp. WF146,Brevibacillus sp. 7WMA2,Brevibacillus parabrevis,Brevibacillus brevis,Brevibacillus choshinensis,Brevibacillus agri,Brevibacillus composti,Brevibacillus borstelensis,Brevibacillus humidisoli,Brevibacillus laterosporus,Brevibacillus sp. JNUCC-41,Brevibacillus sp. NSP2.1,Saccharibacillus brassicae,Aneurinibacillus soli,Aneurinibacillus thermoaerophilus,Aneurinibacillus sp. Ricciae BoGa-3,Aneurinibacillus uraniidurans,Paenibacillus sp. FSL H8-0548,Paenibacillus sp. PAMC21692,Paenibacillus kribbensis,Paenibacillus tritici,Paenibacillus donghaensis,Paenibacillus beijingensis,Paenibacillus sp. FSL W8-0187,Paenibacillus sp. FSL H3-0457,Paenibacillus sp. FSL H8-0079,Paenibacillus sp. FSL R5-0470,Paenibacillus sp. FSL R7-0337,Paenibacillus sp. FSL R7-0216,Paenibacillus sp. FSL P4-0081,Paenibacillus sp. FSL H7-0690,Paenibacillus lentus,Paenibacillus stellifer,Paenibacillus sp. FSL F4-0100,Paenibacillus sp. Y412MC10,Paenibacillus sp. H1-7,Paenibacillus sp. 19GGS1-52,Paenibacillus terrae,Paenibacillus sp. MBLB1832,Paenibacillus sp. FSL W7-1332,Paenibacillus sp. FSL L8-0436,Paenibacillus sp. FSL H7-0940,Paenibacillus sp. BIHB 4019,Paenibacillus graminis,Paenibacillus sp. JNUCC32,Paenibacillus sp. S02,Paenibacillus dendritiformis,Paenibacillus rhizovicinus,Paenibacillus andongensis,Paenibacillus thiaminolyticus,Paenibacillus tundrae,Paenibacillus xylanilyticus,Paenibacillus sonchi,Paenibacillus sp. JDR-2,Paenibacillus sp. IHBB 10380,Paenibacillus sp. RUD330,Paenibacillus sp. FSL R7-0163,Paenibacillus sp. JZ16,Paenibacillus sp. YPG26,Paenibacillus macerans,Paenibacillus agaridevorans,Paenibacillus alvei,Paenibacillus amylolyticus,Paenibacillus brasilensis,Paenibacillus silvisoli,Paenibacillus barcinonensis,Paenibacillus albicereus,Paenibacillus cellulosilyticus,Paenibacillus cellulositrophicus,Paenibacillus sophorae,Paenibacillus algicola,Paenibacillus tianjinensis,Paenibacillus spongiae,Paenibacillus baekrokdamisoli,Paenibacillus antarcticus,Paenibacillus aurantius,Paenibacillus albus,Paenibacillus naphthalenovorans,Paenibacillus polygoni,Paenibacillus konkukensis,Paenibacillus elgii,Paenibacillus urinalis,Paenibacillus larvae,Paenibacillus physcomitrellae,Paenibacillus sp. 32O-W,Paenibacillus sp. FSL k6-2145,Paenibacillus sp. BR1-192,Paenibacillus sp. DCT19,Paenibacillus sp. RC67,Paenibacillus sp. G2S3,Paenibacillus sp. HWE-109,Paenibacillus sp. 481,Paenibacillus sp. PK3 47,Paenibacillus sp. D2 2,Paenibacillus sp. YPD9-1,Paenibacillus sp. R14(2021),Paenibacillus sp. FSL M8-0142,Paenibacillus sp. sptzw28,Paenibacillus sp. JNUCC-31,Paenibacillus sp. FSL E2-0178,Paenibacillus sp. FSL L8-0435,Paenibacillus lycopersici,Paenibacillus chitinolyticus,Paenibacillus psychroresistens,Paenibacillus durus,Paenibacillus swuensis,Paenibacillus mucilaginosus,Paenibacillus polymyxa,Paenibacillus protaetiae,Paenibacillus sp. FSL W8-0186,Paenibacillus sp. FSL H3-0302,Paenibacillus sp. FSL R7-0345,Paenibacillus sp. CC-CFT742,Paenibacillus sp. DR312,Paenibacillus sp. SYP-B4298,Paenibacillus sp. IHB B 3084,Paenibacillus sp. FSL K6-1122,Paenibacillus sp. FSL R10-2734,Paenibacillus sp. FSL R5-0701,Paenibacillus sp. FSL K6-2441,Paenibacillus sp. FSL H7-0737,Paenibacillus sp. FSL W7-1279,Paenibacillus sp. lzh-N1,Anaerobacillus isosaccharinicus,Salisediminibacterium beveridgei,Caldibacillus thermoamylovorans,Halalkalibacter krulwichiae,Siminovitchia fortis,Pradoshia sp. D12,Caldalkalibacillus thermarum,Alkalihalophilus pseudofirmus,Ornithinibacillus sp. FSL M8-0202,Paraliobacillus zengyii,Tepidibacillus sp. LSZ-M11000,Ectobacillus sp. JY-23,Salipaludibacillus sp. LMS25,Amphibacillus xylanus,Aeribacillus sp. FSL K6-2833,Aeribacillus pallidus,Mangrovibacillus cuniculi,Paenalkalicoccus suaedae,Halalkalibacterium halodurans,Lederbergia lenta,Sutcliffiella cohnii,Sutcliffiella horikoshii,Terribacillus saccharophilus,Terribacillus goriensis,Terribacillus sp. FSL K6-0262,Terribacillus sp. DMT04,Psychrobacillus sp. AK 1817,Psychrobacillus glaciei,Parageobacillus genomosp. 1,Parageobacillus caldoxylosilyticus,Parageobacillus toebii,Parageobacillus sp. KH3-4,Parageobacillus thermoglucosidasius,Fictibacillus sp. KU28468,Fictibacillus arsenicus,Fictibacillus phosphorivorans,Mesobacillus jeotgali,Mesobacillus foraminis,Mesobacillus subterraneus,Anoxybacillus caldiproteolyticus,Anoxybacillus flavithermus,Anoxybacillus sediminis,Anoxybacillus sp. PDR2,Fervidibacillus albus,Fervidibacillus halotolerans,Pseudalkalibacillus hwajinpoensis,Gracilibacillus caseinilyticus,Gracilibacillus salinarum,Alkalihalobacillus sp. AL-G,Pontibacillus sp. ALD SL1,Pontibacillus sp. HMF3514,Pontibacillus chungwhensis,Oceanobacillus iheyensis,Oceanobacillus zhaokaii,Oceanobacillus sp. FSL K6-2867,Oceanobacillus jeddahense,Oceanobacillus sp. FSL W7-1293,Oceanobacillus kimchii,Gottfriedia acidiceleris,Evansella sp. LMS18,Evansella cellulosilytica,Sediminibacillus dalangtanensis,Salimicrobium jeotgali,Domibacillus sp. DTU 2020 1001157 1 SI ALB TIR 016,Alkalicoccus halolimnae,Caldifermentibacillus hisashii,Niallia taxi,Niallia oryzisoli,Niallia circulans,Niallia sp. Man26,Niallia sp. XMNu-256,Niallia sp. RD1,Metabacillus sediminilitoris,Metabacillus sp. B2-18,Metabacillus sp. FJAT-53654,Metabacillus sp. cB07,Metabacillus litoralis,Metabacillus endolithicus,Rossellomorea marisflavi,Rossellomorea sp. KS-H15a,Halobacillus halophilus,Halobacillus salinarum,Halobacillus mangrovi,Halobacillus shinanisalinarum,Halobacillus litoralis,Radiobacillus kanasensis,Radiobacillus deserti,Shouchella lehensis,Shouchella miscanthi,Shouchella hunanensis,Shouchella clausii,Salicibibacter kimchii,Salicibibacter cibi,Salicibibacter halophilus,Salicibibacter cibarius,Neobacillus sp. FSL H8-0543,Neobacillus cucumis,Neobacillus sp. DY30,Neobacillus drentensis,Neobacillus mesonae,Neobacillus novalis,Neobacillus sp. 114,Neobacillus sp. PS3-40,Neobacillus sp. PS2-9,Neobacillus sp. OS1-32,Neobacillus sp. OS1-2,Neobacillus sp. OS1-33,Neobacillus sp. PS3-34,Neobacillus sp. PS3-12,Virgibacillus phasianinus,Virgibacillus salarius,Virgibacillus natechei,Virgibacillus necropolis,Virgibacillus halodenitrificans,Virgibacillus sp. Bac330,Virgibacillus sp. NKC19-16,Virgibacillus sp. Bac332,Virgibacillus sp. MSP4-1,Virgibacillus dokdonensis,Geobacillus genomosp. 3,Geobacillus thermocatenulatus,Geobacillus sp. JS12,Geobacillus zalihae,Geobacillus sp. E263,Geobacillus sp. GHH01,Geobacillus subterraneus,Geobacillus sp. C56-T3,Geobacillus proteiniphilus,Geobacillus thermoleovorans,Geobacillus thermodenitrificans,Lysinibacillus sp. 1 U-2021,Lysinibacillus sp. FSL L8-0126,Lysinibacillus macroides,Lysinibacillus capsici,Lysinibacillus telephonicus,Lysinibacillus fusiformis,Lysinibacillus agricola,Lysinibacillus sp. CD3-6,Lysinibacillus sp. JNUCC-52,Lysinibacillus sp. SGAir0095,Lysinibacillus sp. 2017,Lysinibacillus sp. Ag94,Lysinibacillus sphaericus,Lysinibacillus sp. FSL W7-1291,Lysinibacillus timonensis,Lentibacillus daqui,Lentibacillus amyloliquefaciens,Lentibacillus sp. CBA3610,Heyndrickxia oleronia,Heyndrickxia vini,Heyndrickxia coagulans,Allobacillus halotolerans,Priestia endophytica,Priestia filamentosa,Priestia flexa,Priestia aryabhattai,Priestia koreensis,Priestia megaterium,Cytobacillus gottheilii,Cytobacillus kochii,Cytobacillus spongiae,Cytobacillus solani,Cytobacillus pseudoceanisediminis,Cytobacillus oceanisediminis,Cytobacillus firmus,Peribacillus sp. FSL E2-0159,Peribacillus psychrosaccharolyticus,Peribacillus asahii,Peribacillus simplex,Peribacillus muralis,Peribacillus frigoritolerans,Bacillus sp. HBCD-sjtu,Bacillus sp. BD59S,Bacillus sp. N1-1,Bacillus sp. PS68,Bacillus sp. FJAT-52991,Bacillus sp. ABP14,Bacillus sp. S3,Bacillus gobiensis,Bacillus stercoris,Bacillus paramycoides,Bacillus infantis,Bacillus sp. DX3.1,Bacillus sp. FJAT-18017,Bacillus sp. FJAT-42376,Bacillus sp. DTU 2020 1000418 1 SI GHA SEK 038,Bacillus smithii,Bacillus fonticola,Bacillus aquiflavi,Bacillus methanolicus,Bacillus carboniphilus,Bacillus pumilus,Bacillus sp. ms-22,Bacillus sp. SB49,Bacillus sp. OxB-1,Bacillus sp. JNUCC-22,Bacillus sp. MT(2024),Bacillus sp. ZY-1-1,Bacillus sp. CMF12,Bacillus sp. Y1,Bacillus sp. Lzh-5,Bacillus sp. Cs-700,Bacillus sp. 1NLA3E,Bacillus sp. NSP9.1,Bacillus spizizenii,Bacillus vallismortis,Bacillus inaquosorum,Bacillus pacificus,Bacillus sp. FDAARGOS 235,Bacillus toyonensis,Bacillus tropicus,Bacillus luti,Bacillus cytotoxicus,Bacillus pseudomycoides,Bacillus haynesii,Bacillus altitudinis,Bacillus safensis,Bacillus shivajii,Bacillus sp. T3,Bacillus sp. LJBS17,Bacillus sp. RZ2MS9,Bacillus sp. HNR-4,Bacillus sp. SI2,Bacillus sp. ZHX3,Bacillus sp. FDAARGOS 527,Bacillus sp. CRB-7,Bacillus sp. 7D3,Bacillus sp. FJAT-14266,Bacillus sp. KH172YL63,Bacillus atrophaeus,Bacillus paralicheniformis,Bacillus halotolerans,Bacillus licheniformis,Bacillus subtilis,Bacillus siamensis,Bacillus amyloliquefaciens,Bacillus velezensis,Bacillus paranthracis,Bacillus mycoides,Bacillus wiedmannii,Bacillus thuringiensis,Bacillus anthracis,Bacillus cereus,Nosocomiicoccus massiliensis,Nosocomiicoccus ampullae,Macrococcus equipercicus,Macrococcus sp. IME1552,Macrococcus armenti,Macrococcoides canis,Macrococcoides caseolyticum,Jeotgalicoccus saudimassiliensis,Jeotgalicoccus sp. WY2,Jeotgalicoccus sp. ATCC 8456,Mammaliicoccus lentus,Mammaliicoccus vitulinus,Mammaliicoccus sciuri,Salinicoccus sp. Bachu38,Salinicoccus halodurans,Staphylococcus hyicus,Staphylococcus carnosus,Staphylococcus devriesei,Staphylococcus sp. IVB6246,Staphylococcus caprae,Staphylococcus schweitzeri,Staphylococcus sp. AntiMn-1,Staphylococcus edaphicus,Staphylococcus succinus,Staphylococcus agnetis,Staphylococcus kloosii,Staphylococcus xylosus,Staphylococcus schleiferi,Staphylococcus pettenkoferi,Staphylococcus saccharolyticus,Staphylococcus equorum,Staphylococcus gallinarum,Staphylococcus cohnii,Staphylococcus hsinchuensis,Staphylococcus simulans,Staphylococcus condimenti,Staphylococcus pasteuri,Staphylococcus chromogenes,Staphylococcus hominis,Staphylococcus sp. 11-B-312,Staphylococcus sp. M0911,Staphylococcus sp. IVB6240,Staphylococcus sp. IVB6181,Staphylococcus delphini,Staphylococcus casei,Staphylococcus felis,Staphylococcus auricularis,Staphylococcus arlettae,Staphylococcus nepalensis,Staphylococcus warneri,Staphylococcus capitis,Staphylococcus debuckii,Staphylococcus sp. T93,Staphylococcus sp. NRL 22/194,Staphylococcus lugdunensis,Staphylococcus argenteus,Staphylococcus saprophyticus,Staphylococcus epidermidis,Staphylococcus haemolyticus,Staphylococcus pseudintermedius,Staphylococcus aureus,Hydrogenophilus thermoluteolus,Mariprofundus ferrinatatus,Mariprofundus aestuarium,Acidithiobacillus thiooxidans,Acidithiobacillus sp. AMEEHan,Acidithiobacillus ferrivorans,Acidithiobacillus caldus,Candidatus Profftella armatura,Candidatus Profftella armatura (Diaphorina cf. continua),Candidatus Kinetoplastibacterium sorsogonicusi,Candidatus Kinetoplastibacterium desouzaii,Candidatus Nasuia deltocephalinicola,Casimicrobium huifangae,Fluviibacter phosphoraccumulans,Quatrionicoccus australiensis,Ferribacterium limneticum,Azonexus hydrophilus,Dechloromonas sp. HYN0024,Dechloromonas sp. TW-R-39-2,Dechloromonas denitrificans,Dechloromonas sp. A34,Oryzomicrobium terrae,Aromatoleum petrolei,Aromatoleum bremense,Aromatoleum aromaticum,uncultured Propionivibrio sp.,Niveibacterium sp. SC-1,Niveibacterium microcysteis,Azospira restricta,Azospira inquinata,Pseudazoarcus pumilus,Azoarcus sp. KH32C,Azoarcus olearius,Azoarcus sp. DN11,Parazoarcus communis,Pseudothauera hydrothermalis,Nitrogeniibacter aestuarii,Thauera sp. JM12B12,Thauera humireducens,Thauera sp. K11,Sulfuritalea hydrogenivorans,Rugosibacter aromaticivorans,Denitratisoma oestradiolicum,Denitratisoma sp. DHT3,Sterolibacterium denitrificans,Methyloversatilis sp. RAC08,Sulfuricystis thermophila,Sulfuricystis multivorans,Usitatibacter palustris,Usitatibacter rugosus,Sulfurimicrobium lacus,Sulfuricella denitrificans,Sulfuriferula nivalis,Sulfuriferula plumbiphila,Sulfuritortus calidifontis,Thiobacillus sp.,Thiobacillus sp. SCUT-2,Ferriphaselus amnicola,Sideroxydans sp. CL21,Sideroxydans lithotrophicus,Ferrigenium kumadai,Gallionella capsiferriformans,Candidatus Nitrotoga sp. AM1P,Nitrosospira multiformis,Nitrosomonas eutropha,Nitrosomonas sp. sh817,Nitrosomonas europaea,Nitrosomonas sp. H1 AOB3,Nitrosomonas ureae,Methyloradius palustris,Methylotenera mobilis,Methylotenera versatilis,Methylovorus glucosotrophus,Methylophilus medardicus,Methylophilus methylotrophus,Candidatus Methylopumilus rimovensis,Candidatus Methylopumilus turicensis,Ferrovum myxofaciens,Chitinibacter bivalviorum,Iodobacter ciconiae,Iodobacter fluviatilis,Chitinolyticbacter meiyuanensis,Chitiniphilus purpureus,Deefgea piscis,Chitinimonas koreensis,Chitinimonas arctica,Jeongeupia sp. HS-3,Jeongeupia sp. USM3,Silvimonas soli,Microvirgula aerodenitrificans,Aquaspirillum sp. LM1,Laribacter hongkongensis,Pseudogulbenkiania sp. NH8B,Aquitalea magnusonii,Aquitalea sp. USM4,Chromobacterium sp. IIBBL 290-4,Chromobacterium sp. Rain0013,Chromobacterium amazonense,Vogesella sp. LIG4,Vogesella sp. XCS3,Paludibacterium yongneupense,Paludibacterium paludis,Wielerella bovis,Simonsiella muelleri,Uruburuella testudinis,Conchiformibius steedae,Alysiella crassa,Eikenella corrodens,Eikenella exigua,Snodgrassella alvi,Kingella potus,Kingella denitrificans,Kingella negevensis,Kingella oralis,Aquella oligotrophica,Crenobacter cavernae,Vitreoscilla filiformis,Paralysiella testudinis,Neisseria sp. 3986,Neisseria subflava,Neisseria elongata,Neisseria sp. Dent CA1/247,Neisseria sp. oral taxon 014,Neisseria sicca,Neisseria sp. KEM232,Neisseria bacilliformis,Neisseria meningitidis,Neisseria weaveri,Neisseria lactamica,Neisseria gonorrhoeae,Eleftheria terrae,Rhizobacter sp. AJA081-3,Xylophilus sp. GOD-11R,Xylophilus rhododendri,Thiomonas intermedia,Thiomonas sp. X19,Aquabacterium sp. J223,Aquabacterium olei,Leptothrix cholodnii,Schlegelella aquatica,Caldimonas thermodepolymerans,Ideonella dechloratans,Rubrivivax gelatinosus,Sphaerotilus microaerophilus,Sphaerotilus sulfidivorans,Piscinibacter sp. XHJ-5,Piscinibacter gummiphilus,Aquincola tertiaricarbonis,Methylibium sp. Pch-M,Methylibium petroleiphilum,Inhella inkyongensis,Roseateles sp. DAIF2,Roseateles amylovorans,Mitsuaria sp. 7,uncultured Roseateles sp.,Paucibacter aquatile,Paucibacter sp. KCTC 42545,Paucibacter sediminis,Roseateles depolymerans,Turicimonas muris,Sutterella faecalis,Sutterella megalosphaeroides,Sutterella wadsworthensis,Duodenibacillus massiliensis,Candidatus Ichthyocystis hellenicum,Tepidimonas taiwanensis,Pollutimonas sp. M17,Neopusillimonas aromaticivorans,Advenella kashmirensis,Advenella mimigardefordensis,Advenella alkanexedens,Pusillimonas sp. DMV24BSW D,Kerstersia gyiorum,Pelistega ratti,Orrella marina,Orrella dioscoreae,Orrella daihaiensis,Basilea psittacipulmonis,Paenalcaligenes hominis,Paenalcaligenes faecalis,Castellaniella sp. MT123,Castellaniella defragrans,Pigmentiphaga sp. CHJ604,Pigmentiphaga aceris,Bordetella bronchiseptica,Bordetella genomosp. 8,Bordetella hinzii,Bordetella pertussis,Bordetella pseudohinzii,Bordetella bronchialis,Bordetella holmesii,Bordetella parapertussis,Achromobacter sp. ES-001,Achromobacter spanius,Achromobacter denitrificans,Achromobacter deleyi,Achromobacter insolitus,Achromobacter sp. MFA1 R4,Achromobacter xylosoxidans,Oligella urethralis,Oligella ureolytica,Alcaligenes sp. 1735tsa3,Alcaligenes sp. SDU A2,Alcaligenes aquatilis,Taylorella asinigenitalis,Taylorella equigenitalis,Noviherbaspirillum sp. UKPF54,Oxalobacter vibrioformis,Oxalobacter formigenes,Oxalobacter aliiformigenes,Collimonas fungivorans,Glaciimonas sp. PAMC28666,Candidatus Zinderia endosymbiont of Aphrophora alni,Duganella zoogloeoides,Duganella dendranthematis,Telluria mixta,Telluria beijingensis,Pseudoduganella albidiflava,Pseudoduganella plicata,Pseudoduganella sp. SL102,Pseudoduganella armeniaca,Actimicrobium sp. CCC2.4,Herbaspirillum huttiense,Herbaspirillum hiltneri,Herbaspirillum frisingense,Herbaspirillum rubrisubalbicans,Herbaspirillum seropedicae,Janthinobacterium svalbardensis,Janthinobacterium lividum,Janthinobacterium sp. 17J80-10,Janthinobacterium sp. J1-1,Rugamonas sp. DEMB1,Massilia litorea,Massilia sp. METH4,Massilia putida,Massilia forsythiae,Massilia sp. erpn,Massilia sp. MB5,Massilia sp. H6,Massilia endophytica,Massilia oculi,Massilia sp. Se16.2.3,Massilia sp. WG5,Massilia sp. NP310,Massilia sp. W12,Undibacterium parvum,Undibacterium sp. CCC3.4,Undibacterium sp. 20NA77.5,Undibacterium sp. KW1,Simplicispira suum,Hylemonella gracilis,Alicycliphilus denitrificans,Polaromonas sp. JS666,Polaromonas naphthalenivorans,Polaromonas vacuolata,Pulveribacter suum,Vandammella animalimorsus,Ramlibacter tataouinensis,Verminephrobacter eiseniae,Delftia lacustris,Delftia tsuruhatensis,Paracidovorax citrulli,Paracidovorax cattleyae,Paracidovorax avenae,Ottowia testudinis,Ottowia oryzae,Ottowia sp. oral taxon 894,Melaminivora suipulveris,Melaminivora jejuensis,Candidatus Symbiobacter mobilis,Variovorax sp. PAMC 28711,Variovorax sp. 38R,Variovorax sp. WDL1,Variovorax sp. HW608,Variovorax paradoxus,Limnohabitans sp. MORI2,Limnohabitans sp. 103DPR2,Limnohabitans sp. TEGF004,Serpentinimonas maccroryi,Serpentinimonas raichei,Acidovorax sp. T1,Acidovorax sp. HDW3,Acidovorax radicis,Acidovorax sp. DW039,Acidovorax sp. JMULE5,Acidovorax sp. KKS102,Acidovorax temperans,Diaphorobacter sp. HDW4B,Diaphorobacter sp. JS3051,Diaphorobacter sp. JS3050,Diaphorobacter limosus,Rhodoferax mekongensis,Rhodoferax koreense,Rhodoferax sediminis,Rhodoferax saidenbachensis,Rhodoferax ferrireducens,Rhodoferax sp. MIZ03,Rhodoferax sp. PAMC 29310,Rhodoferax antarcticus,Rhodoferax sp. AJA081-3,Rhodoferax sp. BAB1,Hydrogenophaga crassostreae,Hydrogenophaga sp. SL48,Hydrogenophaga sp. PBC,uncultured Hydrogenophaga sp.,Hydrogenophaga taeniospiralis,Hydrogenophaga pseudoflava,Hydrogenophaga sp. PAMC20947,Hydrogenophaga sp. NH-16,Comamonas fluminis,Comamonas sp. PR12,Comamonas serinivorans,Comamonas sp. NLF-1-9,Comamonas resistens,Comamonas endophytica,Comamonas odontotermitis,Comamonas kerstersii,Comamonas sp. B21-038,Comamonas sp. Y33R10-2,Comamonas aquatica,Comamonas terrigena,Comamonas antarctica,Comamonas testosteroni,Comamonas thiooxydans,Ephemeroptericola cinctiostellae,Trinickia violacea,Limnobacter sp. SAORIC-580,Robbsia andropogonis,Mycetohabitans endofungorum,Mycetohabitans rhizoxinica,Candidatus Vallotia tarda,Candidatus Vallotia cooleyia,Pandoraea fibrosis,Pandoraea oxalativorans,Pandoraea pulmonicola,Pandoraea pnomenusa,Lautropia mirabilis,Paraburkholderia sp. PGU19,Paraburkholderia edwinii,Paraburkholderia kururiensis,Paraburkholderia bonniea,Paraburkholderia sp. IMGN 8,Paraburkholderia acidiphila,Paraburkholderia acidisoli,Paraburkholderia megapolitana,Paraburkholderia atlantica,Paraburkholderia pallida,Paraburkholderia sp. SOS3,Paraburkholderia phenoliruptrix,Paraburkholderia fungorum,Paraburkholderia caribensis,Mycoavidus cysteinexigens,Polynucleobacter duraquae,Polynucleobacter necessarius,Ralstonia mannitolilytica,Ralstonia sp. RS647,Ralstonia pickettii,Ralstonia sp. RS642,Ralstonia sp. RRA.1,Ralstonia sp. RS650,Ralstonia pseudosolanacearum,Ralstonia solanacearum,Cupriavidus basilensis,Cupriavidus sp. P-10,Cupriavidus sp. USMAHM13,Cupriavidus sp. EM10,Cupriavidus sp. WKF15,Cupriavidus pinatubonensis,Cupriavidus cauae,Cupriavidus pauculus,Cupriavidus neocaledonicus,Cupriavidus malaysiensis,Cupriavidus campinensis,Cupriavidus necator,Cupriavidus taiwanensis,Cupriavidus oxalaticus,Cupriavidus metallidurans,Burkholderia mayonis,Burkholderia gladioli,Burkholderia pyrrocinia,Burkholderia sp. PAMC 26561,Burkholderia stabilis,Burkholderia vietnamiensis,Burkholderia territorii,Burkholderia cenocepacia,Burkholderia glumae,Burkholderia sp. FERM BP-3421,Burkholderia oklahomensis,Burkholderia pseudomallei,Burkholderia mallei,Burkholderia thailandensis,Burkholderia cepacia,Burkholderia contaminans,Burkholderia ambifaria,Burkholderia ubonensis,Burkholderia multivorans,Burkholderia dolosa,Sneathiella marina,Magnetococcus marinus,Tistrella mobilis,Alphaproteobacteria bacterium endosymbiont of Tiliacea citrago,Candidatus Puniceispirillum marinum,Hyphobacterium sp. CCMP332,Marinicauda algicola,Glycocaulis alkaliphilus,Maricaulis maris,Kordiimonas sp. SCSIO 12610,Gimibacter soli,Temperatibacter marinus,Hyphococcus flavus,Parvularcula bermudensis,Parvularcula sp. LCG005,Parvularcula sp. IMCC14364,Aquisalinus flavus,Candidatus Fonsibacter ubiquis,Candidatus Pelagibacter sp. RS40,Candidatus Pelagibacter sp. IMCC9063,Emcibacter sp.,Paremcibacter congregatus,Luteithermobacter gelatinilyticus,Pseudemcibacter aquimaris,Candidatus Viadribacter manganicus,Hirschia baltica,Hyphomonas neptunium,Hyphomonas sp. Mor2,uncultured Hyphomonas sp.,Candidatus Fokinia cryptica,Candidatus Fokinia solitaria,Candidatus Midichloria mitochondrii,Candidatus Bandiella numerosa,Candidatus Bandiella woodruffii,Candidatus Deianiraea vastatrix,Candidatus Megaera polyxenophila,Candidatus Phycorickettsia trachydisci,Candidatus Tisiphia endosymbiont of Ditula angustiorana,Candidatus Tisiphia endosymbiont of Empis tessellata,Orientia tsutsugamushi,Candidatus Sneabacter namystus,Rickettsia endosymbiont of Oedothorax gibbosus,Rickettsia australis,Rickettsia conorii,Rickettsiales endosymbiont of Stachyamoeba lipophora,Neorickettsia helminthoeca,Neorickettsia findlayensis,Neorickettsia sennetsu,Neoehrlichia mikurensis,Ehrlichia ruminantium,Ehrlichia canis,Anaplasma platys,Anaplasma ovis,Candidatus Mesenet endosymbiont of Phosphuga atrata,Candidatus Mesenet endosymbiont of Agriotes lineatus,Wolbachia endosymbiont of Folsomia candida,Wolbachia endosymbiont (group A) of Longitarsus flavicornis,Wolbachia endosymbiont of Anopheles demeilloni,Wolbachia endosymbiont (group A) of Merzomyia westermanni,Wolbachia endosymbiont of Oedothorax gibbosus,Wolbachia endosymbiont (group A) of Epagoge grotiana,Wolbachia endosymbiont of Drosophila simulans,Wolbachia endosymbiont of Chironomus riparius,Wolbachia endosymbiont (group B) of Athalia cordata,Wolbachia endosymbiont (group A) of Sympetrum striolatum,Wolbachia endosymbiont of Dirofilaria (Dirofilaria) immitis,Wolbachia endosymbiont of Drosophila pseudotakahashii,Wolbachia endosymbiont of Litomosoides sigmodontis,Wolbachia endosymbiont (group B) of Chorthippus parallelus,Wolbachia endosymbiont of Frankliniella intonsa,Wolbachia endosymbiont of Drosophila aff. chauvacae BK-2020,Wolbachia endosymbiont (group A) of Nomada hirtipes,Wolbachia endosymbiont (group A) of Anomoia purmunda,Wolbachia pipientis,Wolbachia endosymbiont of Howardula sp.,Wolbachia endosymbiont (group A) of Lasioglossum lativentre,Wolbachia endosymbiont (group A) of Icerya purchasi,Candidatus Nucleicultrix amoebiphila,endosymbiont of Acanthamoeba sp. UWC8,Candidatus Hydrogenosomobacter endosymbioticus,Candidatus Bealeia paramacronuclearis,Candidatus Cytomitobacter indipagum,Candidatus Cytomitobacter primus,Candidatus Gromoviella agglomerans,Candidatus Nesciobacter abundans,Candidatus Paracaedibacter symbiosus,Candidatus Paracaedibacter acanthamoebae,Thalassobaculum sp. OXR-137,Nisaea acidiphila,Terasakiella sp. SH-1,Haematospirillum jordaniae,Magnetospira sp. QH-2,Thalassospira indica,Thalassospira sp. SN3W,Stella humosa,Nitrospirillum viridazoti,Niveispirillum cyanobacteriorum,Indioceanicola profundi,Azospirillum sp. 412522,Azospirillum sp. TSA2s,Azospirillum lipoferum,Azospirillum baldaniorum,Elioraea tepida,Rhodospirillum centenum,Rhodospirillum rubrum,Defluviicoccus vanus,Ferrovibrio terrae,Pararhodospirillum photometricum,Candidatus Endolissoclinum faulkneri,Magnetospirillum sp. ME-1,Magnetospirillum gryphiswaldense,Rhodovastum atsumiense,Oecophyllibacter saccharovorans,Granulibacter bethesdensis,Sediminicoccus sp. KRV36,Commensalibacter melissae,Roseococcus microcysteis,Parasaccharibacter apium,Pseudoroseomonas cervicalis,Formicincola oecophyllae,Neokomagataea tanensis,Acidocella sp. MX-AZ03,Acidisoma sp. PAMC 29798,Komagataeibacter xylinus,Komagataeibacter rhaeticus,Komagataeibacter nataicola,Komagataeibacter oboediens,Entomobacter blattae,Candidatus Kirkpatrickella diaphorinae,Roseomonas gilardii,Roseomonas haemaphysalidis,Roseomonas sp. OT10,Roseomonas fluvialis,Roseomonas marmotae,Novacetimonas hansenii,Aristophania vespae,Gluconobacter oxydans,Gluconobacter albidus,Gluconobacter sphaericus,Acetobacter pasteurianus,Acetobacter ghanensis,Acetobacter oryzoeni,Acetobacter oryzifermentans,Acetobacter ascendens,Acetobacter persici,Acetobacter aceti,Acetobacter vaccinii,Pararoseomonas sp. SCSIO 73927,Sandaracinobacteroides saxicola,Sphingosinicella sp. BN140058,Sphingosinicella microcystinivorans,Porphyrobacter sp. CACIAM 03H1,Altererythrobacter sp. TH136,Altererythrobacter epoxidivorans,Qipengyuania sediminis,Qipengyuania flava,Tsuneonella amylolytica,Tsuneonella sp. CC-YZS046,Erythrobacter neustonensis,Erythrobacter sp. KY5,Erythrobacter sp.,Aurantiacibacter sp. MUD61,Pelagerythrobacter marinus,Pelagerythrobacter marensis,Sphingosinithalassobacter tenebrarum,Stakelama sp. W311,Tardibacter chloracetimidivorans,Hankyongella ginsenosidimutans,Novosphingobium pentaromativorans,Novosphingobium sp. EMRT-2,Novosphingobium resinovorum,Novosphingobium sp. RL4,Novosphingobium sp. ZN18A2,Novosphingobium humi,Novosphingobium capsulatum,Sphingobium amiense,Sphingobium chlorophenolicum,Sphingobium cloacae,Sphingobium sp. LF-16,Sphingobium indicum,Sphingobium sp. YG1,Sphingobium yanoikuyae,Sphingomicrobium sp. XHP0239,Sphingopyxis sp. GC21,uncultured Sphingopyxis sp.,Sphingopyxis sp. 113P3,Parasphingorhabdus litoris,Parasphingorhabdus halotolerans,Sphingorhabdus lutea,Sphingorhabdus lacus,Sphingomonas suaedae,Sphingomonas sp. SUN019,Sphingomonas daechungensis,Sphingomonas lacunae,Sphingomonas sanguinis,Sphingomonas sp. So64.6b,Sphingomonas sp. QA11,Sphingomonas sp. S1-29,Sphingomonas changnyeongensis,Sphingomonas koreensis,Sphingomonas sp. NIC1,Sphingomonas sp. 7/4-4,Sphingomonas profundi,Sphingomonas sp. MM-1,Sphingomonas alpina,Sphingomonas sp. NIBR02145,Sphingomonas naphthae,Sphingomonas sp. R1,Sphingomonas sp. LY54,Sphingomonas sp. CV7422,Sphingomonas sp. AAP5,Sphingomonas hankookensis,Sphingomonas melonis,Sphingomonas panacisoli,Sphingomonas endolithica,Sphingomonas sp. AP4-R1,Sphingomonas sp. NY01,Sphingomonas sp. FARSPH,Sphingomonas nostoxanthinifaciens,Sphingomonas glaciei,Sphingomonas sp. PAMC26645,Sphingomonas sp. NBWT7,Sphingomonas hengshuiensis,Sphingomonas paucimobilis,Sphingomonas sp. J315,Sphingomonas sp. Y38-1Y,Zymomonas mobilis,Terricaulis silvestris,Caulobacter sp. FWC26,Caulobacter henricii,Caulobacter vibrioides,Caulobacter sp. NIBR1757,Caulobacter sp. S6,Caulobacter flavus,Caulobacter segnis,Caulobacter mirabilis,Phenylobacterium sp. LH3H17,Phenylobacterium parvum,Brevundimonas albigilva,Brevundimonas vitisensis,Brevundimonas sp. LM2,Brevundimonas pondensis,Brevundimonas sp. PAMC22021,Brevundimonas sp. Bb-A,Brevundimonas sp. SGAir0440,Brevundimonas sp. M20,Asticcacaulis sp. DW145,Asticcacaulis excentricus,Salipiger profundus,Tateyamaria omphalii,Falsihalocynthiibacter arcticus,Thalassococcus sp. S3,Roseicyclus marinus,Thalassobacter stenotrophicus,Loktanella salsilacus,Sagittula sp. P11,Celeribacter marinus,Celeribacter indicus,Phaeobacter inhibens,Roseibacterium elongatum,Antarctobacter heliothermus,Ketogulonicigenium robustum,Leisingera sp. M523,Jannaschia sp. W003,Roseivivax marinus,Roseovarius sp. S88,Pseudosulfitobacter pseudonitzschiae,Sulfitobacter sp. DSM 110093,Sulfitobacter faviae,Sulfitobacter mediterraneus,uncultured Ruegeria sp.,Ruegeria sp. SCSIO 43209,Actibacterium sp. EMB200-NS6,Roseobacter ponti,Falsirhodobacter algicola,Tabrizicola piscis,Pontivivens ytuae,Limimaricola variabilis,Thioclava electrotropha,Paroceanicella profunda,Pelagovum pacificum,Gemmobacter fulvus,Roseicitreum antarcticum,Pseudooceanicola algae,Abyssibius alkaniclasticus,Rhodobacter capsulatus,Pseudorhodobacter turbinis,Rhodobaca barguzinensis,Rhodovulum sulfidophilum,Rhodovulum sp. P5,Yoonia vestfoldensis,Cognatishimia activa,Cereibacter azotoformans,Cereibacter sphaeroides,Amylibacter sp. IMCC11727,Parasedimentitalea psychrophila,Silicimonas algicola,Marivivens sp. JLT3646,Algicella marina,Pikeienuella piscinae,Paracoccus alcaliphilus,Paracoccus sp. S3-43,Paracoccus sp. MA,Paracoccus kondratievae,Paracoccus stylophorae,Paracoccus yeei,Paracoccus methylovorus,Paracoccus marcusii,Paracoccus contaminans,Paracoccus sp. MC1862,Paracoccus sp. TOH,Paracoccus sp. AK26,Paracoccus denitrificans,Paracoccus aerodenitrificans,Paracoccus jeotgali,Paracoccus sp. SMMA 5 TC,Kaistia sp. 32K,Chenggangzhangella methanolivorans,Methylocystis iwaonis,uncultured Pleomorphomonas sp.,Acuticoccus sp. I52.16.1,Rhodoligotrophos sp. CJ14,Phreatobacter stygius,Phreatobacter cathodiphilus,Phreatobacter aquaticus,Jiella pelagia,Aureimonas sp. AU12,Aureimonas sp. SA4125,Aurantimonas sp. HBX-1,Martelella lutilitoris,Martelella mediterranea,Kaustia mangrovi,Candidatus Phaeomarinobacter ectocarpi,Parvibaculum lavamentivorans,Anderseniella sp. Alg231-50,Bosea sp. F3-2,Bosea sp. ANAM02,Bosea sp. 685,Oricola thermophila,Roseitalea porphyridii,Breoghania sp.,Pannonibacter phragmitetus,Labrenzia sp. VG12,Stappia sp. ES.058,Stappia indica,Roseibium aggregatum,uncultured Roseibium sp.,Pseudovibrio brasiliensis,uncultured Cohaesibacter sp.,Methylovirgula sp. 4M-Z18,Methylovirgula ligni,Methylovirgula sp. HY1,Methylocella tundrae,Candidatus Filomicrobium marinum,Methyloligella sp. GL2,Methyloceanibacter sp. wino2,Rhodoplanes sp. Z2-YC6860,Hyphomicrobium sp. DMF-1,Hyphomicrobium sp. MC1,Hyphomicrobium nitrativorans,Hyphomicrobium sp. ghe19,Nitratireductor sp.,Nitratireductor sp. OM-1,Phyllobacterium sp. A18/5-2,Aquibium microcysteis,Aquibium oceanicum,Aminobacter sp. MSH1,Mesorhizobium sp. B4-1-4,Mesorhizobium sp. PAMC28654,Mesorhizobium sp. M7D.F.Ca.US.005.01.1.1,Mesorhizobium sp. INR15,Mesorhizobium sp. 113-1-2,Mesorhizobium sp. NBSH29,Mesorhizobium huakuii,Mesorhizobium sp. AA22,Mesorhizobium sp. L-2-11,Mesorhizobium sp. M6A.T.Cr.TU.016.01.1.1,Mesorhizobium terrae,Mesorhizobium japonicum,Mesorhizobium sp. AR07,Mesorhizobium sp. 8,Mesorhizobium sp. WSM4904,Mesorhizobium sp. 113-3-3,Mariluticola halotolerans,Paradevosia shaoguanensis,Pelagibacterium halotolerans,Devosia sp. YIM 151766,Devosia sp. MC521,Devosia lacusdianchii,Devosia sp. SD17-2,Devosia ginsengisoli,Devosia salina,Devosia rhodophyticola,Devosia sp. I507,Devosia sp. A16,Devosia algicola,Maritalea myrionectae,Pseudorhodoplanes sinuspersici,Candidatus Endowatersipora endosymbiont of Watersipora subatra,Terrihabitans soli,Enhydrobacter sp.,Variibacter gotjawalensis,[Pseudomonas] carboxydohydrogena,Afipia carboxidovorans,Tardiphaga alba,Rhodopseudomonas sp. P2A-2r,Rhodopseudomonas palustris,Bradyrhizobium elkanii,Bradyrhizobium lablabi,Bradyrhizobium sp. B124,Bradyrhizobium sp. NC92,Bradyrhizobium xenonodulans,Bradyrhizobium japonicum,Bradyrhizobium sp. I71,Bradyrhizobium daqingense,Bradyrhizobium guangdongense,Bradyrhizobium sp. CCBAU 53340,Bradyrhizobium yuanmingense,Bradyrhizobium erythrophlei,Bradyrhizobium sp. NP1,Bradyrhizobium sp. 62B,Bradyrhizobium prioritasuperba,Bradyrhizobium sp. CCBAU 51753,Bradyrhizobium sp. B117,Bradyrhizobium sp. WBAH23,Bradyrhizobium sp. BWA-3-5,Bradyrhizobium sp. WBOS08,Bradyrhizobium sp. Ash2021,Bradyrhizobium sp. WBAH33,Lentilitoribacter sp. Alg239-R112,Hoeflea sp. IMCC20628,Ensifer adhaerens,Peteryoungia desertarenae,Agrobacterium vaccinii,Agrobacterium vitis,Agrobacterium fabrum,Agrobacterium tumefaciens,Allorhizobium ampelinum,Shinella sp. H4-D48,Shinella zoogloeoides,Shinella sumterensis,Shinella sp. XGS7,Sinorhizobium sp. RAC02,Sinorhizobium garamanticum,Sinorhizobium fredii,Sinorhizobium meliloti,Candidatus Liberibacter americanus,Liberibacter crescens,Candidatus Liberibacter africanus,Candidatus Liberibacter solanacearum,Candidatus Liberibacter asiaticus,Pararhizobium sp. YC-54,Pararhizobium sp. IMCC21322,Pararhizobium sp. BT-229,Rhizobium sp. CC-CFT758,Rhizobium binae,Rhizobium sp. NZLR1,Rhizobium sp. SU303,Rhizobium sp. CB3090,Rhizobium johnstonii,Rhizobium lusitanum,Rhizobium rhizoryzae,Rhizobium gei,Rhizobium indicum,Rhizobium leguminosarum,Rhizobium sp. TH2,Rhizobium sp. SSA 523,Rhizobium sp. Kim5,Rhizobium sp. SL42,Rhizobium sp. BT-175,Rhizobium grahamii,Rhizobium ruizarguesonis,Pseudochrobactrum sp. Wa41.01b-1,Brucella sp. MAB-22,[Ochrobactrum] quorumnocens,Brucella canis,Brucella intermedia,Brucella ceti,Brucella melitensis,Brucella sp. 10RB9215,Brucella anthropi,Brucella abortus,Brucella sp. 458,Brucella sp. 1315,Methylorubrum extorquens,Methylorubrum populi,Methylorubrum sp. B1-46,Microvirga lotononidis,Microvirga ossetica,Microvirga thermotolerans,Microvirga terrae,Methylobacterium currus,Methylobacterium radiodurans,Methylobacterium radiotolerans,Methylobacterium sp. 391 Methyba4,Methylobacterium sp. FF17,Methylobacterium sp. XJLW,Methylobacterium aquaticum,Methylobacterium oryzae,Methylobacterium durans,Methylobacterium nodulans,Methylobacterium terrae,Methylobacterium sp. WL1,Methylobacterium organophilum,Methylobacterium indicum,Methylobacterium sp. 17Sr1-1,Bartonella sp. TP,Bartonella apihabitans,Bartonella alsatica,Bartonella quintana,Bartonella schoenbuchensis,Bartonella bovis,Bartonella harrusi,Bartonella krasnovii,Azorhizobium caulinodans,Pseudolabrys taiwanensis,Pseudolabrys sp. FHR47,Labrys sp. KNU-23,Xanthobacter dioxanivorans,Xanthobacter autotrophicus,Bathymodiolus septemdierum thioautotrophic gill symbiont,Steroidobacter denitrificans,endosymbiont of Euscepes postfasciatus,Isorropodon fossajaponicum symbiont,Candidatus Reidiella endopervernicosa,Bathymodiolus thermophilus thioautotrophic gill symbiont,Immundisolibacter cernigliae,Woeseia oceani,Thiohalobacter sp. IOR34,Salinisphaera sp. LB1,Kangiella koreensis,Kangiella geojedonensis,endosymbiont of unidentified scaly snail isolate Monju,Sinimarinibacterium sp. NLF-5-8,Flagellatimonas centrodinii,Solimonas sp. K1W22B-7,Sulfurivermis fontis,Sulfurifustis variabilis,Acidiferrobacter sp. SPIII 3,Sulfuricaulis limicola,Wohlfahrtiimonas chitiniclastica,Ignatzschineria larvae,Ignatzschineria rhizosphaerae,Dichelobacter nodosus,Suttonella sp. R2A3,Cardiobacterium hominis,Cardiobacterium sp. Marseille-Q4385,Frischella perrara,Zophobihabitans entericus,Gilliamella sp. ESL0441,Gilliamella apicola,Gilliamella apis,Gilliamella sp. B3022,Gilliamella sp. ESL0443,Gilliamella sp. ESL0405,Candidatus Comchoanobacter bicostacola,Methylomarinovum tepidoasis,Methylomarinovum caldicuralii,Methylococcus sp. EFPC2,Methylococcus geothermalis,Methylococcus capsulatus,Methylomagnum ishizawai,Methylotuvimicrobium buryatense,Methylotuvimicrobium alcaliphilum,Methylotuvimicrobium sp. KM2,Methylobacter sp. YRD-M1,Methylobacter sp. S3L5C,Methylogaea oryzae,Methylomicrobium album,Methylovulum psychrotolerans,Methylomonas rapida,Methylomonas paludis,Methylomonas rhizoryzae,Methylomonas sp. LL1,Candidatus Methylospira mobilis,Methylocaldum marinum,Methylocaldum szegediense,Cysteiniphilum sp. QT6929,Beggiatoa leptomitoformis,Thiothrix subterranea,Thiothrix winogradskyi,Candidatus Thiothrix anitrata,Thiothrix litoralis,Thiothrix lacustris,Allofrancisella frigidaquae,Allofrancisella guangzhouensis,Francisella frigiditurris,Francisella noatunensis,Francisella hispaniensis,Francisella persica,Francisella tularensis,Francisella philomiragia,Francisella orientalis,Cycloclasticus zancles,Cycloclasticus sp. PY97N,Hydrogenovibrio marinus,Hydrogenovibrio crunogenus,Methylophaga pinxianii,Methylophaga thalassica,Methylophaga frappieri,Thiosulfativibrio zosterae,Piscirickettsia salmonis,Thiosulfatimonas sediminis,Thiomicrorhabdus indica,Thiomicrorhabdus lithotrophica,Thiomicrorhabdus aquaedulcis,Thiomicrorhabdus immobilis,Thiomicrorhabdus sediminis,Thiomicrorhabdus sp.,Thiomicrospira microaerophila,Thiomicrospira cyclica,Thiomicrospira aerophila,Thiomicrospira sp. S5,Thiomicrospira sp. R3,Halioglobus japonicus,Halioglobus maricola,Congregibacter litoralis,Kineobactrum salinum,Candidatus Paraluminiphilus aquimaris,Aequoribacter fuscus,Oceanicoccus sagamiensis,Spongiibacter sp. IMCC21906,Spongiibacter nanhainus,Spongiibacter taiwanensis,Microbulbifer agarilyticus,Microbulbifer bruguierae,Microbulbifer sp. SH-1,Microbulbifer celer,Microbulbifer sp. MLAF003,Microbulbifer sp. YPW1,Microbulbifer sp. MI-G,Microbulbifer thermotolerans,Microbulbifer elongatus,Microbulbifer sp. ALW1,Agarilytica rhodophyticola,Saccharophagus degradans,Teredinibacter purpureus,Teredinibacter turnerae,Teredinibacter haidensis,Teredinibacter sp. KSP-S5-2,Gilvimarinus sp. DA14,Simiduia agarivorans,Simiduia sp. 21SJ11W-1,Cellvibrio sp. KY-GH-1,Cellvibrio sp. KY-YJ-3,Cellvibrio sp. PSBB006,Cellvibrio japonicus,Marinimicrobium sp. C6131,Marinagarivorans cellulosilyticus,Fluoribacter dumoffii,Legionella sp. MW5194,Legionella fallonii,Legionella clemsonensis,Legionella adelaidensis,Legionella cardiaca,Legionella spiritensis,Legionella sainthelensi,Legionella waltersii,Legionella israelensis,Legionella anisa,Legionella antarctica,Candidatus Legionella polyplacis,Legionella longbeachae,Legionella geestiana,Legionella oakridgensis,Legionella lansingensis,Legionella lytica,Legionella pneumophila,Coxiella-like endosymbiont,Rickettsiella endosymbiont of Miltochrista miniata,Candidatus Rickettsiella viridis,Aquicella lusitana,Aquicella siphonis,Candidatus Coxiella mudrowiae,Coxiella endosymbiont of Dermacentor marginatus,Coxiella endosymbiont of Amblyomma nuttalli,Coxiella endosymbiont of Amblyomma sculptum,Coxiella burnetii,Candidatus Thioglobus autotrophicus,Candidatus Thioglobus sp. NP1,Candidatus Azoamicus ciliaticola,endosymbiont of Pachyrhynchus infernalis,endosymbiont of Sipalinus gigas,Candidatus Nardonella dryophthoridicola,Candidatus Steffania adelgidicola,Candidatus Vondammii sp. HM W22,Candidatus Ruthia endofausta,Candidatus Vesicomyosocius okutanii,Candidatus Palibaumannia cicadellinicola,Celerinatantimonas diazotrophica,Succinivibrio dextrinosolvens,Oceanimonas sp. AH20CE76,Oceanimonas sp. GK1,Oceanimonas pelagia,Dongshaea marina,Oceanisphaera profunda,Oceanisphaera sp. IT1-181,Oceanisphaera avium,Zobellella denitrificans,uncultured Tolumonas sp.,Tolumonas auensis,Aeromonas allosaccharophila,Aeromonas rivuli,Aeromonas sp. FDAARGOS 1411,Aeromonas sp. FDAARGOS 1409,Aeromonas sp. FDAARGOS 1410,Aeromonas sp. FDAARGOS 1417,Aeromonas sp. FDAARGOS 1416,Aeromonas sp. FDAARGOS 1407,Aeromonas sp. FDAARGOS 1403,Aeromonas sp. FDAARGOS 1406,Aeromonas sp. FDAARGOS 1419,Aeromonas sp. FDAARGOS 1415,Aeromonas sp. CU5,Aeromonas sp. ASNIH4,Aeromonas sp. FDAARGOS 1418,Aeromonas rivipollensis,Aeromonas encheleia,Aeromonas sp. CA23,Aeromonas sp. ASNIH2,Aeromonas sp. WP2-W18-CRE-05,Aeromonas simiae,Aeromonas jandaei,Aeromonas enteropelogenes,Aeromonas media,Aeromonas sp. FDAARGOS 1414,Aeromonas sp. ASNIH1,Aeromonas sp. FDAARGOS 1404,Aeromonas sp. 2692-1,Aeromonas schubertii,Aeromonas salmonicida,Aeromonas veronii,Aeromonas dhakensis,Aeromonas hydrophila,Aeromonas caviae,Pleionea sp. HL-JVS1,Oleiphilus messinensis,Spartinivicinus ruber,Gynuella sunshinyii,Saccharospirillum mangrovi,Reinekea forsetii,Litorivicinus lipolyticus,Alloalcanivorax xenomutans,Alcanivorax sp. NBRC 101098,Alcanivorax sp.,Isoalcanivorax pacificus,Hahella sp. KA22,Hahella sp. HNIBRBA332,Hahella chejuensis,Endozoicomonas sp. SCSIO W0465,Endozoicomonas sp. 8E,Endozoicomonas sp. GU-1,Endozoicomonas sp. 4G,Endozoicomonas montiporae,Endozoicomonas euniceicola,Bacterioplanoides sp. SCSIO 12839,Aliamphritea ceti,Aliamphritea spongicola,Thalassolituus hydrocarboniclasticus,Thalassolituus oleivorans,Marinobacterium aestuarii,Marinobacterium rhizophilum,Marinobacterium sediminicola,Marinobacterium iners,Marinobacterium sp. LSUCC0821,Bacterioplanes sanyensis,uncultured Amphritea sp.,Amphritea atlantica,Amphritea japonica,Neptuniibacter halophilus,Bermanella marisrubri,Marinomonas profundi,Marinomonas posidonica,Marinomonas mediterranea,Marinomonas sp. FW-1,Marinomonas rhizomae,Marinomonas pontica,Marinomonas primoryensis,Marinomonas sp. GJ51-6,Marinomonas algicola,Venatoribacter cucullus,Nitrincola iocasae,Neptunomonas japonica,Neptunomonas concharum,Neptunomonas phycophila,Salinicola sp. LHM,Salinicola lusitanus,Salinicola tamaricis,Chromohalobacter canadensis,Zymobacter palmae,Kushneria konosiri,Kushneria phosphatilytica,Cobetia sp. ICG0124,Cobetia sp. cqz5-12,Cobetia sp. L2A1,Pistricoccus aurantiacus,Halotalea alkalilenta,Candidatus Portiera aleyrodidarum,Candidatus Carsonella ruddii,Vreelandella venusta,Vreelandella subglaciescola,Vreelandella profundi,Halomonas sp. YLGW01,Halomonas sp. A40-4,Halomonas sp. 1513,Halomonas qaidamensis,Halomonas chromatireducens,Halomonas sp. GD1P12,Halomonas sp. 18071143,Halomonas sp. KO116,Halomonas sp. CKK8,Halomonas sp. MS1,Halomonas sp. Y3,Halomonas sp. M4R1S46,Halomonas binhaiensis,Halomonas aestuarii,Halomonas sp. DN3,Halomonas sp. THAF12,Halomonas sp. M1,Halomonas sp. ZZQ-149,Halomonas sp. A020,Halomonas sp. JS92-SW72,Halomonas piscis,Halomonas alkalicola,Halomonas beimenensis,Halomonas meridiana,Halomonas elongata,Halomonas sp. FeN2,Halomonas hydrothermalis,Aquirhabdus parva,Moraxella bovis,Moraxella canis,Moraxella ovis,Moraxella bovoculi,Moraxella cuniculi,Moraxella sp. FZFQ2102,Moraxella nonliquefaciens,Moraxella nasovis,Moraxella nasibovis,Moraxella catarrhalis,Moraxella haemolytica,Moraxella sp. ZY210820,Moraxella lincolnii,Moraxella osloensis,Psychrobacter sp. LV10R520-6,Psychrobacter sp. 28M-43,Psychrobacter urativorans,Psychrobacter cryohalolentis,Psychrobacter raelei,Psychrobacter sp. van23A,Psychrobacter sp. M13,Psychrobacter sp. WY6,Psychrobacter sp. KH172YL61,Acinetobacter dispersus,Acinetobacter chinensis,Acinetobacter sp. SWBY1,Acinetobacter proteolyticus,Acinetobacter sp. XS-4,Acinetobacter sp. A22,Acinetobacter sp. SCLZS86,Acinetobacter piscicola,Acinetobacter wuhouensis,Acinetobacter cumulans,Acinetobacter bouvetii,Acinetobacter soli,Acinetobacter bereziniae,Acinetobacter variabilis,Acinetobacter sp. SAAs470,Acinetobacter sp. TTH0-4,Acinetobacter sp. Colony158,Acinetobacter sp. YH16056 T,Acinetobacter sp. NCu2D-2,Acinetobacter sp. NEB 394,Acinetobacter sp. FDAARGOS 560,Acinetobacter colistiniresistens,Acinetobacter sp. F9,Acinetobacter baylyi,Acinetobacter larvae,Acinetobacter radioresistens,Acinetobacter junii,Acinetobacter schindleri,Acinetobacter lanii,Acinetobacter wanghuae,Acinetobacter ursingii,Acinetobacter shaoyimingii,Acinetobacter sp. NyZ410,Acinetobacter sp. FDAARGOS 724,Acinetobacter sp. WCHAc010034,Acinetobacter sp. ACNIH1,Acinetobacter sp. KCTC 92772,Acinetobacter sp. 10FS3-1,Acinetobacter sp. ESL0695,Acinetobacter nosocomialis,Acinetobacter guillouiae,Acinetobacter haemolyticus,Acinetobacter johnsonii,Acinetobacter venetianus,Acinetobacter lwoffii,Acinetobacter indicus,Acinetobacter sp. LoGeW2-3,Acinetobacter sp. Marseille-Q1620,Acinetobacter sp. MYb10,Acinetobacter sp. D009,Acinetobacter sp. AOR07 HL,Acinetobacter towneri,Acinetobacter seifertii,Acinetobacter calcoaceticus,Acinetobacter pittii,Acinetobacter baumannii,Ferrimonas sp. SCSIO 43195,Ferrimonas lipolytica,Ferrimonas sp. YFM,Ferrimonas balearica,Litorilituus sediminis,Thalassotalea sp. LPB0316,Thalassotalea sediminis,Thalassotalea crassostreae,Thalassotalea atypica,Thalassotalea sp. HSM 43,Thalassotalea sp. PS06,Thalassotalea hakodatensis,Thalassotalea piscium,Thalassomonas haliotis,Thalassomonas viridans,Colwellia sp. PAMC 20917,Colwellia psychrerythraea,Colwellia sp. 20A7,Colwellia sp. Arc7-D,Colwellia sp. MT41,Colwellia sp. Arc7-635,Colwellia sp. M166,Psychromonas sp. CNPT3,Psychromonas ingrahamii,Moritella sp. 5,Moritella yayanosii,Moritella sp. 36,Moritella sp. 24,Moritella sp. 28,Moritella marina,Aliiglaciecola sp. LCG003,Glaciecola nitratireducens,Planctobacterium marinum,Alkalimarinus alittae,Alkalimarinus sediminis,Paraneptunicella aestuarii,Hydrocarboniclastica marina,Saliniradius amylolyticus,Paraglaciecola mesophila,Paraglaciecola psychrophila,Paraglaciecola sp. L1A13,Paraglaciecola sp. L3A3,Lacimicrobium alkaliphilum,Agarivorans sp. TSD2052,Agarivorans aestuarii,Agarivorans gilvus,Agarivorans albus,Saccharobesus litoralis,Catenovulum adriaticum,Catenovulum sediminis,Salinimonas sediminis,Salinimonas lutimaris,Salinimonas iocasae,Salinimonas marina,Alteromonas stellipolaris,Alteromonas pelagimontana,Alteromonas gracilis,Alteromonas mediterranea,Alteromonas sp. 009811495,Alteromonas sp. B31-7,Alteromonas sp. M12,Alteromonas australica,Alteromonas macleodii,Alteromonas sp. LMIT006,Alteromonas sp. KC14,Alteromonas sp. RKMC-009,Pseudidiomarina andamanensis,Idiomarina piscisalsi,Idiomarina sp. OXR-189,Idiomarina sp. OT37-5b,Idiomarina sp. PL1-037,Idiomarina sp. X4,Idiomarina abyssalis,Idiomarina loihiensis,Idiomarina sp.,Psychrosphaera ytuae,Psychrosphaera aestuarii,Flocculibacter collagenilyticus,Pseudoalteromonas sp. R3,Pseudoalteromonas arctica,Pseudoalteromonas sp. A22,Pseudoalteromonas mariniglutinosa,Pseudoalteromonas sp. KG3,Pseudoalteromonas shioyasakiensis,Pseudoalteromonas ruthenica,Pseudoalteromonas spongiae,Pseudoalteromonas viridis,Pseudoalteromonas undina,Pseudoalteromonas rhizosphaerae,Pseudoalteromonas agarivorans,Pseudoalteromonas carrageenovora,Pseudoalteromonas sp. SCSIO 43088,Pseudoalteromonas marina,Pseudoalteromonas issachenkonii,Pseudoalteromonas luteoviolacea,Pseudoalteromonas ulvae,Pseudoalteromonas prydzensis,Pseudoalteromonas sp. Xi13,Pseudoalteromonas sp. SCSIO 43101,Pseudoalteromonas sp. HL-AS2,Pseudoalteromonas sp. A25,Pseudoalteromonas sp. H100,Pseudoalteromonas sp. MT33b,Pseudoalteromonas donghaensis,Pseudoalteromonas piratica,Pseudoalteromonas rubra,Pseudoalteromonas nigrifaciens,Pseudoalteromonas phenolica,Pseudoalteromonas espejiana,Pseudoalteromonas xiamenensis,Pseudoalteromonas piscicida,Pseudoalteromonas sp. Scap06,Pseudoalteromonas sp. LC2018020214,Pseudoalteromonas sp. 3J6,Pseudoalteromonas sp. A41-2,Pseudoalteromonas sp. 1 2015MBL MicDiv,Pseudoalteromonas sp. Scap25,Parashewanella tropica,Parashewanella spongiae,Shewanella psychropiezotolerans,Shewanella polaris,Shewanella acanthi,Shewanella frigidimarina,Shewanella cyperi,Shewanella violacea,Shewanella marisflavi,Shewanella khirikhana,Shewanella sedimentimangrovi,Shewanella aestuarii,Shewanella benthica,uncultured Shewanella sp.,Shewanella carassii,Shewanella sediminis,Shewanella mangrovisoli,Shewanella sp. NFH-SH190041,Shewanella sp. SNU WT4,Shewanella decolorationis,Shewanella psychromarinicola,Shewanella pealeana,Shewanella sp. FDAARGOS 354,Shewanella sp. YLB-09,Shewanella sp. ANA-3,Shewanella algae,Shewanella oncorhynchi,Shewanella japonica,Shewanella vesiculosa,Shewanella bicestrii,Shewanella putrefaciens,Shewanella baltica,Shewanella dokdonensis,Shewanella xiamenensis,Shewanella sp. MTB7,Shewanella sp. WPAGA9,Shewanella sp. Scap07,Shewanella sp. Pdp11,Wenzhouxiangella marina,Wenzhouxiangella sp. AB-CW3,Thiosocius teredinicola,Candidatus Thiodiazotropha sp. CDECU1,Thiolapillus brandeum,Sedimenticola thiotaurini,Sedimenticola selenatireducens,Candidatus Endoriftia persephone,Guyparkeria halophila,Granulosicoccus antarcticus,Sulfuriflexus mobilis,Halothiobacillus diazotrophicus,Halothiobacillus neapolitanus,Candidatus Nitrosacidococcus tergens,Candidatus Nitrosacidococcus sp. I8,Thermochromatium tepidum,Thiocapsa bogorovii,Candidatus Nitrosoglobus terrae,Caldichromatium japonicum,Thiocystis violascens,Marichromatium purpuratum,Thiorhodovibrio litoralis,Thiorhodovibrio frisius,Thiorhodovibrio winogradskyi,Candidatus Thiodictyon syntrophicum,Nitrosococcus oceani,Nitrosococcus watsonii,Nitrosococcus wardiae,Nitrosococcus halophilus,Allochromatium vinosum,Allochromatium tepidum,Rheinheimera mangrovi,Rheinheimera sp. D18,Rheinheimera sp. MM224,Rheinheimera sp. F8,Rheinheimera sp. MMS21-TC3,Thioflavicoccus mobilis,Aquisalimonas sp. 2447,Spiribacter salinus,Spiribacter sp. 2438,Spiribacter halobius,Spiribacter curvatus,Ectothiorhodosinus mongolicus,Alkalilimnicola ehrlichii,Thioalkalivibrio nitratireducens,Thioalkalivibrio paradoxus,Thioalkalivibrio versutus,Thioalkalivibrio sulfidiphilus,Halorhodospira halophila,Halorhodospira halochloris,Acidihalobacter aeolianus,Acidihalobacter yilgarnensis,Acidihalobacter ferrooxydans,Ketobacter alkanivorans,Pseudohongiella spirulinae,Marinobacter sp. CuT6,Marinobacter sp. LV10R510-11A,Marinobacter sp. AN1,Marinobacter psychrophilus,Marinobacter fonticola,Marinobacter nanhaiticus,Marinobacter nauticus,Marinobacter salarius,Marinobacter sp. JH2,Marinobacter sp. Arc7-DN-1,Marinobacter sp. LQ44,Marinobacter sp. NP-4(2019),Marinobacter salsuginis,Marinobacter sp. CA1,Halopseudomonas sp. SMJS2,Halopseudomonas phragmitis,Pseudomonas denitrificans (nom. rej.),Halopseudomonas xinjiangensis,Halopseudomonas salegens,Halopseudomonas sabulinigri,Halopseudomonas nanhaiensis,Halopseudomonas oceani,Halopseudomonas litoralis,Stutzerimonas chloritidismutans,Stutzerimonas zhaodongensis,Stutzerimonas frequens,Stutzerimonas degradans,Stutzerimonas balearica,Stutzerimonas stutzeri,Azotobacter salinestris,Azotobacter chroococcum,Denitrificimonas caeni,Thiopseudomonas alkaliphila,Permianibacter aggregans,Entomomonas moraniae,Entomomonas sp. E2T0,Entomomonas asaccharolytica,Pseudomonas sp. IT1137,Pseudomonas salmasensis,Pseudomonas thivervalensis,Pseudomonas rhizosphaerae,Pseudomonas viciae,Pseudomonas sp. REST10,Pseudomonas sp. S09G 359,Pseudomonas sp. FP1742,Pseudomonas sp. TMP25,Pseudomonas sp. ADAK18,Pseudomonas sp. MAG733B,Pseudomonas oleovorans,Pseudomonas sp. 02C 26,Pseudomonas sp. C9-3,Pseudomonas congelans,Pseudomonas serboccidentalis,Pseudomonas hydrolytica,Pseudomonas zeae,Pseudomonas kielensis,Pseudomonas saudiphocaensis,Pseudomonas zarinae,Pseudomonas oryzihabitans,Pseudomonas sp. FP1911,Pseudomonas sp. Ost2,Pseudomonas idahonensis,Pseudomonas tructae,Pseudomonas marincola,Pseudomonas quebecensis,Pseudomonas seleniipraecipitans,Pseudomonas soli,Pseudomonas argentinensis,Pseudomonas vancouverensis,Pseudomonas paraveronii,Pseudomonas pohangensis,Pseudomonas berkeleyensis,Pseudomonas parafulva,Pseudomonas tohonis,Pseudomonas entomophila,Pseudomonas cerasi,Pseudomonas kribbensis,Pseudomonas hygromyciniae,Pseudomonas guangdongensis,Pseudomonas alkylphenolica,Pseudomonas oryzae,uncultured Pseudomonas sp.,Pseudomonas extremaustralis,Pseudomonas psychrophila,Pseudomonas xantholysinigenes,Pseudomonas cremoricolorata,Pseudomonas siliginis,Pseudomonas cavernae,Pseudomonas asturiensis,Pseudomonas coronafaciens,Pseudomonas poae,Pseudomonas extremorientalis,Pseudomonas moraviensis,Pseudomonas mosselii,Pseudomonas sp. SO81,Pseudomonas sp. OST1909,Pseudomonas sp. Tri1,Pseudomonas sp. PIA16,Pseudomonas sp. ABC1,Pseudomonas sp. B14-6,Pseudomonas sp. FP198,Pseudomonas sp. PDNC002,Pseudomonas sp. HTZ2,Pseudomonas sp. Cab53,Pseudomonas sp. phDV1,Pseudomonas sp. NY5710,Pseudomonas sp. HN8-3,Pseudomonas sp. B21-031,Pseudomonas sp. J380,Pseudomonas sp. LTR0,Pseudomonas sp. ZY71,Pseudomonas sp. URMO17WK12:I11,Pseudomonas sp. NyZ480,Pseudomonas sp. FJ2-5-13,Pseudomonas sp. B21-036,Pseudomonas sp. KU26590,Pseudomonas sp. RC3H12,Pseudomonas sp. TE3-3-F2023,Pseudomonas sp. G2-4,Pseudomonas sp. IAC-BECa141,Pseudomonas sp. AE27,Pseudomonas sp. SCB32,Pseudomonas sp. WCS374,Pseudomonas sp. PONIH3,Pseudomonas sp. CCOS 191,Pseudomonas sp. LS44,Pseudomonas sp. KNUC1026,Pseudomonas sp. FP2254,Pseudomonas sp. MM227,Pseudomonas sp. XWY-1,Pseudomonas sp. 4810-S13,Pseudomonas sp. BC42,Pseudomonas sp. Pc102,Pseudomonas sp. p1(2021b),Pseudomonas sp. NY11382,Pseudomonas sp. P8 229,Pseudomonas sp. StFLB209,Pseudomonas sp. A2,Pseudomonas sp. PS1(2021),Pseudomonas sp. FP1762,Pseudomonas sp. SWI7,Pseudomonas sp. G166,Pseudomonas sp. ATCC 13867,Pseudomonas sp. LS1212,Pseudomonas sp. 13159349,Pseudomonas sp. MM211,Pseudomonas sp. FP1740,Pseudomonas furukawaii,Pseudomonas nitroreducens,Pseudomonas paraeruginosa,Pseudomonas citronellolis,Pseudomonas alcaligenes,Pseudomonas phytophila,Pseudomonas taetrolens,Pseudomonas baltica,Pseudomonas donghuensis,Pseudomonas juntendi,Pseudomonas fragi,Pseudomonas lijiangensis,Pseudomonas monteilii,Pseudomonas sp. HR96,Pseudomonas sp. Lz4W,Pseudomonas sp. SWI36,Pseudomonas sp. SWI6,Pseudomonas sp. FSL L8-0168,Pseudomonas sp. FP2335,Pseudomonas sp. Marseille-Q3773,Pseudomonas sp. HD6515,Pseudomonas sp. St316,Pseudomonas sp. C27(2019),Pseudomonas asplenii,Pseudomonas asiatica,Pseudomonas cucumis,Pseudomonas guguanensis,Pseudomonas vanderleydeniana,Pseudomonas agarici,Pseudomonas oryziphila,Pseudomonas psychrotolerans,Candidatus Pseudomonas adelgestsugas,Pseudomonas otitidis,Pseudomonas promysalinigenes,Pseudomonas wenzhouensis,Pseudomonas lactis,Pseudomonas nunensis,Pseudomonas coleopterorum,Pseudomonas knackmussii,Pseudomonas lundensis,Pseudomonas protegens,Pseudomonas chlororaphis,Pseudomonas syringae group genomosp. 3,Pseudomonas viridiflava,Pseudomonas tremae,Pseudomonas savastanoi,Pseudomonas ficuserectae,Pseudomonas fulva,Pseudomonas sp. NY8896,Pseudomonas sp. ADPe,Pseudomonas sp. DTU 2021 1001937 2 SI NGA ILE 001,Pseudomonas sp. B21-021,Pseudomonas sp. FP2338,Pseudomonas sp. G.S.17,Pseudomonas sp. ArH3a,Pseudomonas sp. FP833,Pseudomonas sp. MPC6,Pseudomonas sp. BT-42-2,Pseudomonas sp. B21-012,Pseudomonas sp. Q1-7,Pseudomonas sp. AA-38,Pseudomonas sp. LS.1a,Pseudomonas sp. JQ170C,Pseudomonas sp. OIL-1,Pseudomonas sp. R5-89-07,Pseudomonas sp. SC3(2021),Pseudomonas sp. FP2309,Pseudomonas sp. AN-1,Pseudomonas sp. CIP-10,Pseudomonas sp. FP597,Pseudomonas sp. BSw22131,Pseudomonas sp. DR48,Pseudomonas sp. CYM-20-01,Pseudomonas sp. TCU-HL1,Pseudomonas sp. NS1(2017),Pseudomonas sp. LPH1,Pseudomonas sp. BYT-5,Pseudomonas rhodesiae,Pseudomonas mucidolens,Pseudomonas orientalis,Pseudomonas brassicacearum,Pseudomonas saxonica,Pseudomonas kermanshahensis,Pseudomonas lurida,Pseudomonas glycinae,Pseudomonas frederiksbergensis,Pseudomonas bijieensis,Pseudomonas umsongensis,Pseudomonas amygdali,Pseudomonas syringae,Pseudomonas simiae,Pseudomonas canadensis,Pseudomonas eucalypticola,Pseudomonas hefeiensis,Pseudomonas putida,Pseudomonas plecoglossicida,Pseudomonas mendocina,Pseudomonas aeruginosa,Pseudomonas sp. FP2196,Pseudomonas sp. FP2034,Pseudomonas sp. MTM4,Pseudomonas sp. FP818,Pseudomonas sp. GXZC,Pseudomonas sp. MYb193,Pseudomonas sp. FP607,Pseudomonas sp. FP215,Pseudomonas sp. F3-2,Pseudomonas sp. BIGb0427,Pseudomonas sp. MPDS,Pseudomonas sp. B21-017,Pseudomonas sp. Nvir,Pseudomonas sp. LPB4.O,Pseudomonas sp. FP603,Pseudomonas sp. FP830,Pseudomonas sp. 10S4,Pseudomonas sp. FP453,Pseudomonas sp. NIBR-H-19,Pseudomonas sp. FP1154,Pseudomonas sp. Os17,Pseudomonas sp. FP2262,Pseudomonas sp. S150,Pseudomonas sp. UW4,Pseudomonas azotoformans,Pseudomonas trivialis,Pseudomonas synxantha,Pseudomonas veronii,Pseudomonas mediterranea,Pseudomonas koreensis,Pseudomonas fluorescens,Pseudomonas marginalis,Paraphotobacterium marinum,Salinivibrio proteolyticus,Salinivibrio sp. YCSC6,Salinivibrio costicola,Salinivibrio kushneri,Candidatus Enterovibrio luxaltus,Grimontia sp. NTOU-MAR1,Grimontia kaedaensis,Grimontia hollisae,Aliivibrio fischeri,Aliivibrio salmonicida,Thaumasiovibrio subtropicus,Photobacterium sp. TLY01,Photobacterium toruni,Photobacterium sp. GJ3,Photobacterium sanguinicancri,Photobacterium profundum,Photobacterium phosphoreum,Photobacterium sp. TY1-4,Photobacterium atrarenae,Photobacterium leiognathi,Photobacterium damselae,Vibrio zhugei,Vibrio japonicus,Vibrio crassostreae,Vibrio palustris,Vibrio aphrogenes,Vibrio mediterranei,Vibrio quintilis,Vibrio sp. gvc,Vibrio pectenicida,Vibrio gangliei,Vibrio gigantis,Vibrio tritonius,Vibrio sp. 16,Vibrio sp. STUT-A16,Vibrio sp. J502,Vibrio rotiferianus,Vibrio diazotrophicus,Vibrio sp. SCSIO 43137,Vibrio sp. JC009,Vibrio sp. SCSIO 43155,Vibrio gallicus,Vibrio breoganii,Vibrio cortegadensis,Vibrio pelagius,Vibrio gallaecicus,Vibrio aerogenes,Vibrio inusitatus,Vibrio gazogenes,Vibrio casei,Vibrio splendidus,Vibrio furnissii,Vibrio celticus,Vibrio qinghaiensis,uncultured Vibrio sp.,Vibrio maritimus,Vibrio cidicii,Vibrio cincinnatiensis,Vibrio paracholerae,Vibrio sp. SCSIO 43133,Vibrio sp. SCSIO 43145,Vibrio sp. ABG19,Vibrio sp. SCSIO 43153,Vibrio sp. SCSIO 43009,Vibrio diabolicus,Vibrio echinoideorum,Vibrio rumoiensis,Vibrio aquimaris,Vibrio metschnikovii,Vibrio algicola,Vibrio mimicus,Vibrio panuliri,Vibrio coralliilyticus,Vibrio astriarenae,Vibrio porteresiae,Vibrio ruber,Vibrio spartinae,Vibrio aestuarianus,Vibrio navarrensis,Vibrio mangrovi,Vibrio anguillarum,Vibrio fluvialis,Vibrio atlanticus,Vibrio cyclitrophicus,Vibrio kanaloae,Vibrio neonatus,Vibrio ponticus,Vibrio scophthalmi,Vibrio tapetis,Vibrio ostreae,Vibrio taketomensis,Vibrio nigripulchritudo,Vibrio penaeicida,Vibrio vulnificus,Vibrio cholerae,Vibrio alfacsensis,Vibrio sp. B1ASS3,Vibrio sp. THAF190c,Vibrio sp. SCSIO 43140,Vibrio sp. SCSIO 43139,Vibrio sp. THAF191d,Vibrio sp. ED002,Vibrio sp. dhg,Vibrio sp. B1FIG11,Vibrio sp. ED004,Vibrio sp. SCSIO 43135,Vibrio sp. SS-MA-C1-2,Vibrio sp. SCSIO 43186,Vibrio sp. SCSIO 43136,Vibrio sp. B1FLJ16,Vibrio sp. THAF191c,Vibrio sp. B1REV9,Vibrio sp. Scap24,Vibrio europaeus,Vibrio tubiashii,Vibrio chagasii,Vibrio owensii,Vibrio natriegens,Vibrio alginolyticus,Vibrio campbellii,Vibrio harveyi,Vibrio parahaemolyticus,Rhodanobacter denitrificans,Rhodanobacter thiooxydans,Rhodanobacter sp. FDAARGOS 1247,Rhodanobacter sp. AS-Z3,Tahibacter amnicola,Frateuria aurantia,Frateuria soli,Frateuria edaphi,Aerosticca soli,Dokdonella koreensis,Dyella sp. GSA-30,Dyella sp. M7H15-1,Dyella sp. BiH032,Dyella telluris,Dyella sp. A6,Luteibacter aegosomatis,Luteibacter anthropi,Luteibacter flocculans,Ahniella affigens,Pseudoxanthomonas sp. SL93,Pseudoxanthomonas daejeonensis,Pseudoxanthomonas suwonensis,Arenimonas daejeonensis,Luteimonas sp. MC1572,Luteimonas granuli,Luteimonas sp. MC1750,Luteimonas sp. JM171,Thermomonas brevis,Thermomonas sp. XSG,Thermomonas paludicola,Xylella taiwanensis,Xylella fastidiosa,Lysobacter soli,Lysobacter capsici,Lysobacter avium,Lysobacter enzymogenes,Lysobacter arenosi,Lysobacter terrestris,Lysobacter solisilvae,Lysobacter antibioticus,Lysobacter sp. KIS68-7,Lysobacter oculi,Lysobacter lycopersici,Lysobacter sp. K5869,Lysobacter sp. 5GHs7-4,Pseudolysobacter antarcticus,Stenotrophomonas sp. 169,Stenotrophomonas sp. NY11291,Stenotrophomonas sp. BIO128-Bstrain,Stenotrophomonas sp. SAU14A NAIMI4 5,Stenotrophomonas geniculata,Stenotrophomonas sp. SI-NJAU-1,Stenotrophomonas pavanii,Stenotrophomonas sp. ESTM1D MKCIP4 1,Stenotrophomonas maltophilia,Stenotrophomonas indicatrix,Xanthomonas nasturtii,Xanthomonas euroxanthea,Xanthomonas hyacinthi,Xanthomonas sacchari,Xanthomonas hortorum,Xanthomonas arboricola,Xanthomonas fragariae,Xanthomonas phaseoli,Xanthomonas sp. AM6,Xanthomonas oryzae,Xanthomonas translucens,Xanthomonas campestris,Xanthomonas albilineans,Xanthomonas citri,Bibersteinia trehalosi,Frederiksenia canicola,Bisgaardia hudsonensis,Rodentibacter caecimuris,Rodentibacter haemolyticus,Vespertiliibacter pulmonis,Otariodibacter oris,Mannheimia granulomatis,Mannheimia haemolytica,Mannheimia varigena,Basfia succiniciproducens,Mergibacter septicus,Gallibacterium salpingitidis,Gallibacterium anatis,Avibacterium volantium,Avibacterium sp. 21-595,Avibacterium paragallinarum,Aggregatibacter sp. 2125159857,Aggregatibacter sp. oral taxon 513,Aggregatibacter aphrophilus,Aggregatibacter segnis,Aggregatibacter actinomycetemcomitans,Glaesserella parasuis,Actinobacillus porcitonsillarum,Actinobacillus delphinicola,Actinobacillus lignieresii,Actinobacillus pleuropneumoniae,Actinobacillus arthritidis,Actinobacillus equuli,Histophilus somni,Pasteurella atlantica,Pasteurella dagmatis,Pasteurella sp. XG20,Pasteurella skyensis,Pasteurella canis,Pasteurella multocida,Haemophilus pittmaniae,Haemophilus haemolyticus,Haemophilus parahaemolyticus,Haemophilus parainfluenzae,Haemophilus influenzae,Haemophilus ducreyi,Gallaecimonas sp. GXIMD4217,Gallaecimonas mangrovi,Gallaecimonas kandeliae,Limnobaculum parvum,Limnobaculum zhutongyuii,Leminorella richardii,Pragia fontium,Obesumbacterium proteus,Hafnia sp. CBA7124,Hafnia paralvei,Hafnia alvei,Edwardsiella hoshinae,Edwardsiella anguillarum,Edwardsiella piscicida,Edwardsiella ictaluri,Edwardsiella tarda,Sodalis glossinidius,Sodalis endosymbiont of Henestaris halophilus,Sodalis praecaptivus,Sodalis ligni,Candidatus Sodalis pierantonius,Lonsdalea britannica,Lonsdalea populi,Musicola paradisiaca,Prodigiosinella aquatilis,Brenneria goodwinii,Brenneria izadpanahii,Brenneria sp. EniD312,Brenneria rubrifaciens,Pectobacterium wasabiae,Pectobacterium colocasium,Pectobacterium sp. A5351,Pectobacterium araliae,Pectobacterium odoriferum,Pectobacterium sp. F1-1,Pectobacterium sp. 21LCBS03,Pectobacterium sp. PL64,Pectobacterium aroidearum,Pectobacterium cacticida,Pectobacterium polaris,Pectobacterium atrosepticum,Pectobacterium punjabense,Pectobacterium parvum,Pectobacterium carotovorum,Pectobacterium parmentieri,Pectobacterium brasiliense,Pectobacterium polonicum,Pectobacterium actinidiae,Pectobacterium versatile,Dickeya oryzae,Dickeya sp. NCPPB 3274,Dickeya parazeae,Dickeya poaceiphila,Dickeya solani,Dickeya aquatica,Dickeya chrysanthemi,Dickeya dianthicola,Dickeya fangzhongdai,Dickeya sp. DW 0440,Dickeya lacustris,Dickeya dadantii,Dickeya zeae,Nissabacter sp. SGAir0207,Chimaeribacter arupi,Ewingella americana,Gibbsiella quercinecans,Rouxiella chamberiensis,Rouxiella badensis,Candidatus Fukatsuia symbiotica,Candidatus Fukatsuia endosymbiont of Tuberolachnus salignus,Chania multitudinisentens,Rahnella inusitata,Rahnella aquatilis,Rahnella aceris,Rahnella bonaserana,Rahnella victoriana,Rahnella sikkimica,Yersinia canariae,Yersinia similis,Yersinia alsatica,Yersinia massiliensis,Yersinia frederiksenii,Yersinia hibernica,Yersinia rochesterensis,Yersinia aldovae,Yersinia mollaretii,Yersinia intermedia,Yersinia ruckeri,Yersinia aleksiciae,Yersinia entomophaga,Yersinia enterocolitica,Yersinia pseudotuberculosis,Yersinia pestis,Serratia sp. JKS000199,Serratia sp. 1D1416,Serratia sp. FS14,Serratia entomophila,Serratia nevei,Serratia proteamaculans,Serratia fonticola,Serratia sp. AS13,Serratia sp. K-M0706,Serratia sp. FDAARGOS 506,Serratia odorifera,Serratia rhizosphaerae,Serratia surfactantfaciens,Serratia quinivorans,Serratia plymuthica,Serratia nematodiphila,Serratia liquefaciens,Serratia rubidaea,Serratia marcescens,Serratia ureilytica,Serratia sp. P2ACOL2,Serratia sp. UGAL515B 01,Serratia sp. FGI94,Serratia sp. JUb9,Serratia sp. MYb239,Serratia sp. 3ACOL1,Serratia sp. CMO1,Serratia symbiotica,Winslowiella toletana,Wigglesworthia glossinidia,Duffyella gerundensis,Mixta gaviniae,Mixta hanseatica,Mixta calida,Mixta intestinalis,Buchnera aphidicola,Tatumella citrea,Tatumella ptyseos,Pantoea sp. SS70,Pantoea phytobeneficialis,Pantoea rwandensis,Pantoea sp. Lij88,Pantoea alfalfae,Pantoea cypripedii,Pantoea sp. SO10,Pantoea soli,Pantoea deleyi,Pantoea alhagi,Pantoea sp. CCBC3-3-1,Pantoea sp. BRR-3P,Pantoea sp. JZ29,Pantoea sp. SOD02,Pantoea anthophila,Pantoea eucalypti,Pantoea piersonii,Pantoea eucrina,Pantoea vagans,Candidatus Pantoea carbekii,Pantoea dispersa,Pantoea ananatis,Pantoea agglomerans,Pantoea sp. SM3640,Pantoea sp. Z09,Pantoea sp. JZ2,Pantoea sp. X85,Pantoea sp. At-9b,Pantoea stewartii,Erwinia sp. E sp W01 1,Erwinia persicina,Erwinia rhapontici,Erwinia tasmaniensis,Erwinia billingiae,Erwinia pyri,Erwinia sorbitola,[Pantoea] beijingensis,Erwinia aphidicola,Erwinia amylovora,Candidatus Erwinia haradaeae,Erwinia pyrifoliae,Erwinia sp. HDF1-3R,Erwinia sp. Ejp617,Erwinia sp. E sp W01 6,Erwinia sp. E602,Erwinia tracheiphila,Moellerella wisconsensis,Candidatus Arsenophonus lipoptenae,Arsenophonus apicola,Arsenophonus nasoniae,Arsenophonus endosymbiont of Aphis craccivora,Arsenophonus endosymbiont of Aleurodicus dispersus,Arsenophonus sp. aPb,Arsenophonus endosymbiont of Crataerina pallida,Providencia sp. 1701011,Providencia sp. 1701091,Providencia sp. PROV224,Providencia sp. PROV083,Providencia manganoxydans,Providencia sp. PROV102,Providencia sp. PROV099,Providencia sp. PROV080,Providencia heimbachae,Providencia hangzhouensis,Providencia rustigianii,Providencia sp. PROV279,Providencia sp. PROV103,Providencia sp. PROV252,Providencia sp. PROV100,Providencia sp. 21OH12SH02B-Prov,Providencia sp. R33,Providencia vermicola,Providencia stuartii,Providencia sneebia,Candidatus Providencia siddallii,Providencia rettgeri,Providencia alcalifaciens,Providencia sp. PROV024,Providencia sp. PROV278,Providencia sp. PROV114,Providencia sp. PROV007,Providencia sp. PROV170,Providencia sp. PROV188,Providencia sp. PROV101,Providencia sp. PROV161,Providencia sp. PROV040,Providencia sp. PROV175,Providencia sp. PROV048,Providencia sp. PROV046,Xenorhabdus hominickii,Xenorhabdus sp. SF857,Xenorhabdus sp. TH1,Xenorhabdus bovienii,Xenorhabdus nematophila,Xenorhabdus budapestensis,Xenorhabdus poinarii,Xenorhabdus griffiniae,Xenorhabdus doucetiae,Photorhabdus laumondii,Photorhabdus thracensis,Photorhabdus asymbiotica,Photorhabdus akhurstii,Proteus appendicitidis,Proteus faecis,Proteus columbae,Proteus hauseri,Proteus sp. ZN5,Proteus sp. CD3,Proteus penneri,Proteus terrae,Proteus vulgaris,Proteus mirabilis,Morganella morganii,Enterobacteriaceae endosymbiont of Donacia bicoloricornis,Enterobacteriaceae endosymbiont of Donacia versicolorea,Enterobacteriaceae endosymbiont of Donacia cinerea,Enterobacteriaceae endosymbiont of Macroplea mutica,Pseudocitrobacter corydidari,Enterobacteriaceae endosymbiont of Donacia crassipes,Enterobacteriaceae endosymbiont of Donacia dentata,Enterobacteriaceae endosymbiont of Donacia thalassina,Enterobacteriaceae endosymbiont of Plateumaris rustica,Enterobacteriaceae endosymbiont of Donacia piscatrix,Enterobacteriaceae endosymbiont of Donacia simplex,Enterobacteriaceae endosymbiont of Donacia clavipes,Enterobacteriaceae endosymbiont of Plateumaris consimilis,Candidatus Mikella endobia,Candidatus Schneideria nysicola,Atlantibacter subterranea,Atlantibacter hermannii,Buttiauxella agrestis,Buttiauxella ferragutiae,Buttiauxella selenatireducens,Buttiauxella sp. 3AFRM03,Buttiauxella sp. WJP83,Siccibacter colletis,Phytobacter sp. SCO41,Phytobacter diazotrophicus,Phytobacter ursingii,Scandinavium goeteborgense,Lelliottia sp. AC1,Lelliottia sp. JS-SCA-14,Lelliottia sp. WB101,Lelliottia amnigena,Superficieibacter sp. HKU1,Franconibacter daqui,Candidatus Moranella endobia,Candidatus Riesia pediculischaeffi,Candidatus Riesia pediculicola,Plesiomonas shigelloides,Trabulsiella odontotermitis,Kluyvera sp. CRP,Kluyvera cryocrescens,Kluyvera genomosp. 3,Kluyvera intermedia,Kluyvera ascorbata,Candidatus Ishikawella capsulata,Pseudescherichia vulneris,Yokenella regensburgei,Pluralibacter gergoviae,[Enterobacter] lignolyticus,Candidatus Profftia sp. (ex Adelges kitamiensis),Candidatus Profftia lariciata,Candidatus Profftia tarda,Enterobacteriaceae endosymbiont of Neohaemonia nigricornis,Enterobacteriaceae endosymbiont of Donacia provostii,Enterobacteriaceae endosymbiont of Donacia cincticornis,Enterobacteriaceae endosymbiont of Donacia vulgaris,Enterobacteriaceae endosymbiont of Macroplea appendiculata,Enterobacteriaceae endosymbiont of Donacia proxima,Enterobacteriaceae endosymbiont of Plateumaris sericea,Enterobacteriaceae endosymbiont of Plateumaris braccata,Enterobacteriaceae endosymbiont of Plateumaris pusilla,Enterobacteriaceae endosymbiont of Donacia sparganii,Enterobacteriaceae endosymbiont of Donacia tomentosa,Shimwellia blattae,Jejubacter calystegiae,Cronobacter sp. JZ38,Cronobacter malonaticus,Cronobacter muytjensii,Cronobacter condimenti,Cronobacter universalis,Cronobacter dublinensis,Cronobacter sakazakii,Kosakonia sp. SMBL-WEM22,Kosakonia sp. MUSA4,Kosakonia sp. CCTCC M2018092,Kosakonia sp. BYX6,Kosakonia arachidis,Kosakonia sp. ML.JS2a,Kosakonia sacchari,Kosakonia oryzendophytica,Kosakonia oryzae,Kosakonia pseudosacchari,Kosakonia radicincitans,Kosakonia cowanii,Symbiopectobacterium purcellii,Candidatus Annandia adelgestsuga,Candidatus Annandia pinicola,secondary endosymbiont of Trabutina mannipara,Candidatus Hoaglandella endobia,Candidatus Purcelliella pentastirinorum,Candidatus Tachikawaea gelatinosa,Candidatus Gullanella endobia,Candidatus Doolittlea endobia,Candidatus Westeberhardia cardiocondylae,Candidatus Blochmanniella chromaiodes,Blochmannia endosymbiont of Camponotus sp. C-046,Candidatus Blochmannia sp. SNP,Candidatus Blochmanniella pennsylvanica,Blochmannia endosymbiont of Camponotus nipponensis,Blochmannia endosymbiont of Camponotus (Colobopsis) obliquus,Candidatus Blochmanniella camponoti,Candidatus Blochmannia vicinus,Candidatus Blochmannia ocreatus,Candidatus Blochmanniella vafra,Blochmannia endosymbiont of Camponotus modoc,Blochmannia endosymbiont of Camponotus sp.,Blochmannia endosymbiont of Colobopsis nipponica,Blochmannia endosymbiont of Polyrhachis (Hedomyrma) turneri,Candidatus Regiella endosymbiont of Tuberolachnus salignus,secondary endosymbiont of Heteropsylla cubana,secondary endosymbiont of Ctenarytaina eucalypti,Candidatus Hamiltonella defensa,Shigella dysenteriae,Shigella boydii,Shigella sonnei,Shigella flexneri,Cedecea lapagei,Cedecea sp. FDAARGOS 727,Cedecea neteri,Leclercia sp. J807,Leclercia sp. W6,Leclercia sp. 29361,Leclercia sp. 119287,Leclercia pneumoniae,Leclercia sp. LSNIH1,Leclercia sp. Colony189,Leclercia sp. LSNIH3,Leclercia sp. G3L,Leclercia adecarboxylata,Enterobacter sp. JJBC,Enterobacter sp. RHBSTW-00975,Enterobacter sp. YSU,Enterobacter huaxiensis,Enterobacter sp. DTU 2021 1002640 1 SI PRY ASU LCPMC 013,Enterobacter sp. S-33,Enterobacter sp. DNB-S2,Enterobacter sp. CP102,Enterobacter sp. HK169,Enterobacter sp. T2,Enterobacter cloacae complex sp. ECL414,Enterobacter sp. JH25,Enterobacter sp. AN-K1,Enterobacter soli,Enterobacter sp. SGAir0187,Enterobacter sp. JBIWA008,Enterobacter sp. JBIWA005,Enterobacter sp. MGH 14,Enterobacter cloacae complex sp. ECNIH7,Enterobacter cloacae complex sp. ECL112,Enterobacter pseudoroggenkampii,Enterobacter wuhouensis,Enterobacter quasiroggenkampii,Enterobacter sp. PGRG2,Enterobacter sp. 18A13,Enterobacter sp. E20,Enterobacter sp. R4-368,Enterobacter sp. RHBSTW-00994,Enterobacter sp. JUb54,Enterobacter chengduensis,Enterobacter sichuanensis,Enterobacter chuandaensis,Enterobacter pasteurii,Enterobacter cloacae complex sp. EB5,Enterobacter cloacae complex sp.,Enterobacter mori,Enterobacter oligotrophicus,Enterobacter sp. SA187,Enterobacter sp. ODB01,Enterobacter sp. JBIWA003,Enterobacter sp. SES19,Enterobacter sp. C2,Enterobacter sp. Crenshaw,Enterobacter sp. Colony194,Enterobacter bugandensis,Enterobacter cloacae complex sp. FDA-CDC-AR 0164,Enterobacter cloacae complex sp. ECL68,Enterobacter cloacae complex sp. ECL352,Enterobacter sp. BIDMC 29,Enterobacter cloacae complex sp. ECL405,Enterobacter cancerogenus,Enterobacter roggenkampii,Enterobacter asburiae,Enterobacter kobei,Enterobacter cloacae,Enterobacter ludwigii,Enterobacter hormaechei,Citrobacter freundii complex sp. CFNIH3,Citrobacter sp. B72,Citrobacter sp. RHBSTW-00524,Citrobacter sp. RHB36-C18,Citrobacter sp. FDAARGOS 156,Citrobacter sp. MGH 55,Citrobacter sp. RHBSTW-01013,Citrobacter sp. SX212,Citrobacter sp. R56,Citrobacter sp. TSA-1,Citrobacter sp. SX206,Citrobacter sedlakii,Citrobacter sp. MGH103,Citrobacter sp. RHBSTW-00053,Citrobacter sp. RHBSTW-00881,Citrobacter sp. RHBSTW-00986,Citrobacter sp. XT1-2-2,Citrobacter freundii complex sp. CFNIH4,Citrobacter tructae,Citrobacter europaeus,Citrobacter pasteurii,Citrobacter farmeri,Citrobacter koseri,Citrobacter amalonaticus,Citrobacter arsenatis,Citrobacter rodentium,Citrobacter sp. LUTT5,Citrobacter sp. CFNIH10,Citrobacter sp. Y3,Citrobacter sp. CF971,Citrobacter sp. RHB25-C09,Citrobacter sp. CRE-46,Citrobacter sp. 172116965,Citrobacter sp. RHB21-C01,Citrobacter sp. 21OH12SH02A-Citro,Citrobacter sp. RHB20-C15,Citrobacter sp. BDA59-3,Citrobacter enshiensis,Citrobacter youngae,Citrobacter freundii complex sp. CFNIH9,Citrobacter sp. MGH105,Citrobacter sp. BIDMC108,Citrobacter freundii complex sp. CFNIH2,Citrobacter cronae,Citrobacter werkmanii,Citrobacter braakii,Citrobacter portucalensis,Citrobacter gillenii,Citrobacter freundii,Salmonella sp. 2018103,Salmonella sp. SJTUF14178,Salmonella sp. SSDFZ54,Salmonella bongori,Salmonella enterica,Raoultella sp. HC6,Raoultella terrigena,Raoultella sp. DY2415,Raoultella sp. XY-1,Raoultella ornithinolytica,Raoultella planticola,Klebsiella africana,Klebsiella sp. CTHL.F3a,Klebsiella sp. RHBSTW-00464,Klebsiella sp. WP7-S18-CRE-03,Klebsiella sp. WP3-S18-ESBL-05,Klebsiella sp. FDAARGOS 511,Klebsiella sp. P1CD1,Klebsiella sp. A52,Klebsiella sp. PCX,Klebsiella sp. P1927,Klebsiella quasivariicola,Klebsiella pasteurii,Klebsiella electrica,Klebsiella grimontii,Klebsiella sp. M5al,Klebsiella sp. ZJOU C1,Klebsiella sp. KPN54798,Klebsiella sp. BDA134-6,Klebsiella sp. WP3-W18-ESBL-02,Klebsiella sp. LY,Klebsiella sp. PL-2018,Klebsiella sp. WP4-W18-ESBL-05,Klebsiella sp. WP8-S18-ESBL-06,Klebsiella sp. P1954,Klebsiella sp. LTGPAF-6F,Klebsiella aerogenes,Klebsiella huaxiensis,Klebsiella oxytoca,Klebsiella quasipneumoniae,Klebsiella michiganensis,Klebsiella variicola,Klebsiella pneumoniae,Escherichia sp. TC-EC600-tetX4,Escherichia sp. KS167 9B,Escherichia sp. E4742,Escherichia fergusonii,Escherichia albertii,Escherichia marmotae,Escherichia coli,Hemiselmis andersenii,Cryptomonas paramecium,Guillardia theta,Trichomonas vaginalis,Giardia intestinalis,Dictyostelium discoideum,Phaeodactylum tricornutum,Thalassiosira pseudonana,Bigelowiella natans,Trypanosoma brucei,Leishmania infantum,Leishmania major,Leishmania mexicana,Leishmania donovani,Theileria orientalis,Theileria annulata,Theileria equi,Babesia bigemina,Babesia bovis,Babesia microti,Plasmodium falciparum,Plasmodium malariae,Plasmodium coatneyi,Plasmodium gaboni,Plasmodium sp. gorilla clade G2,Plasmodium vinckei,Plasmodium yoelii,Plasmodium chabaudi,Plasmodium cynomolgi,Plasmodium vivax,Plasmodium knowlesi,Plasmodium relictum,Cryptosporidium parvum,Neospora caninum,Besnoitia besnoiti,Toxoplasma gondii,Encephalitozoon intestinalis,Encephalitozoon cuniculi,Ustilago maydis,Sporisorium graminicola,Malassezia japonica,Malassezia restricta,Malassezia vespertilionis,Psilocybe cubensis,Marasmius oreades,Rhizoctonia solani,Puccinia striiformis,Puccinia triticina,Cryptococcus deuterogattii,Cryptococcus gattii,Cryptococcus decagattii,Cryptococcus neoformans,Kwoniella botswanensis,Kwoniella shivajii,Cutaneotrichosporon cavernicola,Vanrija pseudolonga,Schizosaccharomyces pombe,Schizosaccharomyces osmophilus,Talaromyces rugulosus,Talaromyces marneffei,Penicillium oxalicum,Aspergillus luchuensis,Aspergillus flavus,Aspergillus nidulans,Aspergillus chevalieri,Aspergillus puulaauensis,Aspergillus fumigatus,Botrytis cinerea,Komagataella phaffii,Yarrowia lipolytica,Sugiyamaella lignohabitans,Saccharomycodes ludwigii,Ogataea parapolymorpha,Pichia kudriavzevii,Brettanomyces bruxellensis,Brettanomyces nanus,[Candida] saopauloensis,Debaryomyces hansenii,Scheffersomyces stipitis,Lodderomyces elongisporus,Candida albicans,Candida dubliniensis,Candida orthopsilosis,[Candida] auris,Torulaspora globosa,Torulaspora delbrueckii,Lachancea thermotolerans,Naumovozyma castellii,Naumovozyma dairenensis,Saccharomyces paradoxus,Saccharomyces cerevisiae,Saccharomyces kudriavzevii,Nakaseomyces glabratus,Kazachstania africana,Kazachstania naganishii,Zygotorulaspora mrakii,Zygosaccharomyces rouxii,Tetrapisispora blattae,Tetrapisispora phaffii,Eremothecium gossypii,Eremothecium cymbalariae,Eremothecium sinecaudum,Kluyveromyces marxianus,Kluyveromyces lactis,Ascochyta rabiei,Cercospora beticola,Fulvia fulva,Zymoseptoria tritici,Thermothelomyces thermophilus,Thermothielavioides terrestris,Podospora pseudoanserina,Podospora pseudocomata,Podospora bellae-mahoneyi,Podospora pseudopauciseta,Neurospora crassa,Colletotrichum lupini,Colletotrichum destructivum,Colletotrichum higginsianum,Pyricularia grisea,Pyricularia oryzae,Pyricularia pennisetigena,Purpureocillium takamizusanense,Drechmeria coniospora,Trichoderma breve,Pochonia chlamydosporia,Ustilaginoidea virens,Fusarium falciforme,Fusarium oxysporum,Fusarium musae,Fusarium verticillioides,Fusarium fujikuroi,Fusarium keratoplasticum,Fusarium pseudograminearum,Fusarium graminearum,Fusarium venenatum,Fusarium poae,Akanthomyces muscarius,Nanobdella aerobiophila,Candidatus Micrarchaeum sp.,Candidatus Aciduliprofundum boonei,Aciduliprofundum sp. MAR08-339,Candidatus Methanomassiliicoccus intestinalis,Candidatus Methanoplasma termitum,Picrophilus oshimae,Candidatus Prometheoarchaeum syntrophicum,Candidatus Nitrosotalea okcheonensis,Methanocaldococcus fervens,Candidatus Methanoliparum sp. LAM-1,Thermococcus chitonophagus,Thermococcus profundus,Methanobrevibacter sp. YE315,Methanobacterium sp. BAmetb5,Methanothrix thermoacetophila,Methanocella conradii,Methanohalobium evestigatum,Methanolobus sediminis,Methanosphaerula palustris,uncultured Methanoregula sp.,Halorussus limi,Halobiforma lacisalsi,Halalkalicoccus sp. CGA53,Salarchaeum japonicum,Salarchaeum sp. JOR-1,Halapricum salinum,Halosimplex pelagicum,Haloarcula pelagica,Haloarcula halobia,Halorientalis marina,Salinarchaeum sp. IM2453,Halorubrum sp. PV6,Haloplanus rubicundus,Salinigranum rubrum,Halobaculum sp. XH14,Fervidicoccus fontis,Caldisphaera lagunensis,Acidianus brierleyi,Saccharolobus shibatae,Sulfolobus acidocaldarius,Inovirus M13,Human immunodeficiency virus 1,Bracoviriform facetosae,Betabaculovirus chofumiferanae,Fowlpox virus,Blattambidensovirus incertum1,Tymovirus brassicae,Youcai mosaic virus,Cucumber green mottle mosaic virus,Orthobunyavirus schmallenbergense,Alphainfluenzavirus influenzae,Magoulivirus jiplasmoparae,Kinglevirus lutadaptatum,Penicillium aurantiogriseum partitivirus 1,Cucurbit aphid-borne yellows virus,Severe acute respiratory syndrome-related coronavirus,King virus,Mardivirus columbidalpha1,Bruynoghevirus PaP3,Ficleduovirus FCV1,Muldoonvirus PS2,Serwervirus 201phi21,Cbunavirus possum,Friunavirus AbKT21III,Teseptimavirus Vi06,Teseptimavirus tv3A8767,Teseptimavirus NCA,Cronusvirus cronus,Moineauvirus D1024,Ruegeria phage vB RpoS-V18,Freyavirus freya,Evevirus ev239,Peduovirus P22H1,Peduovirus P22H4,Eganvirus SW9,Jouyvirus ev017
X1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,1,0,1,0,0,0,0,0,0,0,2,0,1,0,2,0,0,0,0,0,6,0,0,0,4,2,3,0,0,0,0,0,0,0,1,0,3,13,0,4,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,3,0,0,3,0,0,0,2,5,0,0,3,4,22,0,0,0,0,0,0,0,0,0,0,0,1,2,3,0,0,2,4,0,0,0,0,0,0,0,0,0,28,20,0,0,32,0,0,0,4,1,0,0,0,0,0,0,0,4,0,0,1,0,0,0,0,0,0,0,1,0,4,0,0,0,0,0,0,0,0,0,0,0,0,2,2,4,0,0,5,0,0,0,0,0,0,1,5,7,7,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,1,10,0,2,0,0,0,0,0,0,0,2,0,0,0,1,2,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,1,0,0,1,1,0,0,0,1,9,0,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,2,0,0,0,0,0,0,0,7,0,0,3,1,1,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,4,0,0,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,9,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,10,175,2,6,0,0,10,1,0,0,1,2,2,20,0,0,0,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,1,1,0,1,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,2,2,4,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,1,1,0,0,1,1,0,2,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,325,711,0,0,0,0,0,0,1,0,0,5,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,2,0,0,0,0,0,0,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,0,0,2,0,3,0,0,265,0,0,0,0,0,0,0,0,0,0,17,26,297,3335,9801,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,1,0,0,0,0,1,8,1,1,9,0,1,1,0,2,2,2,0,0,1,0,0,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,1,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,6,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,11,0,0,0,0,0,0,0,1,1,1,5,347,0,2,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,1,4,2,3,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,2,6,0,0,0,0,0,0,0,0,0,0,0,1,1,8,0,1,1,0,0,3,8,15,0,0,0,0,1,1,2,2,0,0,0,0,1,1,3,22,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,7,8,9,0,0,0,0,1,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,3,0,1,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,1,0,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,4,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,0,134,0,0,1,0,0,0,0,0,0,0,0,0,1,25,149,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,5,5,8,57,1,1,1,1,1,1,2,2,2,3,28,101,417,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,4,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,4,5,329,0,0,265,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,464,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,9,1236,0,1,0,0,2,2,0,2,11,0,0,0,1,2,0,0,1,0,0,0,2,2,0,0,0,1,2,0,0,2,0,0,0,3,0,0,0,0,1,0,0,0,2,0,0,4,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,1,1,0,1,0,0,0,0,0,1,1,3,8,0,0,0,0,1,3,18,31,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,3,0,1,2,0,0,0,0,1,0,0,0,0,1,0,0,1,2,0,0,0,0,0,9,0,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,1,1,2,0,0,1,1,2,2,0,0,0,0,0,3,0,0,15,0,0,0,0,0,0,1,1,5,0,4,5,23,0,0,0,0,0,4,9,0,0,0,19,37,31,320,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,1,1,0,4,0,0,0,0,0,0,0,2,7,2,0,0,0,1,0,1,3,0,0,0,0,5,0,0,5,6,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,0,1,1,0,0,0,0,1,2,0,0,0,2,0,0,3,0,1,3,0,0,0,0,1,0,0,0,3,5,19,0,2,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,2,2,2,3,3,3,3,6,9,12,12,12,21,28,76,1,1,1,3,4,8,20,47,98,125,136,412,1386,2729,0,0,0,1,3,0,0,4,0,0,0,0,0,0,1,1,1,7,1,1,0,0,0,1,1,0,1,1,12,0,42,0,0,0,0,0,176,0,0,0,0,0,0,0,0,1,1,2,2,0,0,2,3,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,1,8,0,0,9,0,0,0,0,0,1,1,1,2,7,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,0,0,0,1,1,2,11,0,0,0,4,17,0,1,6,21,0,0,0,0,0,1,1,2,29,0,0,0,0,0,0,11,23,0,0,0,0,0,0,0,0,4,9,10,0,0,0,0,0,0,0,3,3,34,0,0,0,2,5,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,6,7,9,26,8,15,0,1,1,60,67,5,1,1,5,0,0,0,0,0,0,3,3,4,4,5,9,20,0,0,0,0,0,0,0,0,0,1,2,2,3,3,5,6,10,11,13,16,25,1,3,4,35,51,236,246,363,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,2,2,3,1,2,4,4,5,5,15,15,16,28,31,45,22,30,71,377,0,0,0,0,0,0,1,1,1,4,11,11,38,69,712,765,0,1,1,2,0,0,1,0,0,0,0,0,0,1,0,0,1,3,3,0,0,0,0,0,0,1,1,3,0,0,0,0,1,1,31,0,0,0,0,0,0,0,1,5,0,0,4,0,0,0,11,0,0,0,0,0,0,0,0,0,1,2,11,0,0,0,0,0,0,0,0,0,0,17,1,20,0,0,0,0,0,0,0,0,34,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,6,19,115,1,1,1,1,2,3,3,4,7,8,10,135,157,473,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,1,0,0,0,0,0,0,0,0,1,1,0,0,1,2,2,2,2,0,0,0,0,0,3,0,0,0,0,0,1,0,4,0,0,0,0,2,0,4,0,0,0,6,0,0,0,2,0,0,0,0,0,0,0,0,0,0,1,2,2,3,0,0,0,0,0,0,0,0,3,7,0,0,0,0,0,0,1,2,5,6,6,0,0,0,0,0,0,0,0,0,0,0,0,1,7,9,0,0,33,1,2,33,39,0,0,1,2,2,46,0,0,0,0,3,24,25,0,0,0,0,0,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,8,15,1,1,1,2,3,3,4,4,6,6,42,1,2,3,5,96,4,12,238,10,14,15,42,125,162,0,0,0,0,0,0,2,0,0,0,0,0,4,6,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,3,3,1,1,4,4,7,8,11,32,18786,0,0,1,0,0,0,3,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,3,0,0,3,0,0,0,0,1,4,0,0,0,1,3,4,0,0,0,0,0,0,0,0,180,0,0,0,0,0,0,0,0,0,1,2,0,0,8,0,0,0,0,0,0,0,3,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,3,0,6,0,0,0,0,0,0,0,0,3,7,8,82,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,2,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,1,1,1,1,0,0,2,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,1,3,3,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,1,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,30,0,0,0,0,0,0,0,0,0,0,0,0,1,1,46,0,0,0,0,0,1,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,39,0,0,0,0,0,0,2,150,0,0,0,0,0,0,0,0,0,0,0,1,52,304,540,0,0,0,0,0,0,0,0,2,34,1,46,52,319,1,3,3,5,51,1927,0,0,0,0,0,0,0,0,1,0,0,3,0,0,0,1,3,0,1,5,0,0,0,9,0,4,0,0,0,0,0,0,0,1,2,0,0,0,0,0,0,0,0,3,4,0,0,0,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,1,1,1,0,0,0,0,0,1,3,9,4,19,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,5,0,0,0,0,1,3,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,1,0,0,0,0,0,0,0,5,16,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,6,8,14,161,0,0,0,0,0,0,0,0,3,0,10,0,0,0,0,1,1,19,41,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,3,11,0,0,0,0,0,0,0,0,0,0,0,0,1,6,14,1722,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,1,2,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,1,1,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,4,5,21,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,2,0,0,1,3,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,30,0,0,0,0,0,0,0,0,1,13,1,36,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,7,2724,0,0,12,27,0,3328,0,0,0,0,0,0,1,2,0,2,0,1,3,0,1,5,11,1,0,4,0,1,2,0,0,1,11,0,7,0,0,0,0,1,1,31,0,0,0,0,0,0,0,0,1,0,1,2,3,4,0,0,0,0,9,0,19,1,0,0,0,0,2,3,0,1,0,0,0,3,3,4,9,0,0,0,0,0,0,1,4,4,6,0,0,0,0,0,2,0,0,0,0,5,0,0,0,0,1,9,1,0,3,5,0,0,0,0,0,0,0,5,9,14,0,0,0,0,0,0,1,0,1,0,0,0,9,11,19,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,4,5,0,0,2,0,9,0,0,2,2,61,0,2,4,0,0,4,7,2,3,0,93,137,18,0,0,0,1,0,0,2,33,3,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,5,7,1,1,1,7,12,42,45,51,58,74,0,0,3,0,1,3,11,0,0,2,3,0,0,0,0,0,0,0,2,16,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,10,0,0,0,0,0,0,0,3,8,18,31,0,0,77,0,0,0,0,0,0,2,0,0,7,10,11,3,8,0,0,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,4,5,2,36,0,0,0,0,0,0,0,0,0,0,0,1,1,5,6,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,3,6,1,2,3,3,7,145,1,1,39,377,0,0,0,1,0,0,0,0,0,0,0,1,1,0,3,0,0,0,1,1,4,5,6,14,0,0,0,0,1,22,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,4,0,1,0,0,0,4,0,0,0,0,0,0,0,3,12,2,4,15,0,0,0,0,0,0,1,12,38,0,1,88,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,5,31,1,2,5,7,34,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,3,4,4,5,8,14,1,1,146,194,1,4,0,0,0,0,0,4,7,0,13,1,29,0,0,0,0,0,0,0,1,0,0,3,3,0,0,2,2,1,8,0,0,1,1,5,27,0,0,0,0,1,2,5,0,0,0,3,0,806,0,0,1000,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,133,1,5,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,3,1,3,7,8,12,119,56,72,1,181,1,1,1,1,1,1,1,1,2,2,2,3,3,4,5,5,5,6,9,11,13,18,52,76,1,3,5,13,15,149,414,517,0,0,0,0,0,2,0,0,1,2,9,16,0,0,0,2,4,4,5,7,344,372,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,2,2,2,3,3,3,3,3,3,4,4,5,5,5,8,9,11,17,20,25,49,73,98,101,1,1,1,2,2,2,2,4,4,4,5,5,5,9,11,12,29,25,128,585,2,18,23,68,102,378,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,71,0,0,0,0,0,0,0,0,0,0,1,0,6,0,0,0,0,0,0,0,0,0,1,2,1,2,58,0,0,0,0,0,0,1,1,62,360,0,0,0,0,0,1,1,2,2,2,3,6,47,6102,0,0,2,1,2,3,4,1,1,2,5,6,5,5,0,0,9,0,0,0,1,12,16,0,1,5,5,9,23,56,0,0,0,0,0,570,0,0,0,2,13,21705,0,0,3,0,3,16,19,1,0,0,5,3,8,14,66,244,17,38,63,147,844,0,3,7,0,3,29,35,172,0,0,0,0,0,0,0,0,1,2,2,2,4,7,20,25,26,33,74,103,0,0,0,1,2,3,4,6,16,20,79,101,467,0,1,1,2,1,5,0,1,18,0,0,0,1,1,26,0,0,0,0,0,1,1,3,4,6,7,17,24,48,319,1158,0,0,0,0,0,0,0,0,0,0,1,1,2,2,10,17,20,42,60,136,1,1,3,6,16,19,480,879,0,4,20,0,0,4,90,1093,1,1096,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,9,10,15,37,40,59,61,1,3,5,30,34,250,0,0,0,0,0,2,2,8,8,9,237,286,1,26,103,216,698,5,3,9,46,2,3,7,40,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,16,22,42,50,124,1,1,1,2,2,3,3,4,9,25,47,84,1,1,3,7,16,25,78,121,122,4,64,74,90,0,1,1,1,2,6,54,225,283,1731,9713,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,4,0,0,0,0,5,5,0,0,2,9,0,0,0,9,11,12,31,4,29,35,40,1,1,2,7,9,52,77,96,12,127,20,61,73,2,2,2,3,3,3,6,10,10,17,21,204,318,0,0,0,0,4,5,74,0,0,0,0,0,1,1,1,3,8,26,180,3,1,3,12,25,32,33,47,52,19,0,0,0,0,0,0,1,5,5,13,1,3,5,221,23,75,87,3,43,50,57,793,0,1,397,0,0,0,0,34,2,5,6,96,1423,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,11,1,1,2,2,4,11,175,239,1,3,4,4,7,23,119,264,266,283,1476,1901,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,4,26,29,31,48,72,1,2,3,4,5,7,9,13,23,33,69,801,1,3,4,5,15,117,253,396,518,633,930,0,15,16,488,20750,0,0,0,16,82,1322,0,0,0,0,0,0,0,0,0,0,3,9,17,21,1,2,3,4,5,6,10,17,21,27,35,209,255,537,825,1291,4416,15235,0,0,0,138,328,555,27477,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,2,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,1,0,1,189,0,0,0,0,1,88,0,0,0,0,0,0,0,0,0,4,157,0,0,0,0,0,0,0,0,0,0,0,1,3,3,0,0,0,154,1080
X2,1,4,14,0,1,12,1,5,12,2,13,6,15,1,15,109,68,0,4,0,2,4,0,9,3,12,0,0,1,2,0,0,1,1,2,4,5,0,14,0,18,5,15,1,2,2,13,0,1,8,4,23,7,1,4,2,10,0,0,0,25,1,2,9,20,8,28,0,1,4,5,0,0,2,3,4,62,184,11,142,8,0,0,0,1,23,0,0,0,0,0,0,2,3,7,0,0,1,5,1,0,0,0,0,0,1,9,1,5,1,3,4,0,3,1,58,36,0,1,2,62,35,6,0,0,2,0,0,1,1,3,7,26,12,0,6,0,1,6,314,0,0,1,4,5,2,3,3,9,45,69,4,3,255,1,1,4,29,106,0,0,0,0,1,2,20,197,0,2,1,0,0,0,1,3,4,8,17,17,10,1,0,0,0,0,0,1,2,2,3,3,12,7,15,77,0,1,17,0,0,0,0,1,1,14,260,105,40,21,0,0,0,0,0,2,0,0,1,1,0,3,2,5,0,7,0,0,0,0,37,5,0,2,3,0,1,2,4,9,8,5,0,4,4,0,0,10,19,0,0,0,3,41,0,1,9,34,6,1,2,2,0,0,2,2,1,1,8,0,0,0,1,1,1,1,0,3,17,0,0,0,1,0,1,3,5,7,15,7,6,0,0,0,1,0,1,2,1,12,7,24,1,1,0,0,0,0,8,8,6,0,0,4,1,58,1,2,3,7,1,0,0,3,0,0,1,0,2,5,0,0,0,0,4,12,0,6,15,0,0,0,1,6,7,9,68,1,2,55,9,30,0,0,0,0,0,0,0,0,1,0,5,4,7,0,0,0,0,0,0,2,3,10,27,59,0,0,50,7,12,3,1,2,3,1,0,0,5,0,0,2,2,0,0,0,11,0,0,39,0,0,0,0,17,22,5,1,0,0,0,1,10,0,0,0,0,0,0,0,0,0,0,0,1,3,1,37,91,0,0,0,0,0,0,0,0,0,1,1,4,17,12,0,6,6,60,575,8,98,2,0,20,16,9,23,5,5,1,87,0,0,0,953,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,0,1,1,11,12,4,0,0,0,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,1,1,2,3,0,0,0,0,0,0,0,0,0,0,2,4,6,0,0,0,0,0,1,0,0,0,0,0,0,0,1,1,1,2,1,5,1,2,4,2,3,1,2,5,13,0,0,0,0,0,0,0,1,47,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,5,1,5,0,1,1,1,12,0,0,0,0,5,1,0,0,0,0,0,0,1,3,11,89,0,0,1,1,21,16,3,6,0,3,49,0,0,0,1,11,0,0,0,0,0,0,0,0,0,0,0,0,1,1,14,0,0,0,8,3,20,16,8,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,1,1,1,1,2,2,3,4,5,8,0,0,0,1,4,0,1,9,0,74,1,0,0,0,0,1,8,1,1,0,0,0,4,0,0,0,2,0,2,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,0,1125,712,0,0,0,0,1,9,29,0,0,128,6,11,18,0,0,5,12,6523,1,1,6,0,1,33,1,14,2,0,0,0,0,2,21,2,18,646,0,0,0,0,1,2,0,0,0,0,4,1,38,0,0,0,0,0,0,1,1,1,2,1,3,3,10,7,1,3,7,3,1,120,0,48,719,0,0,0,0,0,1,2,2,4,8,143,116,892,8588,19312,13,0,0,0,0,0,0,0,0,0,0,0,1,2,2,14,22,0,15,1,13,10,1,0,0,2,23,5,19,38,104,0,25,6,1,3,17,155,1,0,14,0,15,18,53,9,1,6,0,1,0,0,0,0,1,1,2,1,2,0,0,5,5,0,0,0,6,0,0,0,0,4,12,8,32,1,0,1,0,1,0,0,0,0,0,0,0,0,0,1,1,7,10,1,0,3,130,17,3,0,2,0,7,10,11,0,12,0,1,2,5,4,0,0,0,0,0,0,0,6,26,0,0,0,0,2,2,0,0,1,3,5,0,0,3,0,0,0,0,1,2,2,0,4,14,550,44,21,6,53,0,0,0,0,0,0,0,0,0,1,2,15,5,17,5,0,5,0,43,109,57,4,6,0,2,0,4,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,4,6,1,2,2,3,5,6,18,36,26,18,20,59,2,2,13,0,0,0,0,1,1,4,6,13,0,62,6,0,17,1,1,7,14,82,0,0,0,0,0,19,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,3,3,4,6,11,32,0,20,13,15,5,1,0,1,12,3,24,0,0,0,0,22,0,1,1,4,0,20,3,9,6,0,5,0,0,0,2,8,1,1,2,0,0,0,3,4,0,1,0,3,0,2,2,4,5,12,23,20,16,0,0,0,0,0,0,2,0,0,0,2,0,0,1,0,44,0,0,3,5,0,1,10,0,0,0,0,0,0,0,0,0,0,0,1,1,82,0,0,0,0,0,0,0,0,1,1,0,3,0,0,1,2,0,5,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,3,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,4,1,7,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,2,2,1,0,55,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,4,0,0,2,5,1,0,0,0,0,0,0,2,4,0,0,1,6,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,10,0,129,0,0,0,0,0,0,1,0,1,2,0,6,0,2,8,0,0,0,1,1,2,4,0,0,0,0,0,0,2,6,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,2,3,7,0,0,0,0,0,0,0,0,3,2,0,0,3,0,0,0,0,0,0,0,6,14,0,4,0,0,0,0,0,1,1,0,0,0,1,3,0,0,0,0,0,5,0,0,0,1,4,0,0,0,0,0,2,0,0,0,0,0,1,4,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,16,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,0,1,1,0,0,3,0,0,1,1,1,0,0,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,6,10,0,0,0,0,1,0,0,0,0,0,0,308,0,2,8,0,0,0,0,0,1,1,1,9,27,164,718,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,3,3,4,4,9,10,10,1,1,1,1,1,1,1,1,2,2,3,3,3,4,10,11,27,3526,0,1,0,37,17,54,71,42,9,0,0,0,0,14,0,0,30,85,184,1412,0,0,1,1,0,2,3,0,0,0,0,0,0,0,0,0,0,0,0,1,1,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,1,2,4,4,5,6,8,8,10,15,21,63,14,26,3,6,0,28,0,0,0,0,0,0,0,1,3,6,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,2,49,6,0,23,5,105,531,0,0,883,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,0,47,1282,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,2,5,0,2,2885,17,12,2,2,2,3,11,5,134,3,30,0,1,0,6,7,14,0,0,1,12,0,1,3,12,15,0,2,5,2,0,0,0,11,1,3,0,0,37,0,2,3,4,0,1,3,2,0,1,17,0,2,15,0,32,1,3,0,0,3,43,4,5,0,0,1,4,12,5,15,6,9,0,2,0,0,1,3,10,11,2,1,45,0,2,15,5,8,55,491,94,2,3,7,0,0,11,2,17,1,0,0,8,11,3,5,0,1,14,7,6,18,20,1,3,5,8,5,0,0,1,1,4,0,0,4,5,0,1,3,3,0,41,0,330,0,0,0,0,0,0,2,2,0,0,4,0,0,4,4,4,1,5,6,9,0,2,8,0,0,1,22,34,0,0,1,0,7,0,0,0,31,1,1,0,1,1,0,20,2,0,1,1,2,9,19,0,0,150,3,4,0,0,3,8,3,14,1,0,0,0,516,5,14,2,13,0,19,104,7,9,21,1,600,1044,131,0,0,0,0,4,4,17,0,4,12,4,9,2,12,36,2,0,4,6,6,8,4,0,19,6,27,2,7,0,0,11,32,0,3,31,0,103,0,0,6,9,8,2,6,7,1,10,0,0,66,1,1,88,0,0,0,0,0,0,6,0,1,1,2,10,16,10,0,0,1,48,0,0,9,0,0,0,1,16,15,0,0,1,0,1,5,5,8,1,26,0,1,8,9,19,0,0,1,5,7,6,3,82,2,0,0,0,0,1,1,1,2,3,14,2,2,3,3,6,7,1,5,0,1,7,2,5,16,8,9,0,0,4,8,7,17,24,72,27,24,64,2,4,0,6,33,3,47,1,97,47,15,472,8,0,6,0,9,26,21,12,0,3,49,0,0,1,2,8,37,27,102,16,49,60,42,17,6,22,20,35,4,5,21,130,36,348,0,5,9,11,1,885,18,21,0,1,19,35,14,517,29,13,356,65,2,10,161,217,7,9,21,24,25,73,0,5,8,18,100,26,6,33,17,30,54,0,2,73,0,1,12,13,13,67,94,51,45,320,0,0,0,0,0,0,0,0,1,5,114,8,0,2,4,27,55,136,17,22,141,188,0,22,88,108,470,1,5,478,670,0,0,0,0,3,143,0,43,231,1,1,1,2,3,68,132,271,2,3,4,4,7,9,25,986,84,130,219,0,0,2,3,15,296,615,834,194,263,5,22,24,59,77,199,0,0,0,0,0,0,0,0,1,1,4,6,6,6,7,8,10,54,1,1,3,7,33,22,24,57,65,82,89,127,301,195,53,18,54,72,67,325,106,47,74,355,2,6,7,18,61,116,22,74,103,22,64,184,127,2,5,10,12,3,7,12,16,12602,158,129,185,31,50,147,78,56,79,367,324,569,101,64,206,1192,1022,3067,12110,1023,190,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,3,5,5,8,9,9,10,12,13,16,28,30,44,51,1,2,3,4,5,5,5,10,14,85,18,32,10,58,12,25,98,38,23,39,172,34,71,22,250,123,196,375,389,976,665,381,61,1266,1790,0,1,2,3,4,20,7,77,79,73,132,89,1150,1138,10766,12945,1,21,62,22,0,15,1,0,1,1,2,2,4,2,1,17,7,10,8,0,0,0,1,3,55,2124,5,70,0,0,8,12,3,3,154,5,0,5,9,1,11,22,46,11,1,29,19,0,0,11,227,0,0,0,1,1,2,5,7,7,0,96,61,0,0,0,0,0,7,12,1,1,7,30,16,28,1,3,4,5,28,43,54,82,508,105,0,0,6,20,30,0,0,1,1,2,3,4,4,11,27,16,23,13,1,1,2,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,2,2,4,4,5,5,14,14,14,15,16,16,29,1,1,1,1,1,1,1,2,3,3,3,4,10,13,31,34,37,0,2,55,35,60,228,246,791,3,1,2,23,19,16,27,16,11,99,10,265,300,735,0,0,0,0,0,0,0,0,1,1,2,2,3,3,0,4,6,6,6,9,0,4,0,1,1,10,0,14,0,0,0,1,21,1,9,17,3,7,30,0,0,2,11,17,0,11,0,11,12,0,0,6,0,0,0,1,2,1,13,0,2,0,6,14,9,10,0,1,5,4,12,2,0,0,2,2,5,7,36,27,0,0,2,10,4,2,58,0,5,34,0,1,8,9,10,0,0,0,0,0,1,2,3,5,16,10,4,10,5,0,0,4,9,10,1,4,4,57,175,0,0,0,1,1,2,6,25,51,50,45,0,0,0,1,1,17,22,1,1,4,8,9,56,88,102,0,5,244,24,16,503,77,0,16,13,29,31,364,0,0,0,0,35,204,312,0,1,2,2,12,202,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,6,10,12,33,1,2,3,5,5,8,9,10,11,12,28,36,7,12,14,2,3,4,12,15,19,58,45,232,161,0,24,2,2,2,51,23,0,213,25,39,297,59,27,96,110,719,39,276,1902,70,267,407,751,1616,903,0,0,0,0,0,1,8,6,6,9,13,24,46,47,185,0,0,0,0,0,0,0,1,1,2,2,3,3,4,5,5,9,10,12,12,13,15,21,52,1,1,4,8,11,8,26,19,27,17,10,16,30,35,9,74,26,142,167,246,341,48016,13,0,1,0,1,1,35,0,0,0,0,88,5,0,0,4,11,0,0,1,2,0,0,0,1,1,1,3,0,0,0,0,0,0,0,0,12,0,5,0,0,1,0,1,3,19,0,21,0,0,0,0,0,25,2,0,27,0,0,0,0,0,10,0,1,6,2,22,7,0,0,0,0,0,1,0,0,240,0,0,0,1,1,4,0,4,6,3,24,0,31,144,0,1,2,0,1,1,1,7,0,0,0,0,0,0,1,0,2,1,0,1,3,24,27,23,5,152,0,0,0,0,0,0,1,1,39,33,98,367,0,0,0,1,0,0,0,9,0,0,0,0,0,0,1,0,2,2,0,3,5,0,0,0,0,0,1,6,0,23,0,10,6,29,37,19,0,0,0,0,1,2,2,3,0,0,4,25,0,16,1,0,0,5,0,0,0,0,1,1,5,7,0,0,0,1,3,0,2,4,1,0,0,14,0,18,1,0,0,2,1,6,20,0,1,0,1,0,0,0,3,1,0,0,0,2,55,2,10,0,73,104,0,0,0,0,0,0,0,1,2,5,8,13,76,1,1,5,9,0,0,0,0,0,0,1,1,1,2,1,1,0,0,3,0,0,6,0,6,9,0,0,1,2,4,0,1,0,0,0,0,0,0,1,6,25,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,2,3,3,20,0,0,0,0,0,1,1,3,2,2,7,16,5,14,42,0,0,0,3,5,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,6,15,5,1,0,246,0,0,0,0,1,1,24,799,0,0,0,0,0,0,0,0,0,0,2,1,224,1343,1447,0,0,0,1,1,1,4,5,15,55,0,414,203,963,0,33,9,20,253,3937,0,0,4,7,13,0,0,3,20,0,6,10,7,0,0,9,3,12,11,32,0,0,0,31,3,5,0,0,1,2,2,10,1,4,5,1,9,0,2,2,13,0,1,6,3,0,0,0,2,0,8,1,1,0,3,0,0,0,0,0,0,0,0,1,1,1,1,2,3,3,4,6,11,30,0,0,7,0,0,4,16,0,0,23,63,11,71,0,0,1,10,0,0,0,0,0,5,11,0,0,1,9,30,0,0,1,2,20,53,2,107,0,0,0,0,0,0,1,1,2,3,3,4,0,0,1,4,9,11,0,0,0,2,13,3,4,1,2,0,0,0,0,1,2,4,11,2,0,7,0,4,0,0,0,0,0,0,4,0,0,7,1,0,2,0,0,1,4,0,0,0,0,0,2,2,0,0,0,0,0,1,1,6,0,0,0,0,2,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,50,38,68,486,2,0,0,0,0,0,0,1,4,2,200,0,0,0,0,0,2,48,766,0,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,1,0,0,1,0,25,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,0,1,13,1,18,0,25,193,0,0,0,0,0,0,0,2,4,2,4,23,7,44,12,2647,0,0,0,1,0,1,0,0,0,0,0,0,1,0,2,0,1,2,3,0,3,0,0,4,0,0,0,0,0,0,2,11,6,0,0,0,16,0,0,8,18,0,0,0,12,0,0,1,0,20,9,0,0,0,0,0,0,0,0,0,0,3,4,1,1,1,1,0,0,0,0,0,0,0,0,0,1,1,3,4,17,1,1,0,0,0,0,0,1,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,1,2,0,4,16,52,0,0,0,1,0,1,1,3,6,0,2,8,25,0,0,11,26,0,0,15,90,15,0,0,1210,0,0,0,0,0,1,1,1,1,2,7,1,1,1,4,1029,4,223,1,0,0,0,0,3,3,1,20,51,7,152,0,0,1,0,1,2,0,0,0,0,0,0,0,0,0,0,1,1,1,2,3,0,0,0,0,0,0,10,15,5842,0,0,28,70,0,8179,0,13,1,5,19,2,8,25,0,0,1,11,152,7,6,20,55,44,0,152,8,0,24,2,3,8,239,51,87,0,0,6,5,0,5,103,0,1,0,1,6,11,0,4,1,1,5,12,24,24,0,0,0,1,13,6,115,20,2,1,1,3,21,20,0,0,0,1,3,35,29,31,70,0,0,0,5,0,1,2,8,101,34,0,1,2,3,6,36,1,2,4,1,22,0,1,3,13,22,150,73,1,31,9,0,0,0,9,3,6,51,48,96,55,3,10,0,5,7,18,83,0,22,0,0,2,19,107,0,0,0,0,0,0,0,1,1,2,3,5,10,26,92,5,18,4,13,99,6,0,11,72,114,0,0,53,14,210,0,47,29,11,22,23,27,34,74,0,622,287,133,0,3,5,5,0,0,27,206,16,72,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,1,17,25,10,23,50,87,0,1,4,61,193,1021,626,452,210,659,6,23,3,0,173,11,71,3,0,10,37,0,1,1,2,4,6,22,4,114,0,0,1,0,10,0,0,3,7,13,4,0,0,8,19,9,0,0,0,0,1,1,4,51,116,23,155,1,2,119,0,0,4,32,1,0,35,0,0,96,21,49,76,76,0,6,95,0,0,0,0,0,0,0,0,0,0,0,0,1,4,1,3,6,7,8,49,40,2,1,22,10,3,110,3,0,0,0,0,0,0,0,0,1,4,67,1,11,6,0,0,0,1,7,1,1,7,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,3,4,4,5,7,12,85,1,1,2,2,2,7,12,8,13,1,22,10,3,9,0,2,117,14,19,631,9,18,258,1596,0,2,8,35,3,0,0,1,2,13,19,0,1,0,13,0,1,12,1,1,0,2,0,43,0,0,0,0,9,81,0,0,0,0,0,1,2,12,0,1,2,15,12,0,12,12,11,138,3,15,0,0,2,1,0,1,5,35,1,1,3,2,70,7,1,227,1,0,0,0,3,7,1,32,385,0,7,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,2,9,1,1,1,1,2,58,3,4,9,6,3,4,50,216,1,3,35,52,210,365,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,3,4,1,1,2,19,15,15,0,150,283,115,89,185,5,30,326,458,4,12,0,2,5,0,3,24,128,1,112,1,97,0,1,2,0,13,17,17,6,0,1,23,4,0,0,0,44,3,82,0,15,2,17,20,78,8,1,4,11,1,9,54,0,0,0,7,1,341,0,1,1441,6,6,0,0,0,0,1,3,11,29,1,2,2,3,20,12,0,0,0,0,0,0,0,1,1,0,0,0,0,0,10,0,0,8,11,930,32,88,165,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,2,2,5,5,6,6,7,7,9,10,13,1,7,36,1,1,3,3,4,4,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,3,3,3,4,5,7,9,15,16,2,4,11,2,1,0,0,15,25,13,14,28,6,243,10,19,364,543,316,0,1702,24,3,17,22,0,17,12,24,3,32,38,12,64,33,34,18,19,0,100,72,106,53,110,652,13,52,239,19,122,199,781,774,1,0,1,1,4,96,0,0,58,2,128,21,0,2,2,0,54,13,10,29,1567,1882,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,3,4,5,5,12,17,1,2,2,3,6,6,0,4,12,8,2,11,5,17,24,17,4,0,47,26,22,347,47,23,17,8,65,18,9,378,155,407,95,106,542,1831,650,0,0,8,25,22,31,2,42,32,72,73,9,78,420,105,40,105,106,295,6842,6,138,206,334,640,1978,0,0,0,0,0,0,0,0,11,12,0,0,0,1,1,0,0,1,57,0,1,2,12,0,3,2,4,0,0,1,3,34,0,0,0,0,1,1,2,4,1,26,79,0,22,143,0,0,0,0,1,4,15,0,671,1011,0,1,3,6,14,1,0,12,0,3,8,16,399,13713,5,25,41,2,7,58,13,14,47,17,16,66,11,20,0,3,94,0,1,3,1,91,228,1,0,32,41,128,323,208,2,2,4,4,17,1431,0,2,4,14,299,57299,9,11,59,69,3,565,467,28,9,9,1153,107,45,137,759,422,182,343,491,372,3565,11,67,306,39,179,114,213,1318,0,0,0,3,3,1,3,11,0,16,10,32,135,223,359,320,132,266,7,471,0,0,5,2,35,21,87,23,318,129,438,458,1395,2,29,80,13,9,68,0,25,183,0,0,2,11,7,75,0,0,1,2,9,17,10,5,28,102,72,55,321,1707,1801,8921,0,0,0,1,6,17,49,2,3,15,31,0,3,10,164,157,338,171,469,253,73,43,5,274,29,100,1513,7571,0,26,299,1,347,111,5155,8208,28,6811,0,0,0,0,0,0,0,1,2,8,4,5,16,33,81,47,45,921,273,475,442,805,637,0,7,0,211,209,909,0,0,5,7,30,25,23,28,180,327,1806,1573,6,314,216,390,845,182,62,160,454,94,29,91,424,0,0,0,0,0,0,0,0,18,24,141,1,2,3,9,9,23,38,546,145,332,350,555,14,0,4,4,75,29,26,4,105,350,33,550,28,61,4,73,150,272,384,428,645,21,455,922,580,0,3,2,5,2,9,180,568,239,2705,201841,0,0,0,0,62,1,1,1,2,2,4,6,16,31,86,5,989,0,1,2,12,26,6,0,0,73,4254,0,2,25,116,490,110,356,87,237,196,6416,585,56,26,87,10,195,717,1169,68,589,783,228,132,14,17,5,6,8,40,17,105,46,1,59,2296,3939,0,0,0,6,73,5,593,0,0,2,14,72,8,30,15,47,130,76,1169,14,42,33,121,217,167,42,318,438,262,0,0,0,1,3,19,43,43,29,51,11,11,33,2248,182,595,472,19,340,157,715,4131,11,27,504,1,2,3,25,367,7,87,30,673,10844,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,3,1,1,2,2,2,4,1,2,8,72,1,2,23,231,44,6,2,10,50,466,1470,4274,1,24,116,77,90,77,1149,2753,1231,1354,6113,7503,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,8,28,2,21,495,86,290,143,622,245,805,33,0,64,21,39,35,59,29,87,70,57,3435,39,207,14,39,70,462,888,510,3221,3580,11235,6,164,167,1046,126466,0,10,31,153,628,5507,0,0,0,0,0,0,0,0,2,4,21,61,112,93,10,0,18,73,64,4,173,128,175,103,18,1939,331,2927,4333,2535,11191,86346,0,0,1,952,2891,1943,187632,10,17,58,7,301,373,63,67,136,7,0,0,0,1,0,2,4,0,60,75,0,0,1,1,2,15,16,18,1,64,206,1814,14,2,10,312,1,29,3,12,6,9,12,1,11,47,477,3,0,0,1,6,78,173,0,115,0,4,2,4,14,0,0,0,7,8,16,1,0,0,8,20,0,25,22,26,204,0,63,2,0,8,77,307,0,0,1,0,1,0,0,0,4,0,11,13,14,8,510,0,0,30,0,7,37,0,1,3,0,0,0,0,1,9,10,3,11,19,0,1,2,0,0,10,0,32,0,5,6,2,15,52,3,6,18,41,35,0,0,0,1,0,1,1,5,1,0,0,0,0,0,2,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,404,0,0,0,398,0,736,0,0,0,0,3,0,11,0,0,26,0,1,0,0,0,0,0,0,0,0,1,1,4,11,0,0,0,0,550,980
...
X8,1,19,0,37,1,3,1,0,1,2,4,20,0,0,1,47,7,1,0,3,7,13,0,6,0,3,0,0,0,2,0,2,0,0,0,0,0,0,7,0,69,1,0,0,1,0,7,0,0,1,0,7,1,0,4,1,1,0,1,0,0,0,4,0,1,2,3,6,0,0,13,0,0,0,2,0,3,24,4,1,32,2,0,5,0,5,1,0,0,0,0,0,0,0,0,0,3,0,8,0,1,1,10,0,0,1,0,1,1,0,0,2,0,1,17,2,9,0,0,1,4,7,1,0,1,0,0,0,0,0,6,17,7,21,8,0,0,5,2,27,0,0,0,8,5,0,0,6,0,4,1,3,3,2,0,0,1,2,3,0,0,0,1,11,2,10,3,0,0,0,0,0,0,0,3,14,0,17,2,2,0,0,2,0,0,0,0,0,1,0,1,1,0,1,54,0,0,16,0,0,0,0,0,1,25,3,95,46,0,0,4,1,0,0,0,2,0,0,0,1,0,0,0,0,3,0,0,0,0,0,0,1,1,0,0,3,2,0,0,4,2,0,1,3,2,1,0,9,0,0,7,0,4,0,0,3,2,0,0,0,0,0,0,0,0,0,0,0,0,4,0,1,2,0,0,0,0,0,0,0,0,1,0,3,0,0,0,1,6,6,0,0,0,0,0,15,17,0,0,1,2,0,0,0,3,0,0,0,0,0,0,0,0,0,15,1,0,1,0,0,1,0,2,0,0,22,6,10,1,2,1,0,1,1,0,0,0,0,0,0,0,0,0,0,3,3,1,0,3,0,17,81,10,0,1,0,0,0,2,0,0,0,3,1,0,0,1,0,0,0,0,2,0,12,1,10,0,10,2,6,1,2,0,0,0,0,0,0,0,0,23,0,3,0,1,3,1,0,0,1,0,0,0,1,0,2,0,0,1,0,7,4,0,0,0,1,4,0,0,0,0,0,0,0,0,0,12,52,0,1,1,0,0,0,0,0,2,0,0,0,3,0,0,3,0,61,12,14,5,1,1,129,15,4,2,4,7,0,6,1,1,0,2,0,1,1,0,0,2,0,1,0,2,0,0,3,0,0,0,0,0,0,0,0,0,1,3,0,6,0,1,0,0,1,1,0,0,0,0,0,3,0,2,0,0,0,0,0,0,0,4,0,1,1,0,0,0,0,3,0,0,0,1,4,0,1,0,0,1,2,0,0,7,0,1,3,0,0,1,0,0,6,0,0,0,0,0,0,38,1,1,0,3,0,1,1,0,0,1,13,0,0,0,0,4,0,1,1,1,2,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,3,0,0,0,2,0,0,0,0,0,0,136,0,0,0,0,1,0,0,2,41,0,20,1,0,6,0,0,1,0,0,0,1,3,4,1,1,2,0,1,0,0,0,0,1,0,0,0,0,0,0,1,42,4,7,1,1,4,10,30,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,0,2,0,0,0,0,0,0,0,0,0,1,1,0,1,1,0,0,1,0,0,0,0,0,0,0,0,0,1,1,2,1,1,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,2,0,845,105,0,0,0,1,0,2,3,1,0,28,0,5,0,0,1,0,0,0,0,0,8,0,1,4,1,3,0,0,0,0,0,2,0,6,23,369,0,0,0,0,0,1,0,1,0,0,0,1,3,1,0,14,0,0,0,0,0,0,0,0,0,1,0,5,0,3,0,0,0,5,0,2,459,0,0,0,0,1,0,0,0,2,3,95,201,719,9344,40828,8,0,1,1,4,0,0,0,0,2,0,1,0,1,2,3,0,2,2,0,3,2,0,0,0,1,1,9,9,4,11,0,2,17,1,4,14,17,10,0,0,8,8,2,22,4,0,2,0,1,1,0,0,0,0,0,4,1,0,0,0,0,0,0,0,0,0,0,0,0,0,7,17,5,0,0,1,2,0,0,17,0,0,0,0,0,0,0,0,4,0,1,0,0,1,0,0,16,2,3,2,0,13,12,0,2,5,1,0,5,0,0,0,0,0,0,0,2,0,1,0,0,0,1,0,0,5,1,0,7,6,0,0,0,3,0,0,0,0,0,0,0,0,0,1,59,43,7,6,13,0,0,1,0,1,0,0,0,0,0,0,0,1,4,3,0,5,0,18,65,18,20,1,0,19,0,0,0,1,2,2,4,1,0,0,2,12,0,0,1,0,0,0,6,0,0,3,7,0,12,1,0,1,14,0,0,0,9,1,4,65,0,20,8,23,9,0,0,0,0,1,2,2,2,9,0,0,0,0,2,0,1,9,13,28,0,17,0,0,0,14,0,0,0,0,1,3,0,0,2,0,10,3,1,0,0,1,0,5,1,1,22,0,29,0,4,9,6,1,0,1,29,0,0,1,0,0,6,0,4,1,2,0,2,1,3,1,9,7,0,1,2,0,0,3,19,0,16,2,0,4,0,0,0,1,0,3,0,1,2,1,5,0,0,0,1,7,0,1,1,0,0,1,2,0,1,0,3,0,0,1,2,4,0,2,0,3,1,1,0,2,8,14,0,1,0,0,1,2,0,0,0,0,4,4,3,2,0,2,0,0,0,0,0,0,1,0,0,0,1,0,5,1,1,2,1,4,0,0,0,1,0,0,0,0,0,0,1,0,1,1,0,1,0,4,0,0,1,1,1,1,2,0,0,0,1,0,2,0,0,1,0,2,0,0,1,6,1,11,0,0,0,1,0,6,0,0,0,0,4,0,1,2,0,0,20,0,1,1,1,1,0,1,0,0,2,0,1,63,3,7,2346,1,1,0,3,0,0,0,0,2,0,0,3,0,1,0,0,1,1,2,1,1,1,2,3,3,4,6,8,9,0,0,0,3,0,0,3,13,0,66,2,0,0,0,0,2,1,0,2,9,0,0,0,2,6,3,0,0,0,0,0,0,3,0,0,4,0,3,0,2,1,7,0,0,1,4,0,0,37,5,0,11,5,0,4,1,0,3,0,0,1,1,2,1,1,9,1,0,0,0,0,0,0,0,1,0,0,1,0,1,1,3,0,1,0,0,0,0,0,1,3,0,0,0,0,1,1,0,0,1,0,1,0,3,0,1,1,3,0,0,4,4,1,0,2,0,0,1,2,0,0,6,0,80,12,2,6,0,2,1,2,0,0,0,0,0,0,12,24,14,0,6,2,0,1,1,1,1,1,1,2,2,1,2,0,0,0,0,0,0,1,0,5,3,0,33,6,1,1,4,0,0,0,3,1,0,0,0,4,1,1,0,0,0,1,0,1,1,7,0,3,0,0,0,0,1,2,0,1,0,0,0,1,2,9,0,0,0,0,0,1,1,0,1,1,0,0,0,0,2,0,0,0,0,0,1,3,0,0,0,0,579,1,0,0,0,0,0,0,0,1,2,0,20,6,254,453,1,3,0,0,1,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,2,2,2,4,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,3,3,0,2,0,0,0,0,0,0,0,1,0,0,0,0,1,0,3,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,0,0,0,0,0,1,0,0,0,0,1,1,2,0,1,0,3,3,1,25,1,4,0,1,0,0,0,0,0,0,0,9,0,0,0,0,7,6,0,15,123,2,3,1,3,21,73,227,0,0,0,0,0,0,1,0,0,1,99,110,894,0,356,0,0,0,0,1,2,0,1,1,5,8,14,1,4,5,10,88,1,0,14,0,0,1,1,1,1,1,1,1,1,1,1,2,2,4,5,6,7,0,0,1,0,0,0,1,1,4,0,26,0,0,1,0,1,0,7,1,11,0,0,6,0,2,0,8,0,0,0,0,1,0,2,0,0,5,3,0,0,4,7,0,0,1,6,3,0,1,2,0,5,0,0,0,1,11,13,1,0,1,0,1,6,0,0,5,0,0,10,1,6,11,4,0,7,0,20,2,21,76,1,2,0,1,1,0,1,0,1,6,0,0,1,0,0,0,0,1,1,0,1,24,1,0,1,0,14,4,0,0,3,11,187,1,0,402,1,1,5,1,1,0,0,0,1,0,0,0,3,0,0,2,1,4,0,0,11,616,2,3,5,0,3,0,0,0,0,0,0,1,0,0,1,0,0,0,1,1,3,0,0,3299,4,2,3,3,14,1,0,3,1,7,1,0,0,3,24,0,6,0,2,115,3,2,5,22,0,0,0,4,3,24,4,1,0,1,1,6,0,0,2,8,1,9,0,0,0,1,1,0,0,4,1,4,6,0,0,0,0,3,1,0,2,2,0,0,1,0,8,10,2,3,0,23,0,0,0,0,3,1,10,0,0,3,17,1,0,8,0,0,18,22,26,7,0,0,0,2,2,2,4,0,1,0,3,4,2,13,0,0,82,1,14,21,6,77,6,14,7,22,0,0,0,2,1,0,5,4,0,0,2,0,1,0,1,2,29,0,1,0,0,3,0,0,0,0,0,0,3,0,17,16,2,0,3,0,1,0,2,2,1,0,0,1,0,0,0,12,3,0,0,3,0,0,0,0,0,1,1,0,31,3,0,0,1,15,19,5,1,0,47,0,1,0,2,4,2,9,4,0,0,0,0,107,8,18,0,2,1,19,45,0,5,16,6,149,30,3,0,0,0,5,0,0,16,0,0,0,9,0,2,12,11,3,1,0,1,1,9,1,0,26,5,8,0,0,1,43,6,5,0,3,5,0,2,1,0,0,154,1,0,0,0,21,0,0,1,60,0,1,17,0,1,4,2,7,22,0,0,4,0,7,3,1,14,1,0,1,3,1,3,1,1,7,0,1,1,1,1,0,0,8,0,0,9,0,3,62,0,0,0,2,9,0,0,1,7,16,2,7,67,1,0,0,0,0,0,2,0,0,0,25,0,0,3,1,13,1,0,0,0,7,0,6,1,7,0,16,0,2,2,3,0,6,13,2,15,58,38,0,3,0,0,8,20,6,0,14,24,7,116,4,17,7,0,47,27,17,5,1,0,18,0,4,1,1,6,11,4,7,7,5,6,668,10,0,21,0,31,4,8,0,32,9,16,0,0,5,0,10,726,60,39,1,5,50,30,95,41,52,24,631,90,19,15,77,423,89,1,73,56,39,298,19,21,32,128,11,12,12,1,22,6,32,8,7,245,1,35,26,3,10,484,219,53,18,1083,1,0,136,98,879,5259,24,15,3,10,225,257,30,1,22,5,91,107,20,501,336,471,2,17,52,169,1773,346,87,1990,59147,6,7,0,3,79,31,1,0,25,0,9,9,0,24,202,72,116,2,22,0,11,8,21,44,18,201,105,279,26,0,6,9,85,103,114,168,662,202,54,21,1060,1266,2249,63000,3,13,1,4,21,2,0,8,9,1,61,16,6,8,125,1,1,168,0,18,1,26,144,345,38,325,58,100,185,68,926,27,132,13,182,107,45,25,109,39,14,9,1,5,0,0,30,21,7,4,5,5,6,33,7,0,1,0,3,0,0,3,0,38,4,896,121,9,36,67,0,15,143,196,35,57,2,2,44,5,2,3326,994,2,8,3,0,0,0,0,0,0,0,0,0,0,0,3,0,0,18,0,5,0,1,0,3,0,1,2,8,10,10,31,9,2,0,0,0,0,0,2,0,12,0,24,0,2,13,23,2,5,5,24,2,2,33,5,1,2,71,73,59,12,75,250,254,55,7,546,197,0,2,0,4,0,0,12,1,1,1,33,2,131,117,184,218,5,7,20,21,1,3,32,1,24,0,6,0,0,0,0,6,4,9,7,0,0,3,0,5,3,2,6,2,3,0,40,0,5,0,80,0,0,33,7,0,3,26,4,0,3,0,4,0,0,0,139,8,0,2,4,2,0,195,100,1,1,9,49,1,0,2,8,0,9,17,2,4,11,60,4,5,0,1,0,3,101,27,25,24,355,34,0,3,0,3,17,1,0,73,53,13,1,0,20,5,6,18,58,3,6,0,7,5,0,0,1,1,1,2,1,1,1,1,3,6,0,2,0,0,0,0,0,0,0,0,24,0,1,0,0,0,0,0,0,0,1,0,0,5,0,1,0,0,0,0,0,0,0,1,0,0,0,2,0,0,1,2,1,0,6,1,4,14,3,2,7,5,0,62,26,0,0,0,0,0,10,2,0,0,2,1,0,1,1,3,0,1,1,0,4,25,14,132,151,9,0,9,3,0,1,0,5,0,3,46,3,183,0,0,5,0,4,0,3,5,29,0,0,1,1,9,3,1,2,0,0,1,1,6,15,0,1,0,0,0,0,8,1,3,5,1,23,0,21,10,1,24,21,1,2,0,5,0,0,25,0,7,3,1,1,3,0,0,0,0,2,0,27,1,3,0,6,24,0,0,0,0,0,0,23,2,0,0,0,0,1,11,19,6,0,0,0,1,6,7,4,0,9,2,0,1,0,0,0,0,4,1,20,2,0,0,16,18,0,7,25,18,8,1,1,0,2,0,0,5,9,4,8,3,0,0,0,0,2,14,17,8,14,59,0,0,0,0,0,5,2,0,3,0,0,8,15,28,30,0,2,81,5,9,147,64,0,0,7,22,0,84,1,1,2,0,9,26,34,1,0,9,0,0,71,0,1,2,9,1,1,0,0,0,0,0,0,9,0,0,8,0,8,12,33,52,11,0,1,0,4,54,3,7,43,5,0,76,4,13,1,2,0,0,34,0,27,66,34,136,33,0,17,16,2,7,1,6,0,3,12,13,54,51,20,168,30,569,14,266,1163,63,136,66,627,649,516,0,0,9,0,0,7,1,6,23,2,9,5,15,30,56,0,3,0,6,4,0,0,0,1,6,0,0,0,7,9,0,0,0,4,38,6,6,28,55,8,0,0,0,9,1,51,6,19,7,3,12,12,43,18,29,3,8,155,85,437,53477,6,0,0,0,0,0,0,0,1,1,1,48,7,3,51,45,87,2,1,25,15,16,1,6,0,1,2,6,0,19,18,1,5,0,0,8,1,1,0,0,0,14,2,3,5,74,6,0,1,10,1,2,0,0,4,5,1,1,1,2,0,0,7,1,3,2,0,0,8,1,0,0,1,0,0,1,2,12,1,0,1,0,0,0,5,1,0,1,0,0,1,6,3,0,0,1,1,0,0,0,1,0,1,2,0,0,7,2,0,0,2,0,0,13,126,0,3,0,0,0,0,8,0,1,0,1,12,0,19,341,0,1,1,1,1,3,0,53,15,4,3,12,4,1,97,2,12,51,1,1,23,8,0,0,1,17,3,99,1,1,0,12,5,3,17,30,0,0,2,0,29,0,1,17,0,0,0,16,0,21,0,0,0,5,2,0,3,6,0,0,2,1,1,1,1,0,0,0,1,3,2,1,0,4,1,6,10,1,0,2,0,10,10,0,0,0,0,8,0,0,0,1,0,0,7,1,3,0,1,0,7,47,1,2,2,1,0,0,0,3,3,1,0,3,4,5,0,1,0,0,12,0,2,1,0,2,1,25,20,4,15,1,1,6,14,13,11,0,1,243,0,3,0,18,9,0,27,2,2,0,1,0,0,0,24,0,0,1,0,0,2,1,1,2,2,7,1,4,1,7,544,1,1,2,7,1,0,0,0,2,0,16,3,0,0,11,3,9,2,8,9,9,17,13,0,13,0,6,0,2,0,4,0,1,1,0,20,1,3,0,0,0,1,0,0,0,1,0,2,1,11,0,1,142,2,18,5,11,8,1,11,597,1,1,1,2,3,0,9,4,0,3,3,0,588,1826,29,0,5,3,0,14,0,1,8,4,12,0,130,64,56,3,8,9,0,17,1954,1,1,4,2,0,0,0,1,12,0,2,0,4,0,0,1,0,4,0,4,0,0,0,1,5,0,1,0,0,0,0,1,1,0,1,1,3,0,1,0,5,1,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,0,0,0,1,11,0,11,0,0,2,10,0,11,1,0,0,16,19,16,3,0,0,1,2,0,0,0,5,2,0,1,7,0,0,3,10,2,0,2,3,6,4,0,0,0,0,0,0,1,0,0,0,1,0,1,0,1,0,4,3,0,0,0,1,0,0,5,3,3,1,2,0,0,0,0,0,2,0,23,0,0,0,1,0,1,3,1,4,6,2,14,0,0,7,0,0,0,0,0,0,3,0,1,1,0,1,0,1,1,1,6,0,0,0,17,4,0,0,0,1,0,9,0,0,0,1,1,1,1,5,10,0,0,0,0,1,0,0,7,0,0,0,1,8,2,0,0,19,0,10,5,1,0,1,0,4,7,0,5,228,0,1,0,2,0,0,0,2,4,0,70,1,3,3,0,8,0,2,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,3,1,0,1,0,0,1,0,0,0,1,2,2,4,0,1,0,24,0,0,2,0,1,0,0,1,0,0,0,2,7,0,3,0,3,2,1,16,0,0,1,4,0,2,4,5,0,3,6,10,0,1272,1,0,0,0,0,0,18,1,1,0,0,1,0,6,0,0,0,1,1,3,1,0,2,0,0,1,0,0,0,2,0,0,8,1,0,0,3,0,0,2,0,0,0,0,10,2,0,2,0,1,0,0,1,0,0,0,0,0,0,0,0,0,94,0,0,0,2,4,0,1,1,6,0,0,0,1,0,0,3,0,8,2,2,2,1,7,2,0,0,1,0,0,2,1,2,0,0,0,0,0,0,1,0,0,0,0,0,0,7,0,2,93,5,0,0,1,0,0,0,0,2,1,0,1,0,1,0,0,11,11,1,0,11,31,12,1,0,22651,1,0,0,0,3,0,0,0,0,0,0,0,0,0,3,473,0,286,0,0,0,1,2,0,0,0,38,4,1,100,1,7,0,0,0,0,0,0,5,12,1,1,2,0,0,0,0,0,4,25,3,6,0,0,0,2,0,0,2,172879,0,0,1,18,0,6935,0,3,0,1,0,0,4,0,1,0,0,0,7,2,1,2,2,22,0,6,1,0,0,2,0,0,1,9,17,0,0,1,2,0,10,48,0,0,0,0,0,3,0,2,0,0,0,2,5,1,1,0,0,0,4,0,8,2,0,0,0,0,0,15,0,0,0,0,0,4,7,15,14,0,0,0,1,0,0,1,0,9,2,0,2,2,0,0,6,0,1,0,0,3,0,1,0,4,3,7,5,0,3,5,0,0,0,0,0,0,4,17,5,1,0,0,0,0,12,0,0,0,0,1,0,3,0,34,0,0,0,0,0,1,1,1,0,0,1,0,0,3,6,0,1,4,1,6,0,0,8,0,6,0,0,158,3,27,0,0,2,0,6,2,1,5,0,0,90,3,37,0,0,0,0,1,1,1,2,2,3,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,1,0,0,3,4,2,1,1,7,1,0,1,0,82,242,128,5,324,13,3,8,0,0,2,1,5,0,0,0,11,0,0,0,0,0,3,0,0,18,0,0,7,0,1,0,0,0,0,0,0,0,0,0,0,4,1,0,1,0,0,0,0,10,1,0,2,0,0,115,0,2,0,0,0,0,2,0,0,12,18,0,4,16,0,1,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,124,10,1,1,0,1,0,16,0,0,0,0,0,0,0,0,1,4,8,0,0,2,19,0,0,0,0,0,3,0,0,0,1,1,1,0,0,0,7,0,0,0,0,5,2,0,0,1,0,0,0,3,0,0,0,0,2,1,1,1,0,1,6,23,46,0,0,3,0,0,6,3,8,8,3,8,4,19,0,1,39,4,18,24,5,8,72,640,0,2,6,0,0,1,0,1,0,1,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,14,0,0,0,0,0,1,5,0,0,2,1,1,0,2,0,0,2,34,0,1,0,0,0,0,0,0,0,1,0,0,1,0,10,0,0,20,1,0,0,0,0,0,0,2,172,0,5,0,0,1,1,0,0,0,0,0,0,0,1,0,4,0,0,0,2,0,2,0,0,0,0,7,12,0,0,0,0,0,0,1,18,53,0,78,1,26,313,0,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,8,0,0,0,0,7,1,0,5,50,18,3,44,0,4,72,10,1,0,0,0,1,0,23,0,21,0,12,0,11,0,0,1,0,0,12,12,0,0,0,7,0,0,1,0,262,0,7,3,7,3,41,4,12,0,0,1,0,0,0,0,0,0,1,0,0,5,0,0,727,3,0,1,0,1,0,0,0,0,2,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,11,0,0,7,0,0,3,1,273,0,0,8,0,1,1,1,3,1,1,1,1,1,1,19,0,0,0,0,0,0,0,0,0,2,0,0,0,2,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,1,0,0,0,0,1,0,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,3,0,0,2,0,0,0,0,0,0,0,0,1,1,3,0,0,0,0,0,0,1,2,0,0,0,0,0,0,2,5,0,0,0,1,2,2,29,5,0,1,1,0,6,3,2,46,0,7,1,3,0,2,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,0,3,3,0,39,1,3,7,0,0,0,7,37,0,64,1,2,4,0,0,13,0,0,0,5,42,12,6,1,29,112,81,0,428,1,0,0,9,0,6,1,8,0,4,10,2,5,4,11,13,5,4,0,1,22,19,4,8,2,5,30,4,19,0,501,131,0,0,0,0,4,9,0,0,5,0,36,0,0,0,1,0,55,0,0,0,100,398,0,1,0,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,3,0,0,0,0,0,0,0,0,5,0,0,2,0,7,2,1,0,0,14,1,0,46,5,5,0,9,1,4,10,29,22,64,37,12,71,129,57,2,0,0,4,1,23,0,1,118,6,25,8,12,0,7,7,101,20,32,4,3,70,44,128,179,2112,1,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,3,0,9,0,0,0,4,0,0,0,4,0,2,0,0,4,0,1,0,0,0,0,2,3,0,2,0,0,0,1,0,0,0,0,10,0,11,0,1128,116,4,0,0,0,3,2,0,0,0,24,2,0,96,5531,0,0,4,3,4,50,3,1,9,0,0,3,3,4,0,0,10,0,0,0,0,19,16,0,2,12,5,4,34,32,1,4,1,0,0,172,0,1,1,38,60,34069,0,0,9,13,0,32,37,0,0,0,5,2,4,10,144,4,14,32,28,9,70,0,0,1,4,2,3,15,1,0,0,0,0,1,0,1,0,0,4,0,0,3,21,65,16,2,69,0,57,0,0,0,0,2,0,11,5,24,75,93,1,22,0,0,0,2,0,1,0,0,3,0,0,0,0,0,34,0,0,0,0,4,0,0,0,0,34,1,0,5,67,431,905,0,0,0,0,0,0,0,1,1,19,0,0,6,0,40,17,12,1,57,315,2,2,0,0,0,156,83,858,0,0,26,2,0,0,19,724,1,0,0,0,0,0,0,0,3,1,2,0,0,0,1,1,1,0,4,67,2,89,49,39,163,0,0,0,15,25,130,0,0,0,1,0,8,8,1,7,130,94,1,2,13,0,9,49,8,15,4,61,6,7,7,35,0,0,0,1,1,0,0,0,0,13,1,0,0,1,62,0,20,0,110,12,0,67,41,2,0,0,0,0,0,1,0,9,5,0,41,0,5,1,43,16,11,12,0,37,5,0,15,18,0,0,0,0,0,0,6,45,49,140,1455,0,0,0,2,0,0,0,0,0,0,0,1,0,1,8,0,2,0,0,0,5,1,4,0,0,9,3,0,0,6,3,2,1,99,19,17,13,103,0,6,1,4,0,8,7,0,6,83,18,30,9,1,0,0,0,0,0,3,1,9,0,0,136,23,0,0,0,0,1,0,50,0,0,0,5,25,0,0,1,3,2,0,247,0,3,2,15,69,18,0,0,11,46,0,0,0,0,0,15,14,1,11,6,0,0,1,504,17,102,23,4,95,194,267,499,1,1,13,0,0,0,17,29,0,11,2,8,42,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,5,1,0,0,0,1,0,0,0,5,23,12,0,0,30,36,0,34,261,0,0,2,8,0,6,163,468,120,229,493,2243,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,1,0,56,1,0,25,33,3,2,6,5,0,19,0,18,33,26,0,0,0,0,601,0,0,0,2,6,7,7,64,474,737,354,0,15,85,66,15529,0,0,0,5,100,27,0,0,0,0,0,0,0,0,1,0,0,11,7,3,0,0,0,0,9,0,6,0,0,1,1,240,7,668,274,124,8319,14109,0,1,5,139,608,38,37130,9,371,95,4,193,402,246,55,300,4,1,0,0,1,0,7,4,5,102,86,0,71,1,0,8,19,29,12,5,580,218,315,4,6,101,2002,2,20,12,110,15,3586,47,50,281,137,2652,3,0,4,4,23,559,194,9,465,10,7,10,1,5,7,0,3,18,4,3,122,0,427,135,84,1,88,18,81,163,11,47,1,6,4,7,990,0,0,12,8,1,2,1,1,9,15,3,17,2,1,42,0,11,8,0,2,1468,25,48,186,0,9,1,16,0,46,108,19,6,29,3,12,1,3,15,17,16,150,1,26,156,0,10,353,278,12,25,346,26,0,1,0,0,0,0,0,1,0,0,0,0,0,0,4,0,0,0,0,1,9,1,2,0,0,0,0,0,0,0,2,0,0,1,0,0,0,0,0,0,1771,1,1,0,36,0,1,1,0,0,1,3,2,64,0,0,30,0,4,1,1,0,0,0,0,2,0,1,0,2,9,0,3,0,0,258,982
X9,0,3,2,4,1,5,2,7,1,0,22,12,9,0,2,134,40,0,3,0,1,6,0,6,0,5,0,1,0,0,0,1,0,2,1,0,0,0,24,0,223,2,3,0,0,0,3,1,0,0,3,4,3,5,3,0,2,1,0,0,294,1,2,5,18,0,1,0,0,1,5,0,0,0,1,0,41,24,6,13,4,0,0,0,0,17,0,0,0,0,0,0,1,0,6,0,1,0,9,0,0,0,2,0,0,0,0,3,0,0,0,5,0,1,0,34,9,1,0,6,21,32,2,0,0,2,2,0,13,0,5,1,31,9,1,4,5,2,0,97,0,0,3,3,20,0,2,1,0,28,26,4,0,14,0,0,20,40,218,0,0,0,0,5,0,4,20,0,1,1,0,1,0,0,0,1,0,26,40,15,0,0,0,0,1,0,4,0,16,0,2,0,10,17,6,0,1,6,1,0,0,0,0,1,3,35,38,39,14,0,2,0,0,0,0,0,0,2,0,0,0,0,2,2,2,2,0,0,0,8,0,0,3,1,0,0,0,4,3,17,3,1,0,0,0,0,0,17,0,0,0,1,57,0,0,0,3,0,0,0,3,0,1,0,1,0,0,5,0,0,0,0,0,0,0,0,0,9,1,0,0,0,0,0,1,2,4,10,9,5,0,0,0,0,2,3,1,0,4,12,2,0,3,0,0,4,0,2,0,2,0,1,0,3,33,0,0,4,1,1,1,0,0,1,0,1,0,1,7,0,0,2,8,0,2,0,0,3,1,1,0,1,0,3,0,25,0,1,56,8,10,0,0,0,0,0,1,0,0,4,1,1,2,18,1,0,0,1,0,0,0,3,0,56,30,1,0,65,6,0,13,1,1,0,2,1,0,3,0,1,0,0,0,0,0,6,0,0,0,0,0,0,0,10,3,4,0,0,0,0,1,6,0,1,1,0,0,0,0,1,0,0,0,0,1,0,31,115,1,0,0,2,0,0,0,0,1,0,0,5,0,11,0,0,4,42,230,15,22,3,0,19,10,2,16,29,6,0,23,1,0,0,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,0,0,0,4,0,5,0,0,0,1,0,0,0,0,0,0,0,0,0,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,5,26,2,1,0,0,0,1,1,0,0,0,0,0,0,0,0,0,1,0,2,0,0,0,0,5,9,0,0,4,0,0,0,0,2,0,1,1,2,0,0,0,5,2,1,0,0,0,0,2,0,0,4,0,0,3,0,2,0,2,0,4,26,1,0,1,0,6,0,0,0,0,0,0,3,8,0,23,55,1,0,0,0,4,8,0,3,0,0,50,0,0,0,3,14,1,0,0,0,0,0,0,0,2,0,0,0,0,1,9,0,0,1,0,0,8,13,3,9,0,0,3,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,2,0,0,0,1,6,1,0,0,0,0,0,0,0,0,0,1,2,0,0,2,25,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,16,0,0,0,0,0,1,0,0,0,0,0,0,12,1,1,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,1,4,0,1880,545,0,0,0,0,0,8,540,0,0,167,0,11,1,1,0,0,12,0,1,0,4,0,0,0,0,18,1,2,2,0,0,4,14,1,14,1,0,1,0,0,0,0,0,1,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,1,0,0,4,0,7,0,3,948,1,0,0,0,0,0,0,0,2,9,106,82,518,6966,22318,1,1,0,0,0,0,0,0,0,0,0,0,1,1,0,4,1,0,25,0,2,4,2,1,2,2,13,2,20,8,20,0,34,2,8,6,16,121,1,0,12,0,6,5,19,14,1,1,0,0,0,0,1,0,0,0,1,0,4,1,0,1,0,1,0,0,2,0,3,0,0,4,4,4,9,8,0,1,0,2,3,1,0,0,0,0,0,0,0,0,0,1,16,5,0,0,4,38,2,0,2,1,2,22,0,0,5,2,1,0,4,3,0,0,0,0,0,2,2,11,575,1,0,3,1,0,0,0,2,0,2,1,1,0,0,0,0,0,0,0,1,0,2,0,2,33,51,23,2,20,25,1,0,0,37,0,0,0,0,3,4,4,0,0,5,23,1,0,14,87,22,24,165,0,0,0,1,0,0,0,1,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,11,0,0,2,3,0,2,5,0,2,5,14,23,29,0,3,12,1,0,0,0,0,4,2,0,8,2,3,0,0,5,0,0,9,5,54,2,2,0,0,3,2,56,0,53,0,13,72,2,15,8,24,1,4,2,0,29,2,0,1,0,4,5,0,17,0,7,23,17,34,1,2,0,1,0,28,2,0,0,0,19,0,0,3,2,0,10,0,17,2,0,0,0,0,0,0,12,0,2,7,7,44,1,0,1,0,0,9,3,2,0,7,0,1,3,2,19,3,0,0,0,0,2,0,8,0,0,0,3,0,0,0,0,23,0,0,0,2,5,3,9,0,0,0,0,0,0,0,0,0,2,0,0,0,2,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,3,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,1,0,2,1,1,0,0,0,0,1,0,2,0,0,0,0,0,1,0,0,0,0,0,0,187,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,2,3,0,21,0,0,1,0,8,0,0,6,0,1,1,9,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,9,0,753,0,2,0,0,0,0,1,0,0,0,0,3,1,0,0,3,0,0,0,0,1,0,0,0,0,0,0,3,1,7,0,0,0,1,0,0,0,0,0,0,0,0,6,0,5,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,34,0,2,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,3,1,0,0,0,1,0,0,68,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,6,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,2,0,0,0,0,0,0,0,0,0,0,0,359,0,2,93,0,0,7,0,0,3,2,0,8,7,49,381,0,0,1,0,0,0,0,0,0,0,1,1,2,1,1,1,1,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,1,2,0,0,0,1,0,0,0,0,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,1,0,7,0,1,2,4,0,2,0,0,0,0,0,0,1,0,0,0,1,0,0,7,8,2,1,1,0,0,0,75,52,103,135,29,0,0,0,0,0,3,0,0,6,965,137,1146,0,4,0,0,0,0,3,0,3,0,0,0,0,0,0,0,0,0,0,0,0,36,2,2,0,0,1,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,1,0,0,0,0,0,0,0,3,0,0,2,0,0,0,0,1,0,1,1,0,0,4,2,0,0,0,11,0,0,0,2,2,4,5,0,5,16,1,2,6,1,0,5,2,16,0,0,0,0,0,0,0,0,2,0,1,0,1,0,0,0,0,1,0,0,1,1,0,0,0,0,1,9,0,0,6,45,578,0,0,910,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,13,0,0,39,1058,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,0,0,0,0,11,2205,5,0,3,5,2,2,0,2,1,1,1,0,0,0,5,12,3,0,0,4,3,7,0,3,2,17,0,0,0,8,0,0,1,2,0,4,0,0,0,3,0,0,1,0,0,0,1,0,0,10,0,4,1,0,0,1,0,0,0,0,3,2,1,0,1,0,1,0,2,4,0,1,0,0,3,0,0,1,8,1,0,0,3,2,0,8,1,0,36,267,13,2,2,0,0,1,9,8,2,0,0,0,4,2,5,0,0,0,14,8,1,6,12,3,1,3,2,10,0,0,0,1,3,0,0,8,1,0,0,4,2,1,28,0,710,1,2,0,1,1,0,5,0,1,0,1,0,0,3,0,2,0,1,1,0,0,0,0,2,0,0,1,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,10,0,0,0,0,0,19,9,0,0,105,1,2,0,2,4,2,0,12,4,2,0,0,134,2,4,49,0,0,355,82,1,0,108,100,1089,4,8,0,0,0,16,0,3,2,0,16,0,4,2,3,11,15,2,0,0,1,4,0,0,0,8,6,12,2,7,2,8,33,17,0,5,0,10,11,3,0,0,3,14,0,12,0,3,25,0,0,67,2,0,25,0,0,0,0,0,1,0,0,0,0,3,1,6,9,0,0,0,12,2,0,8,0,0,1,5,10,4,0,0,0,0,5,0,3,1,1,12,0,0,0,7,6,6,0,152,3,14,6,11,40,3,2,0,0,0,0,0,0,0,0,7,15,0,19,0,15,2,0,6,0,1,12,1,16,16,0,7,0,6,0,6,1,8,21,38,23,184,34,27,0,0,1,8,4,39,0,7,27,15,233,0,1,16,0,4,33,26,13,5,2,36,0,1,0,0,32,45,29,57,13,3,51,51,16,7,10,3,29,1,1,6,73,21,47,0,11,22,4,0,604,19,15,0,4,70,10,14,19,9,12,29,35,1,25,28,201,0,119,14,61,27,215,2,9,5,17,6,22,4,15,7,0,70,0,12,4,0,7,12,1,4,26,48,227,24,367,0,0,0,0,0,1,0,0,0,1,24,1,1,2,6,3,38,9,13,49,109,199,0,5,42,88,490,47,74,588,2733,8,0,0,2,7,23,0,0,32,3,1,0,0,0,61,98,295,0,3,49,0,1,3,4,17,149,61,30,0,1,0,0,16,11,252,53,266,127,13,0,23,44,118,131,0,0,0,0,3,0,0,1,2,0,0,3,2,4,6,1,0,25,0,0,0,7,19,18,6,83,14,97,101,64,214,18,182,11,120,49,13,159,343,50,50,1778,0,4,3,10,9,451,21,102,30,38,306,728,548,0,1,20,46,4,35,604,116,38,129,533,121,81,39,327,634,58,50,606,2074,313,358,36,405,386,101,3962,4727,78,11,0,0,0,0,0,0,0,1,0,0,0,0,2,0,0,3,0,1,0,0,7,3,7,2,5,4,23,21,0,14,5,0,0,0,4,0,48,0,0,6,51,4,13,9,19,0,17,1,10,11,5,42,7,54,17,82,113,128,24,237,223,391,102,13,510,890,0,0,0,0,0,0,0,6,2,15,8,37,86,128,143,123,3,25,81,28,1,4,16,0,9,0,4,1,0,0,1,16,3,21,10,1,0,0,2,0,14,4,3,16,0,0,2,2,1,1,85,1,0,1,10,0,5,5,23,4,4,7,34,1,1,0,108,0,0,0,0,0,0,3,32,3,3,16,36,2,1,3,0,1,1,6,2,3,4,21,7,2,0,4,0,4,15,29,5,11,543,75,0,1,1,18,364,0,0,0,5,0,4,8,2,1,2,22,16,10,1,0,0,0,1,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,4,0,0,4,0,0,0,1,0,0,0,3,8,46,2,0,0,2,0,1,0,1,0,0,3,1,12,14,3,0,3,6,72,12,30,0,0,0,1,0,0,0,0,1,3,6,0,2,12,7,2,8,0,0,12,24,34,65,97,63,0,2,2,10,37,1,21,130,8,109,0,137,36,249,0,1,0,2,2,2,1,2,0,0,3,0,2,1,0,6,12,2,11,3,1,2,0,7,2,9,1,10,0,1,0,0,11,0,17,7,0,32,21,0,3,4,6,3,58,8,2,6,0,0,7,0,0,1,0,0,29,0,22,0,17,18,4,45,2,5,0,4,2,1,26,0,0,0,0,7,1,2,19,23,0,4,1,6,0,0,56,1,13,25,0,1,9,7,0,1,0,0,0,0,0,0,2,1,0,2,9,42,4,2,1,1,5,4,0,2,1,7,9,0,0,0,1,7,5,4,8,14,12,43,0,0,0,1,3,24,18,1,0,1,12,4,184,63,76,18,7,265,8,14,429,115,0,14,7,31,10,156,0,1,0,1,20,182,102,0,2,4,2,8,144,1,0,0,0,1,8,0,1,6,1,0,0,1,0,0,0,0,11,4,23,41,9,7,4,0,7,30,3,12,11,6,9,27,1,24,1,4,1,2,9,11,10,51,28,206,259,1,24,25,3,3,92,24,0,36,56,67,80,50,34,45,44,631,20,316,2017,39,296,437,898,2402,840,3,2,0,0,0,2,0,2,14,15,410,27,30,43,22,2,1,3,0,1,0,2,1,0,1,3,2,1,11,4,4,0,0,2,5,11,5,8,25,0,2,0,5,4,8,22,15,14,23,11,23,12,96,18,99,4,14,132,207,378,69350,0,0,23,0,0,0,16,1,8,0,0,50,2,0,2,0,2,0,0,1,0,0,0,0,0,1,1,1,1,0,0,0,0,0,0,1,0,0,5,0,1,0,0,1,0,0,0,50,0,1,0,0,0,13,1,0,19,0,0,0,0,49,6,0,3,2,0,5,5,0,0,1,0,0,0,0,1,61,4,0,0,0,0,24,4,0,2,3,31,0,18,35,0,0,0,0,0,1,0,0,0,0,1,0,0,1,0,0,0,0,0,0,24,6,8,12,0,41,0,1,0,0,0,0,0,0,22,7,58,284,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,1,0,0,0,0,0,0,0,0,1,0,2,0,5,1,8,11,8,54,40,0,1,0,0,0,0,0,0,0,0,0,9,0,2,0,0,0,1,0,0,0,2,0,0,10,4,0,0,1,0,5,0,0,0,0,0,0,19,0,13,0,0,0,0,0,0,3,0,0,0,0,0,0,0,1,2,0,1,0,0,64,0,0,0,67,94,0,0,0,1,0,0,0,1,0,0,2,0,1,1,0,2,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,21,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,3,0,3,0,0,0,0,0,0,0,0,0,5,2,0,0,0,0,1,0,24,0,0,1,0,0,0,0,0,42,0,0,14,1,2,50,1,2,0,0,1,5,0,0,1,1,0,0,3,0,0,0,0,1,0,1,0,0,0,0,0,0,10,0,0,277,1,0,0,0,0,0,35,267,0,0,0,0,0,0,0,0,0,0,0,0,169,1353,512,0,7,1,0,1,1,0,8,24,91,0,422,75,1653,1,30,10,38,166,2806,0,0,0,10,7,0,0,0,3,0,2,2,10,0,0,11,0,3,1,24,1,1,0,18,43,3,0,1,0,2,0,5,0,1,1,4,6,0,0,1,1,0,0,3,3,1,2,0,0,1,1,0,1,3,2,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,5,4,5,81,0,0,9,0,0,10,7,0,0,15,24,1,46,0,0,0,0,0,0,0,0,0,2,13,0,0,0,9,46,0,3,2,0,33,13,0,13,0,0,0,0,2,0,1,0,1,0,0,1,0,0,0,2,0,11,0,1,0,0,427,13,1,2,0,0,1,0,0,0,1,0,9,0,0,7,0,2,0,0,0,0,0,0,17,0,0,4,0,0,1,0,0,0,3,1,0,0,0,0,0,1,0,0,0,0,0,0,0,33,0,0,4,0,0,7,0,1,1,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,2,43,372,0,0,0,0,1,1,0,0,10,0,187,0,0,0,0,0,1,3,112,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,5,4,1,0,0,0,0,0,1,0,0,0,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,1,0,0,5,36,2,3,0,42,19,0,0,0,0,0,0,0,1,0,0,0,6,14,130,23,2531,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,6,1,0,3,0,0,0,0,0,0,0,0,0,1,0,15,0,0,0,26,0,1,8,46,0,0,2,1,1,0,1,0,8,1,1,0,0,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,53,0,0,0,3,0,0,0,0,0,0,1,0,0,0,0,0,1,1,0,0,0,0,0,0,0,0,0,6,0,14,17,17,0,0,0,1,0,1,0,1,5,0,1,0,9,0,0,1,13,0,0,1,69,7,0,0,11,0,0,0,0,0,0,5,0,0,0,3,0,2,2,0,0,1,165,0,1,0,0,3,17,5,0,25,5,3,88,0,0,1,0,0,0,8,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,5,12,4562,1,0,26,10,0,7079,0,6,1,1,22,0,2,94,2,12,0,5,103,16,13,77,98,25,0,140,13,1,19,3,58,4,170,32,87,1,3,3,0,0,5,161,0,0,0,0,4,8,0,2,5,1,3,5,8,28,0,0,7,0,3,21,96,16,0,1,5,0,46,11,0,0,0,0,3,16,34,14,22,0,0,1,1,0,0,1,0,73,17,0,8,0,0,3,41,0,0,2,0,4,0,14,0,8,49,305,60,0,50,23,0,3,0,0,0,3,35,8,65,5,15,2,0,0,3,16,24,0,9,1,0,0,31,241,1,0,0,0,0,0,0,2,0,0,4,4,21,31,85,4,31,127,5,56,5,1,4,69,82,0,1,34,41,140,0,1,11,8,28,11,10,23,48,0,363,28,138,0,0,7,20,0,0,12,56,5,21,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,14,3,15,18,39,96,0,0,14,14,109,1743,542,521,826,605,6,0,0,3,19,17,64,1,2,1,31,0,2,0,2,2,25,5,8,180,0,0,3,0,9,0,0,1,0,2,9,0,1,5,34,141,0,0,0,1,0,0,1,90,59,3,5,0,1,253,0,0,7,16,2,0,18,2,0,113,3,10,103,81,0,8,3,1,1,0,0,0,0,1,1,0,0,4,1,3,13,0,1,8,15,3,5,23,3,8,20,4,21,263,6,3,0,0,0,0,0,0,0,1,2,16,20,0,7,1,0,0,0,1,1,12,2,1,0,0,0,0,0,0,0,1,0,0,0,0,1,0,0,2,0,0,0,1,0,0,0,0,1,0,6,0,1,10,8,101,0,0,0,7,2,2,0,9,13,0,39,46,0,36,0,3,92,20,30,62,15,19,554,2537,0,1,8,4,5,0,0,0,0,26,2,0,0,0,99,0,0,0,0,1,0,1,2,60,1,0,0,0,8,76,1,1,0,0,0,2,4,21,0,1,3,8,5,0,16,5,37,129,4,5,0,0,1,0,1,0,3,17,1,8,1,75,94,11,1,254,2,0,0,0,2,2,1,33,3597,0,20,3,1,0,0,29,0,0,0,0,4,0,0,4,0,0,1,0,0,1,0,0,0,0,0,12,31,1,0,13,264,3,1,58,123,7,1,14,55,151,203,0,2,1,1,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,9,5,11,2,9,6,41,20,55,185,273,151,36,84,1,26,408,306,16,1,3,0,2,1,1,15,64,0,203,1,37,0,0,3,0,3,27,28,14,19,0,20,3,0,2,0,975,0,79,13,2,0,15,12,58,5,0,1,1,8,2,28,0,0,0,1,0,104,1,0,1359,1,7,2,0,0,1,0,46,1,27,0,0,0,1,15,5,0,0,0,0,0,0,2,0,0,0,0,0,0,2,5,0,0,20,10,2107,1,3,3,1,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,3,0,0,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,0,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,6,0,0,0,2,0,13,2,18,0,6,11,1,41,1,8,15,0,3,5,0,0,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,0,0,0,7,7,21,0,3,42,15,27,0,39,51,2,1,0,6,44,169,7,14,14,30,28,27,34,287,534,118,0,2319,30,0,2,24,2,25,15,12,0,24,45,2,35,31,29,17,26,1,96,65,63,108,67,16,7,65,119,7,196,369,674,527,2,0,2,1,7,81,1,0,32,4,234,45,2,14,2,0,68,11,10,2069,2300,2193,2,3,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,3,1,3,0,0,0,0,0,2,0,1,11,3,1,1,0,1,3,0,6,23,0,4,0,0,2,2,0,17,14,23,0,5,9,15,21,20,1,0,36,56,1,49,86,18,7,25,6,14,28,302,205,832,299,145,789,1973,588,0,4,4,45,5,47,16,4,18,52,35,17,78,623,68,59,80,112,768,14,12,230,349,697,803,1466,0,0,0,0,0,0,0,0,8,1,0,0,2,0,0,2,0,0,476,0,0,0,15,0,14,0,20,0,1,0,0,25,4,0,0,3,0,2,5,4,0,26,108,0,4,10,0,0,0,0,1,0,10,0,853,323,0,0,0,0,54,2,0,29,0,12,4,15,253,9107,18,1,36,5,0,8,7,7,101,9,23,71,67,25,0,3,81,0,0,2,1,70,224,0,0,25,30,45,251,1970,25,1,18,1,0,1209,0,3,20,42,263,62477,2,16,79,33,2,1384,360,27,0,7,92,29,50,193,1304,256,123,282,282,366,1824,2,5,13,7,47,44,51,123,11,0,9,2,2,1,1,20,0,34,10,17,67,241,750,271,93,250,5,652,0,3,25,2,23,0,118,55,326,111,2877,392,791,0,69,10,20,7,66,0,9,267,1,0,35,15,11,82,2,0,3,4,9,23,10,43,153,112,80,14,292,1225,3092,10350,0,0,0,2,2,4,6,6,56,541,54,0,12,5,156,149,200,163,369,180,24,7,20,435,4,115,694,5781,21,28,89,3,1,0,60,6254,43,291,0,0,0,0,0,0,4,2,0,1,18,3,18,0,175,20,78,15,1897,394,393,568,1298,1,7,0,315,322,871,1,0,2,0,13,28,12,123,66,94,1066,1449,5,326,175,1355,898,87,98,76,353,67,18,32,272,1,2,32,1,2,0,3,3,5,0,36,3,0,12,0,2,0,5,447,57,81,742,626,41,1,1,10,34,40,8,2,211,119,3,325,4,17,9,18,82,281,533,98,325,1,53,184,394,0,3,0,0,0,0,177,812,62,1637,20497,0,0,1,23,1,1,3,0,1,2,0,1,2,12,61,0,102,1,2,0,23,20,147,0,3,26,135,0,103,6,171,180,35,641,47,59,109,259,15,77,32,298,48,108,176,228,35,494,1308,115,153,3,9,1,0,4,8,15,38,60,11,8,2647,58,0,2,0,2,8,11,614,0,0,1,0,25,135,25,28,74,83,62,1547,14,31,77,87,364,275,62,85,196,276,1,0,0,0,2,38,82,42,40,110,29,3,37,2832,143,590,322,11,422,1445,1613,3331,3,25,223,0,90,1,31,476,49,40,15,810,3241,1,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,14,0,0,0,0,1,2,0,0,15,26,0,10,0,2,44,0,0,18,117,160,5,42,19,1846,120,1173,5457,13,40,315,34,64,413,1700,8834,1839,2325,14541,11488,7,0,0,0,0,0,0,0,0,0,87,0,15,0,0,2,70,19,132,24,23,168,615,152,217,93,57,2,142,57,46,87,53,14,68,73,30,5261,47,99,128,34,46,270,2391,1184,6233,2256,13771,5,95,162,3486,103052,0,0,63,270,704,1863,0,0,0,0,0,0,0,0,4,9,48,66,80,218,41,0,26,38,56,8,105,133,61,128,4,1718,311,2519,5838,2571,14239,92731,2,0,17,1112,2110,537,171649,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,56,0,0,3,7,0,0,0,1,0,19,0,0,0,0,7,0,0,0,0,0,2,0,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,1,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,1,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,1,2,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,275,0,0,0,26,0,0,0,0,0,0,2,0,117,0,0,25,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,564,1108
```

### Relative abundance output

`counts_phylum.csv` parsed from 7 kraken2 reports of metagenomic samples using `KrakenParser`:

```
Sample_id,taxon,rel_abund_perc
X1,Other (<4.0%),42.686249843331495
X1,Escherichia coli,12.75490546506176
X1,Haemophilus ducreyi,10.075525825933164
X1,Salmonella enterica,9.632211973651838
X1,Staphylococcus aureus,8.720517307808358
X1,Klebsiella pneumoniae,7.072132502100518
X1,Bacteroides fragilis,4.549653472470442
X1,Morganella morganii,4.508803609642424
X2,Other (<4.0%),46.04232622442552
X2,Morganella morganii,16.5117268346954
X2,Escherichia coli,15.349350872456869
X2,Salmonella enterica,10.345628717042564
X2,Klebsiella pneumoniae,7.063587503374482
X2,Haemophilus ducreyi,4.68737984800517
...
X8,Other (<4.0%),32.34802433843469
X8,Bartonella krasnovii,25.39596964453076
X8,Pediococcus pentosaceus,9.254716232772273
X8,Latilactobacillus sakei,8.688709539996534
X8,Staphylococcus aureus,7.8557850790470285
X8,Bacteroides fragilis,5.997643719867084
X8,Escherichia coli,5.454406567029118
X8,Haemophilus ducreyi,5.004744878322517
X9,Other (<4.0%),46.9787738378817
X9,Escherichia coli,18.22909641989718
X9,Salmonella enterica,10.944105961952845
X9,Klebsiella pneumoniae,9.848017408277853
X9,Staphylococcus aureus,7.364958937831675
X9,Haemophilus ducreyi,6.635047434158754
```

### Visualization examples gallery

|[Stacked Barplot](https://github.com/PopovIILab/KrakenParser/wiki/Stacked-Barplot-API)|[Streamgraph](https://github.com/PopovIILab/KrakenParser/wiki/Streamgraph-API)|
|-------|-------|
|![kpstbar](https://github.com/user-attachments/assets/916b0164-28be-4f49-9634-707408487b85)|![kpstream](https://github.com/user-attachments/assets/5c6d930c-e85f-4e2e-9dbf-8caefca49a76)|

[Stacked Barplot + Streamgraph](https://github.com/PopovIILab/KrakenParser/wiki/Combined-Stacked-Barplot-&-Streamgraph)|[Clustermap](https://github.com/PopovIILab/KrakenParser/wiki/Clustermap)|
|-------|-------|
|![combined_white](https://github.com/user-attachments/assets/58acea93-f079-46fd-ac4b-d2ac83098c59)|![kpclust](https://github.com/user-attachments/assets/98a4d540-7c43-4802-8f77-277a5637a7a1)|

## Quick Start (Full Pipeline)
To run the full pipeline, use the following command:
```bash
KrakenParser --complete -i data/kreports
#Having troubles? Run KrakenParser --complete -h
```
This will:
1. Convert Kraken2 reports to MPA format
2. Combine MPA files into a single file
3. Extract taxonomic levels into separate text files
4. Process extracted text files
5. Convert them into CSV format
6. Calculate relative abundance

### **Input Requirements**
- The Kraken2 reports must be inside a **subdirectory** (e.g., `data/kreports`).
- The script automatically creates output directories and processes the data.

## Installation

```
pip install krakenparser
```

## Using Individual Modules
You can also run each step manually if needed.

### **Step 1: Convert Kraken2 Reports to MPA Format**
```bash
KrakenParser --kreport2mpa -i data/kreports -o data/mpa
#Having troubles? Run KrakenParser --kreport2mpa -h
```
This script converts Kraken2 `.kreport` files into **MPA format** using KrakenTools.

### **Step 2: Combine MPA Files**
```bash
KrakenParser --combine_mpa -i data/mpa/* -o data/COMBINED.txt
#Having troubles? Run KrakenParser --combine_mpa -h
```
This merges multiple MPA files into a single combined file.

### **Step 3: Extract Taxonomic Levels**
```bash
KrakenParser --deconstruct -i data/COMBINED.txt -o data/counts
#Having troubles? Run KrakenParser --deconstruct -h
```

If user wants to inspect **Viruses** domain separately:
```bash
KrakenParser --deconstruct_viruses -i data/COMBINED.txt -o data/counts_viruses
#Having troubles? Run KrakenParser --deconstruct_viruses -h
```

This step extracts only species-level data (excluding human reads).

### **Step 4: Process Extracted Taxonomic Data**
```bash
KrakenParser --process -i data/COMBINED.txt -o data/counts/txt/counts_phylum.txt
#Having troubles? Run KrakenParser --process -h
```

Repeat on other 5 taxonomical levels (class, order, family, genus, species) or wrap up `KrakenParser --process` to a loop!

This script cleans up taxonomic names (removes prefixes, replaces underscores with spaces).

### **Step 5: Convert TXT to CSV**
```bash
KrakenParser --txt2csv -i data/counts/txt/counts_phylum.txt -o data/counts/csv/counts_phylum.csv
#Having troubles? Run KrakenParser --txt2csv -h
```
Repeat on other 5 taxonomical levels (class, order, family, genus, species) or wrap up `KrakenParser --txt2csv` to a loop!

This converts the processed text files into structured CSV format.

### **Step 6: Calculate relative abundance**
```bash
KrakenParser --relabund -i data/counts/csv/counts_phylum.csv -o data/counts/csv_relabund/counts_phylum.csv
#Having troubles? Run KrakenParser --relabund -h
```
Repeat on other 5 taxonomical levels (class, order, family, genus, species) or wrap up `KrakenParser --relabund` to a loop!

This calculates relative abundance and saves as CSV format.

If user wants to group low abundant taxa in "Other" group:
```bash
KrakenParser --relabund -i data/counts/csv/counts_phylum.csv -o data/counts/csv_relabund/counts_phylum.csv --other 3.5
#Having troubles? Run KrakenParser --relabund -h
```

This will group all the taxa that have abundance <3.5 into "Other <3.5%" group. Other parameters are welcome!

## Arguments Breakdown
### **KrakenParser** (Main Pipeline)
- Automates the entire workflow.
- Takes **one argument**: the path to Kraken2 reports (`data/kreports`).
- Runs all the scripts in sequence.

### **--kreport2mpa** (Step 1)
- Converts Kraken2 reports to MPA format.
- Uses `KrakenTools/kreport2mpa.py`.

### **--combine_mpa** (Step 2)
- Combines multiple MPA files into one.
- Uses `KrakenTools/combine_mpa.py`.

### **--deconstruct** & **--deconstruct_viruses** (Step 3)
- Extracts **phylum, class, order, family, genus, species** into separate text files.
- Removes human-related reads (**--deconstruct** only).

### **--process** (Step 4)
- Cleans and formats extracted taxonomic data.
- Removes prefixes (`s__`, `g__`, etc.), replaces underscores with spaces.

### **--txt2csv** (Step 5)
- Converts cleaned text files to CSV.
- Transposes data so that sample names become rows.

### **--relabund** (Step 6)
- Calculates relative abundance based on total abundance CSV.
- Optionally can group low abundant taxa.

## Example Output Structure
After running the full pipeline, the output directory will look like this:
```
data/
├─ kreports/           # Input Kraken2 reports
├─ mpa/                # Converted MPA files
├─ COMBINED.txt        # Merged MPA file
└─ counts/
   ├─ txt/             # Extracted taxonomic levels in TXT
   │  ├─ counts_species.txt
   │  ├─ counts_genus.txt
   │  ├─ counts_family.txt
   │  ├─ ...
   └─ csv/             # Total abundance CSV output
   │  ├─ counts_species.csv
   │  ├─ counts_genus.csv
   │  ├─ counts_family.csv
   │  ├─ ...
   └─ csv_relabund/    # Relative abundance CSV output
   │  ├─ counts_species.csv
   │  ├─ counts_genus.csv
   │  ├─ counts_family.csv
   │  ├─ ...
```

## Conclusion
KrakenParser provides a **simple and automated** way to convert Kraken2 reports into usable CSV files for downstream analysis. You can run the **full pipeline** with a single command or use **individual scripts** as needed.

For any issues or feature requests, feel free to open an issue on GitHub!

🚀 Happy analyzing!